searchData={"items":[{"type":"module","title":"Vix.Operator","doc":"Provides an intuitive and readable interface for performing image processing operations by overriding common mathematical and relational operators.\n\nThis module simplifies complex image processing pipelines by allowing you to use familiar operators, such as `+`, `-`, `*`, `/`, and comparison operators (`==`, `>=`, etc.), directly with images, numbers, and lists of numbers (pixels). It also includes utility functions for logical operations and validation, like `all?/2`.","ref":"Vix.Operator.html"},{"type":"module","title":"Key Features - Vix.Operator","doc":"- **Bitwise Operations**: Perform Bitwise Boolean operations such as `&&`, `||`, and `xor` between images and numbers.\n- **Arithmetic Operations**: Use operators such as `+`, `-`, `*`, `/`, and `**` to perform pixel-wise operations between images, numbers, or lists of numbers.\n- **Comparison Operations**: Compare pixel values using operators like `==`, `!=`, `<`, `<=`, `>`, and `>=`, returning the result as a new image.\n- **Logical Validation**: Check pixel values for truthiness (e.g., `255` for true, `0` for false) using `all?/2`.","ref":"Vix.Operator.html#module-key-features"},{"type":"module","title":"Example Usage - Vix.Operator","doc":"```elixir\ndefmodule Example do\n alias Vix.Vips.Operation\n\n def demo_operations do\n   # Import only the required operators for readability and clarity\n   use Vix.Operator, only: [+: 2, -: 2, *: 2, /: 2, ==: 2, all?: 2]\n\n   # Create a black image (100x100, 3 bands)\n   black = Image.build_image!(100, 100, [0, 0, 0])\n\n   # Add constant values to pixels\n   grey1 = black + 125\n   grey2 = black + [125, 125, 125]\n\n   # Pixel-wise addition: [255, 255, 255] + [0, 0, 0]\n   result_image = white + grey1\n\n   # Create a white image\n   white = Image.build_image!(100, 100, [255, 255, 255])\n\n   result = (black + 255) == white\n   true = all?(result, true)\n end\nend\n```","ref":"Vix.Operator.html#module-example-usage"},{"type":"function","title":"Vix.Operator.&&/2","doc":"Performs Bitwise Boolean AND Operation (&&) between Images and numbers, returning the result as an Image.","ref":"Vix.Operator.html#&&/2"},{"type":"function","title":"Overview - Vix.Operator.&&/2","doc":"The operation handles various input combinations:\n\n* Image && Image\n* Image && number(s)\n* number(s) && Image\n* non-Image values (falls back to `Kernel`)","ref":"Vix.Operator.html#&&/2-overview"},{"type":"function","title":"Input Handling - Vix.Operator.&&/2","doc":"Values are cast up before operations. Float values are converted to integers","ref":"Vix.Operator.html#&&/2-input-handling"},{"type":"function","title":"Number Inputs - Vix.Operator.&&/2","doc":"- Single number: Applied to all image bands uniformly\n- Number list:\n  - If list size matches image bands: Each number applies to its respective band\n  - If list size does not match the image bands: Either the image bands or the list is scaled up to match the other.","ref":"Vix.Operator.html#&&/2-number-inputs"},{"type":"function","title":"Image Inputs - Vix.Operator.&&/2","doc":"- When both inputs are images: Uses `Operation.boolean!(a, b, :VIPS_OPERATION_BOOLEAN_AND)`\n\n\n# Examples","ref":"Vix.Operator.html#&&/2-image-inputs"},{"type":"function","title":"Image && Image Operations - Vix.Operator.&&/2","doc":"```elixir\niex> img = Image.build_image!(2, 1, [0, 255, 0]) && Image.build_image!(2, 1, [0, 255, 255])\niex> Image.shape(img)\n{2, 1, 3}\niex> Image.to_list!(img)\n[[[0, 255, 0], [0, 255, 0]]]\n\n# Identical Images\niex> (Image.build_image!(2, 2, [2, 4, 8]) && Image.build_image!(2, 2, [2, 4, 8])) |> Image.to_list!()\n[[[2, 4, 8], [2, 4, 8]], [[2, 4, 8], [2, 4, 8]]]\n\n# Different dimensions\niex> img = Image.build_image!(1, 1, [2]) && Image.build_image!(1, 2, [2, 4, 8])\niex> Image.shape(img)\n{1, 2, 3}\niex> Image.to_list!(img)\n[[[2, 0, 0]], [[0, 0, 0]]]\n```","ref":"Vix.Operator.html#&&/2-image-image-operations"},{"type":"function","title":"Image && Number Operations - Vix.Operator.&&/2","doc":"```elixir\n# Single number comparison (applies to all bands)\niex> (Image.build_image!(1, 2, [2, 5, 3]) && 6) |> Image.to_list!()\n[[[2, 4, 2]], [[2, 4, 2]]]\n\n# Float Comparison\niex> (Image.build_image!(1, 1, [10]) && 6.0) |> Image.to_list!()\n[[[2]]]\n\n# List comparison (band-wise)\niex> (Image.build_image!(1, 1, [2, 2]) && [1, 3]) |> Image.to_list!()\n[[[0, 2]]]\n```","ref":"Vix.Operator.html#&&/2-image-number-operations"},{"type":"function","title":"Reverse Operations - Vix.Operator.&&/2","doc":"```elixir\n# Number && Image\niex> (10.0 && Image.build_image!(1, 1, [5])) |> Image.to_list!()\n[[[0]]]\n\n# List && Image\niex> ([2, 2] && Image.build_image!(1, 1, [1, 3])) |> Image.to_list!()\n[[[0, 2]]]\n```","ref":"Vix.Operator.html#&&/2-reverse-operations"},{"type":"function","title":"Kernel Fallback - Vix.Operator.&&/2","doc":"```elixir\n# When neither argument is an image\niex> false && true\nfalse\n```","ref":"Vix.Operator.html#&&/2-kernel-fallback"},{"type":"function","title":"Vix.Operator.**/2","doc":"Performs Power (**) operation between Images, numbers, and lists of numbers (pixels).","ref":"Vix.Operator.html#**/2"},{"type":"function","title":"Overview - Vix.Operator.**/2","doc":"The operator handles Images, numbers, and lists together with the following rules:\n- Single numbers are applied to all image bands\n- Lists can be matched with image bands\n- Type casting is handled automatically\n- When neither argument is an image, delegates to `Kernel.**/2`","ref":"Vix.Operator.html#**/2-overview"},{"type":"function","title":"Behavior - Vix.Operator.**/2","doc":"","ref":"Vix.Operator.html#**/2-behavior"},{"type":"function","title":"Power Rules - Vix.Operator.**/2","doc":"When operating with numbers or lists:\n\n- Single number: Applied to all image bands\n- List matching image bands: Each number maps to corresponding band\n- List size does not match bands: Creates multi-band output with either the image bands or the list is scaled up to match the other.\n- Two images: Bands are scaled up to match each other.","ref":"Vix.Operator.html#**/2-power-rules"},{"type":"function","title":"Type Handling - Vix.Operator.**/2","doc":"Output Image Band Format:\n\n- Two images: Cast to smallest common format that can hold result\n- Image + number:\n  - Double input → Double output\n  - otherwise  → Float output","ref":"Vix.Operator.html#**/2-type-handling"},{"type":"function","title":"Examples - Vix.Operator.**/2","doc":"","ref":"Vix.Operator.html#**/2-examples"},{"type":"function","title":"Basic Image Power Operation - Vix.Operator.**/2","doc":"```elixir\n# Raising each pixel of a single-band image to the power of another single-band image\niex> img1 = Image.build_image!(2, 2, [2])\niex> img2 = Image.build_image!(2, 2, [3])\niex> result = img1 ** img2\niex> Image.to_list!(result)\n[[[8.0], [8.0]], [[8.0], [8.0]]]\n\n# Raising multi-band image pixels to the power of single-band image\niex> multi_band = Image.build_image!(1, 2, [2, 3, 4])\niex> single_band = Image.build_image!(1, 2, [2])\niex> result = multi_band ** single_band\niex> Image.to_list!(result)\n[[[4.0, 9.0, 16.0]], [[4.0, 9.0, 16.0]]]\n```","ref":"Vix.Operator.html#**/2-basic-image-power-operation"},{"type":"function","title":"Image and Number Operations - Vix.Operator.**/2","doc":"```elixir\n# Raising all bands of an image to a constant power\niex> img = Image.build_image!(1, 1, [3, 4, 5]) ** 2\niex> Image.to_list!(img)\n[[[9.0, 16.0, 25.0]]]\n\n# Raising image pixels to a fractional power\niex> img = Image.build_image!(1, 1, [16]) ** 0.5\niex> Image.to_list!(img)\n[[[4.0]]]\n```","ref":"Vix.Operator.html#**/2-image-and-number-operations"},{"type":"function","title":"List Operations - Vix.Operator.**/2","doc":"```elixir\n# List matching image bands\niex> img = Image.build_image!(1, 2, [2, 3]) ** [3, 2]\niex> Image.to_list!(img)\n[[[8.0, 9.0]], [[8.0, 9.0]]]\n\n# List larger than bands (expands single-band image)\niex> img = Image.build_image!(1, 2, [2]) ** [3, 4, 5]\niex> Image.shape(img)\n{1, 2, 3}\niex> Image.to_list!(img)\n[[[8.0, 16.0, 32.0]], [[8.0, 16.0, 32.0]]]\n```","ref":"Vix.Operator.html#**/2-list-operations"},{"type":"function","title":"Reverse Operations - Vix.Operator.**/2","doc":"```elixir\n# Number on the left side\niex> img = 2 ** Image.build_image!(1, 2, [3, 4])\niex> Image.to_list!(img)\n[[[8.0, 16.0]], [[8.0, 16.0]]]\n\n# List on the left side\niex> img = [2, 3, 4] ** Image.build_image!(1, 2, [2])\niex> Image.shape(img)\n{1, 2, 3}\niex> Image.to_list!(img)\n[[[4.0, 9.0, 16.0]], [[4.0, 9.0, 16.0]]]\n```","ref":"Vix.Operator.html#**/2-reverse-operations"},{"type":"function","title":"Type Casting Examples - Vix.Operator.**/2","doc":"```elixir\n# Always returns float output\niex> img = Image.build_image!(2, 2, [3]) ** 2\niex> Image.format(img)\n:VIPS_FORMAT_FLOAT\n```","ref":"Vix.Operator.html#**/2-type-casting-examples"},{"type":"function","title":"Fallback Behavior - Vix.Operator.**/2","doc":"```elixir\n# Standard Kernel.** behavior when no images involved\niex> 2 ** 3\n8\n```","ref":"Vix.Operator.html#**/2-fallback-behavior"},{"type":"function","title":"Vix.Operator.*/2","doc":"Performs Multiplication (*) operation between Images, numbers, and lists of numbers (pixels).","ref":"Vix.Operator.html#*/2"},{"type":"function","title":"Overview - Vix.Operator.*/2","doc":"The operator handles Images, numbers, and lists together with the following rules:\n- Single numbers are applied to all image bands\n- Lists can be matched with image bands\n- Type casting is handled automatically\n- When neither argument is an image, delegates to `Kernel.*/2`","ref":"Vix.Operator.html#*/2-overview"},{"type":"function","title":"Behavior - Vix.Operator.*/2","doc":"","ref":"Vix.Operator.html#*/2-behavior"},{"type":"function","title":"Multiplication Rules - Vix.Operator.*/2","doc":"When operating with numbers or lists:\n\n- Single number: Applied to all image bands\n- List matching image bands: Each number maps to corresponding band\n- List size does not match bands: Creates multi-band output with either the image bands or the list is scaled up to match the other.\n- Two images: Bands are scaled up to match each other.","ref":"Vix.Operator.html#*/2-multiplication-rules"},{"type":"function","title":"Type Handling - Vix.Operator.*/2","doc":"Output Image Band Format:\n\n- Two images: Cast to smallest common format that can hold result\n- Image + number:\n  - Complex input → Complex output\n  - Double input → Double output\n  - otherwise → Float output","ref":"Vix.Operator.html#*/2-type-handling"},{"type":"function","title":"Examples - Vix.Operator.*/2","doc":"","ref":"Vix.Operator.html#*/2-examples"},{"type":"function","title":"Basic Image Multiplication - Vix.Operator.*/2","doc":"```elixir\n# Multiplying two single-band images\niex> img1 = Image.build_image!(2, 2, [3])\niex> img2 = Image.build_image!(2, 2, [4])\niex> result = img1 * img2\niex> Image.to_list!(result)\n[[[12], [12]], [[12], [12]]]\n\n# Multiplying images with different bands\niex> multi_band = Image.build_image!(1, 2, [2, 3, 4])\niex> single_band = Image.build_image!(1, 2, [5])\niex> result = multi_band * single_band\niex> Image.to_list!(result)\n[[[10, 15, 20]], [[10, 15, 20]]]\n```","ref":"Vix.Operator.html#*/2-basic-image-multiplication"},{"type":"function","title":"Image and Number Operations - Vix.Operator.*/2","doc":"```elixir\n# Multiplying all bands by a number\niex> img = Image.build_image!(1, 1, [6, 7, 8]) * 3\niex> Image.to_list!(img)\n[[[18.0, 21.0, 24.0]]]\n\n# Multiplying by a float (demonstrates type conversion)\niex> img = Image.build_image!(1, 1, [10]) * 2.5\niex> Image.format(img)\n:VIPS_FORMAT_FLOAT\niex> Image.to_list!(img)\n[[[25.0]]]\n```","ref":"Vix.Operator.html#*/2-image-and-number-operations"},{"type":"function","title":"List Operations - Vix.Operator.*/2","doc":"```elixir\n# List matching image bands\niex> img = Image.build_image!(1, 2, [2, 3]) * [4, 5]\niex> Image.to_list!(img)\n[[[8.0, 15.0]], [[8.0, 15.0]]]\n\n# List larger than bands (expands single-band image)\niex> img = Image.build_image!(1, 2, [3]) * [2, 4, 6]\niex> Image.shape(img)\n{1, 2, 3}\niex> Image.to_list!(img)\n[[[6.0, 12.0, 18.0]], [[6.0, 12.0, 18.0]]]\n```","ref":"Vix.Operator.html#*/2-list-operations"},{"type":"function","title":"Reverse Operations - Vix.Operator.*/2","doc":"```elixir\n# Number on the left side\niex> img = 10 * Image.build_image!(1, 2, [2, 4])\niex> Image.to_list!(img)\n[[[20.0, 40.0]], [[20.0, 40.0]]]\n\n# List on the left side\niex> img = [2, 3, 4] * Image.build_image!(1, 2, [5])\niex> Image.shape(img)\n{1, 2, 3}\niex> Image.to_list!(img)\n[[[10.0, 15.0, 20.0]], [[10.0, 15.0, 20.0]]]\n```","ref":"Vix.Operator.html#*/2-reverse-operations"},{"type":"function","title":"Type Casting Examples - Vix.Operator.*/2","doc":"```elixir\n# Integer to float conversion\niex> img = Image.build_image!(2, 2, [4]) * 2.5\niex> Image.format(img)\n:VIPS_FORMAT_FLOAT\n```","ref":"Vix.Operator.html#*/2-type-casting-examples"},{"type":"function","title":"Fallback Behavior - Vix.Operator.*/2","doc":"```elixir\n# Standard Kernel.* behavior when no images involved\niex> 5 * 3\n15\n```","ref":"Vix.Operator.html#*/2-fallback-behavior"},{"type":"function","title":"Vix.Operator.+/2","doc":"Performs Addition (+) operation between Images, numbers, and lists of numbers (pixels).","ref":"Vix.Operator.html#+/2"},{"type":"function","title":"Overview - Vix.Operator.+/2","doc":"The operator handles Images, numbers, and lists together with the following rules:\n- Single numbers are applied to all image bands\n- Lists can be matched with image bands\n- Type casting is handled automatically\n- When neither argument is an image, delegates to `Kernel.+/2`","ref":"Vix.Operator.html#+/2-overview"},{"type":"function","title":"Behavior - Vix.Operator.+/2","doc":"","ref":"Vix.Operator.html#+/2-behavior"},{"type":"function","title":"Addition Rules - Vix.Operator.+/2","doc":"When operating with numbers or lists:\n\n- Single number: Applied to all image bands\n- List matching image bands: Each number maps to corresponding band\n- List size does not match bands: Creates multi-band output with either the image bands or the list is scaled up to match the other.\n- Two images: Bands are scaled up to match each other.","ref":"Vix.Operator.html#+/2-addition-rules"},{"type":"function","title":"Type Handling - Vix.Operator.+/2","doc":"Output Image Band Format:\n\n- Two images: Cast to smallest common format that can hold result\n- Image + number:\n  - Complex input → Complex output\n  - Double input → Double output\n  - otherwise → Float output","ref":"Vix.Operator.html#+/2-type-handling"},{"type":"function","title":"Examples - Vix.Operator.+/2","doc":"","ref":"Vix.Operator.html#+/2-examples"},{"type":"function","title":"Basic Image Addition - Vix.Operator.+/2","doc":"```elixir\n# Adding two single-band images\niex> img1 = Image.build_image!(2, 2, [10])\niex> img2 = Image.build_image!(2, 2, [20])\niex> result = img1 + img2\niex> Image.to_list!(result)\n[[[30], [30]], [[30], [30]]]\n\n# Adding images with different bands\niex> multi_band = Image.build_image!(1, 2, [10, 20, 30])\niex> single_band = Image.build_image!(1, 2, [5])\niex> result = multi_band + single_band\niex> Image.to_list!(result)\n[[[15, 25, 35]], [[15, 25, 35]]]\n```","ref":"Vix.Operator.html#+/2-basic-image-addition"},{"type":"function","title":"Image and Number Operations - Vix.Operator.+/2","doc":"```elixir\n# Adding a number to all bands\niex> img = Image.build_image!(1, 1, [10, 20, 30]) + 5\niex> Image.to_list!(img)\n[[[15.0, 25.0, 35.0]]]\n\n# Adding float (demonstrates type conversion)\niex> img = Image.build_image!(1, 1, [10]) + 5.5\niex> Image.format(img)\n:VIPS_FORMAT_FLOAT\niex> Image.to_list!(img)\n[[[15.5]]]\n```","ref":"Vix.Operator.html#+/2-image-and-number-operations"},{"type":"function","title":"List Operations - Vix.Operator.+/2","doc":"```elixir\n# List matching image bands\niex> img = Image.build_image!(1, 2, [10, 20]) + [5, 10]\niex> Image.to_list!(img)\n[[[15.0, 30.0]], [[15.0, 30.0]]]\n\n# List larger than bands (expands single-band image)\niex> img = Image.build_image!(1, 2, [10]) + [5, 10, 15]\niex> Image.shape(img)\n{1, 2, 3}\niex> Image.to_list!(img)\n[[[15.0, 20.0, 25.0]], [[15.0, 20.0, 25.0]]]\n```","ref":"Vix.Operator.html#+/2-list-operations"},{"type":"function","title":"Reverse Operations - Vix.Operator.+/2","doc":"```elixir\n# Number on the left side\niex> img = 5 + Image.build_image!(1, 2, [10, 20])\niex> Image.to_list!(img)\n[[[15.0, 25.0]], [[15.0, 25.0]]]\n\n# List on the left side\niex> img = [5, 10, 15] + Image.build_image!(1, 2, [10])\niex> Image.shape(img)\n{1, 2, 3}\niex> Image.to_list!(img)\n[[[15.0, 20.0, 25.0]], [[15.0, 20.0, 25.0]]]\n```","ref":"Vix.Operator.html#+/2-reverse-operations"},{"type":"function","title":"Type Casting Examples - Vix.Operator.+/2","doc":"```elixir\n# Integer to float conversion\niex> img = Image.build_image!(2, 2, [10]) + 5.5\niex> Image.format(img)\n:VIPS_FORMAT_FLOAT\n```","ref":"Vix.Operator.html#+/2-type-casting-examples"},{"type":"function","title":"Fallback Behavior - Vix.Operator.+/2","doc":"```elixir\n# Standard Kernel.+ behavior when no images involved\niex> 5 + 10\n15\n```","ref":"Vix.Operator.html#+/2-fallback-behavior"},{"type":"function","title":"Vix.Operator.-/2","doc":"Performs Subtraction (-) operation between Images, numbers, and lists of numbers (pixels).","ref":"Vix.Operator.html#-/2"},{"type":"function","title":"Overview - Vix.Operator.-/2","doc":"The operator handles Images, numbers, and lists together with the following rules:\n- Single numbers are applied to all image bands\n- Lists can be matched with image bands\n- Type casting is handled automatically\n- When neither argument is an image, delegates to `Kernel.-/2`","ref":"Vix.Operator.html#-/2-overview"},{"type":"function","title":"Behavior - Vix.Operator.-/2","doc":"","ref":"Vix.Operator.html#-/2-behavior"},{"type":"function","title":"Subtraction Rules - Vix.Operator.-/2","doc":"When operating with numbers or lists:\n\n- Single number: Applied to all image bands\n- List matching image bands: Each number maps to corresponding band\n- List size does not match bands: Creates multi-band output with either the image bands or the list is scaled up to match the other.\n- Two images: Bands are scaled up to match each other.","ref":"Vix.Operator.html#-/2-subtraction-rules"},{"type":"function","title":"Type Handling - Vix.Operator.-/2","doc":"Output Image Band Format:\n\n- Two images: Cast to smallest common format that can hold result\n- Image + number:\n  - Complex input → Complex output\n  - Double input → Double output\n  - otherwise → Float output","ref":"Vix.Operator.html#-/2-type-handling"},{"type":"function","title":"Examples - Vix.Operator.-/2","doc":"","ref":"Vix.Operator.html#-/2-examples"},{"type":"function","title":"Basic Image Subtraction - Vix.Operator.-/2","doc":"```elixir\n# Subtracting two single-band images\niex> img1 = Image.build_image!(2, 2, [30])\niex> img2 = Image.build_image!(2, 2, [10])\niex> result = img1 - img2\niex> Image.to_list!(result)\n[[[20], [20]], [[20], [20]]]\n\n# Subtracting images with different bands\niex> multi_band = Image.build_image!(1, 2, [30, 40, 50])\niex> single_band = Image.build_image!(1, 2, [10])\niex> result = multi_band - single_band\niex> Image.to_list!(result)\n[[[20, 30, 40]], [[20, 30, 40]]]\n```","ref":"Vix.Operator.html#-/2-basic-image-subtraction"},{"type":"function","title":"Image and Number Operations - Vix.Operator.-/2","doc":"```elixir\n# Subtracting a number from all bands\niex> img = Image.build_image!(1, 1, [50, 60, 70]) - 20\niex> Image.to_list!(img)\n[[[30.0, 40.0, 50.0]]]\n\n# Subtracting a float (demonstrates type conversion)\niex> img = Image.build_image!(1, 1, [50]) - 15.5\niex> Image.format(img)\n:VIPS_FORMAT_FLOAT\niex> Image.to_list!(img)\n[[[34.5]]]\n```","ref":"Vix.Operator.html#-/2-image-and-number-operations"},{"type":"function","title":"List Operations - Vix.Operator.-/2","doc":"```elixir\n# List matching image bands\niex> img = Image.build_image!(1, 2, [30, 50]) - [10, 20]\niex> Image.to_list!(img)\n[[[20.0, 30.0]], [[20.0, 30.0]]]\n\n# List larger than bands (expands single-band image)\niex> img = Image.build_image!(1, 2, [30]) - [5, 10, 15]\niex> Image.shape(img)\n{1, 2, 3}\niex> Image.to_list!(img)\n[[[25.0, 20.0, 15.0]], [[25.0, 20.0, 15.0]]]\n```","ref":"Vix.Operator.html#-/2-list-operations"},{"type":"function","title":"Reverse Operations - Vix.Operator.-/2","doc":"```elixir\n# Number on the left side\niex> img = 100 - Image.build_image!(1, 2, [30, 50])\niex> Image.to_list!(img)\n[[[70.0, 50.0]], [[70.0, 50.0]]]\n\n# List on the left side\niex> img = [50, 60, 70] - Image.build_image!(1, 2, [20])\niex> Image.shape(img)\n{1, 2, 3}\niex> Image.to_list!(img)\n[[[30.0, 40.0, 50.0]], [[30.0, 40.0, 50.0]]]\n```","ref":"Vix.Operator.html#-/2-reverse-operations"},{"type":"function","title":"Type Casting Examples - Vix.Operator.-/2","doc":"```elixir\n# Integer to float conversion\niex> img = Image.build_image!(2, 2, [30]) - 10.5\niex> Image.format(img)\n:VIPS_FORMAT_FLOAT\n```","ref":"Vix.Operator.html#-/2-type-casting-examples"},{"type":"function","title":"Fallback Behavior - Vix.Operator.-/2","doc":"```elixir\n# Standard Kernel.- behavior when no images involved\niex> 50 - 20\n30\n```","ref":"Vix.Operator.html#-/2-fallback-behavior"},{"type":"function","title":"Vix.Operator.//2","doc":"Performs Division (/) operation between Images, numbers, and lists of numbers (pixels).","ref":"Vix.Operator.html#//2"},{"type":"function","title":"Overview - Vix.Operator.//2","doc":"The operator handles Images, numbers, and lists together with the following rules:\n- Single numbers are applied to all image bands\n- Lists can be matched with image bands\n- Type casting is handled automatically\n- When neither argument is an image, delegates to `Kernel.//2`","ref":"Vix.Operator.html#//2-overview"},{"type":"function","title":"Behavior - Vix.Operator.//2","doc":"","ref":"Vix.Operator.html#//2-behavior"},{"type":"function","title":"Division Rules - Vix.Operator.//2","doc":"When operating with numbers or lists:\n\n- Single number: Applied to all image bands\n- List matching image bands: Each number maps to corresponding band\n- List size does not match bands: Creates multi-band output with either the image bands or the list is scaled up to match the other.\n- Two images: Bands are scaled up to match each other.","ref":"Vix.Operator.html#//2-division-rules"},{"type":"function","title":"Type Handling - Vix.Operator.//2","doc":"Output Image Band Format:\n\n- Two images: Cast to smallest common format that can hold result\n- Image + number:\n  - Complex input → Complex output\n  - Double input → Double output\n  - otherwise → Float output","ref":"Vix.Operator.html#//2-type-handling"},{"type":"function","title":"Examples - Vix.Operator.//2","doc":"","ref":"Vix.Operator.html#//2-examples"},{"type":"function","title":"Basic Image Division - Vix.Operator.//2","doc":"```elixir\n# Dividing two single-band images\niex> img1 = Image.build_image!(2, 2, [20])\niex> img2 = Image.build_image!(2, 2, [4])\niex> result = img1 / img2\niex> Image.to_list!(result)\n[[[5.0], [5.0]], [[5.0], [5.0]]]\n\n# Dividing images with different bands\niex> multi_band = Image.build_image!(1, 2, [20, 30, 40])\niex> single_band = Image.build_image!(1, 2, [10])\niex> result = multi_band / single_band\niex> Image.to_list!(result)\n[[[2.0, 3.0, 4.0]], [[2.0, 3.0, 4.0]]]\n\n# Dividing two images where the divisor contains zero.\n# Vix detects division by zero, and sets those pixels to zero in\n# the output, without any error or warning.\niex> img1 = Image.build_image!(2, 2, [20])\niex> img2 = Image.build_image!(2, 2, [0])\niex> result = img1 / img2\niex> Image.to_list!(result)\n[[[0.0], [0.0]], [[0.0], [0.0]]]\n```","ref":"Vix.Operator.html#//2-basic-image-division"},{"type":"function","title":"Image and Number Operations - Vix.Operator.//2","doc":"```elixir\n# Dividing all bands by a number\niex> img = Image.build_image!(1, 1, [30, 60, 90]) / 10\niex> Image.to_list!(img)\n[[[3.0, 6.0, 9.0]]]\n\n# Dividing by a float (demonstrates type conversion)\niex> img = Image.build_image!(1, 1, [25]) / 2.5\niex> Image.format(img)\n:VIPS_FORMAT_FLOAT\niex> Image.to_list!(img)\n[[[10.0]]]\n```","ref":"Vix.Operator.html#//2-image-and-number-operations"},{"type":"function","title":"List Operations - Vix.Operator.//2","doc":"```elixir\n# List matching image bands\niex> img = Image.build_image!(1, 2, [40, 60]) / [4, 6]\niex> Image.to_list!(img)\n[[[10.0, 10.0]], [[10.0, 10.0]]]\n\n# List larger than bands (expands single-band image)\niex> img = Image.build_image!(1, 2, [30]) / [3, 6, 5]\niex> Image.shape(img)\n{1, 2, 3}\niex> Image.to_list!(img)\n[[[10.0, 5.0, 6.0]], [[10.0, 5.0, 6.0]]]\n```","ref":"Vix.Operator.html#//2-list-operations"},{"type":"function","title":"Reverse Operations - Vix.Operator.//2","doc":"```elixir\n# Number on the left side\niex> img = 100 / Image.build_image!(1, 2, [5, 10])\niex> Image.to_list!(img)\n[[[20.0, 10.0]], [[20.0, 10.0]]]\n\n# List on the left side\niex> img = [100, 200, 300] / Image.build_image!(1, 2, [10])\niex> Image.shape(img)\n{1, 2, 3}\niex> Image.to_list!(img)\n[[[10.0, 20.0, 30.0]], [[10.0, 20.0, 30.0]]]\n```","ref":"Vix.Operator.html#//2-reverse-operations"},{"type":"function","title":"Type Casting Examples - Vix.Operator.//2","doc":"```elixir\n# Integer to float conversion\niex> img = Image.build_image!(2, 2, [25]) / 2\niex> Image.format(img)\n:VIPS_FORMAT_FLOAT\n```","ref":"Vix.Operator.html#//2-type-casting-examples"},{"type":"function","title":"Fallback Behavior - Vix.Operator.//2","doc":"```elixir\n# Standard Kernel./ behavior when no images involved\niex> 10 / 2\n5.0\n```","ref":"Vix.Operator.html#//2-fallback-behavior"},{"type":"function","title":"Vix.Operator.!=/2","doc":"Performs Not_equal (!=) comparison between Images and numbers, returning the result as an Image.","ref":"Vix.Operator.html#!=/2"},{"type":"function","title":"Overview - Vix.Operator.!=/2","doc":"The operator compares Images and numbers, with the result being an Image where:\n- `0` represents `false`\n- `255` represents `true`\n\nWhen neither argument is an image, the operation delegates to `Kernel.!=/2`.","ref":"Vix.Operator.html#!=/2-overview"},{"type":"function","title":"Behavior - Vix.Operator.!=/2","doc":"","ref":"Vix.Operator.html#!=/2-behavior"},{"type":"function","title":"Image Comparison Rules - Vix.Operator.!=/2","doc":"- Single number: Applied to all image bands\n- List matching image bands: Each number maps to corresponding band\n- List size does not match bands: Creates multi-band output with either the image bands or the list is scaled up to match the other.\n- Two images: Uses `Operation.relational!(a, b, :VIPS_OPERATION_RELATIONAL_NOTEQ)`. Bands are scaled up to match each other.","ref":"Vix.Operator.html#!=/2-image-comparison-rules"},{"type":"function","title":"Type Handling - Vix.Operator.!=/2","doc":"- Images are cast to the smallest common format before comparison\n- Supports mixed numeric types (e.g., integers with floats)\n- Works bidirectionally (image < number and number < image)","ref":"Vix.Operator.html#!=/2-type-handling"},{"type":"function","title":"Examples - Vix.Operator.!=/2","doc":"","ref":"Vix.Operator.html#!=/2-examples"},{"type":"function","title":"Examples - Vix.Operator.!=/2","doc":"","ref":"Vix.Operator.html#!=/2-examples"},{"type":"function","title":"Basic Image Comparison - Vix.Operator.!=/2","doc":"```elixir\n# Comparing two images\niex> img = Image.build_image!(2, 2, [10, 15]) != Image.build_image!(2, 2, [15, 15])\niex> Image.shape(img)\n{2, 2, 2}\niex> Image.to_list!(img)\n[[[255, 0], [255, 0]], [[255, 0], [255, 0]]]\n```","ref":"Vix.Operator.html#!=/2-basic-image-comparison"},{"type":"function","title":"Checking All Pixels - Vix.Operator.!=/2","doc":"```elixir\n# Using all?/2 to verify if all pixels match condition\niex> img = Image.build_image!(2, 2, [5]) != Image.build_image!(2, 2, [10])\niex> all?(img, true)\ntrue\n```","ref":"Vix.Operator.html#!=/2-checking-all-pixels"},{"type":"function","title":"Multi-band Image Operations - Vix.Operator.!=/2","doc":"```elixir\n# Same values across all bands (should be false)\niex> (Image.build_image!(10, 10, [10, 20, 30]) != Image.build_image!(10, 10, [10, 20, 30])) |> all?(true)\nfalse\n\n# Different values between single and multi-band\niex> (Image.build_image!(10, 10, [20]) != Image.build_image!(10, 10, [10, 10, 10])) |> all?(true)\ntrue\n\n# Multi-band vs single-band with matching values\niex> (Image.build_image!(10, 10, [10, 20, 30]) != Image.build_image!(10, 10, [30])) |> all?(true)\nfalse\n```","ref":"Vix.Operator.html#!=/2-multi-band-image-operations"},{"type":"function","title":"Image vs. Number Comparison - Vix.Operator.!=/2","doc":"```elixir\n# Single number compared to all bands\niex> img = Image.build_image!(1, 2, [5, 10, 20]) != 5\niex> Image.to_list!(img)\n[[[0, 255, 255]], [[0, 255, 255]]]\n\n# Comparing with same value (should be false)\niex> (Image.build_image!(10, 10, [10]) != 10) |> all?(true)\nfalse\n\n# Float comparison with different value\niex> (Image.build_image!(10, 10, [10]) != 20.0) |> all?(true)\ntrue\n\n# List comparison with bands\niex> img = Image.build_image!(1, 1, [10, 20]) != [10, 10]\niex> Image.to_list!(img)\n[[[0, 255]]]\n```","ref":"Vix.Operator.html#!=/2-image-vs-number-comparison"},{"type":"function","title":"Reverse Comparison - Vix.Operator.!=/2","doc":"```elixir\n# Float on the left side\niex> (10.0 != Image.build_image!(10, 10, [20])) |> all?(true)\ntrue\n\n# List on the left side\niex> ([10, 20, 30] != Image.build_image!(10, 10, [20, 30, 40])) |> all?(true)\ntrue\n```","ref":"Vix.Operator.html#!=/2-reverse-comparison"},{"type":"function","title":"Fallback Behavior - Vix.Operator.!=/2","doc":"```elixir\n# Standard Kernel.!= behavior when no images involved\niex> 4 != 5\ntrue\n```","ref":"Vix.Operator.html#!=/2-fallback-behavior"},{"type":"function","title":"Vix.Operator.</2","doc":"Performs Less_than (<) comparison between Images and numbers, returning the result as an Image.","ref":"Vix.Operator.html#%3C/2"},{"type":"function","title":"Overview - Vix.Operator.</2","doc":"The operator compares Images and numbers, with the result being an Image where:\n- `0` represents `false`\n- `255` represents `true`\n\nWhen neither argument is an image, the operation delegates to `Kernel.</2`.","ref":"Vix.Operator.html#%3C/2-overview"},{"type":"function","title":"Behavior - Vix.Operator.</2","doc":"","ref":"Vix.Operator.html#%3C/2-behavior"},{"type":"function","title":"Image Comparison Rules - Vix.Operator.</2","doc":"- Single number: Applied to all image bands\n- List matching image bands: Each number maps to corresponding band\n- List size does not match bands: Creates multi-band output with either the image bands or the list is scaled up to match the other.\n- Two images: Uses `Operation.relational!(a, b, :VIPS_OPERATION_RELATIONAL_LESS)`. Bands are scaled up to match each other.","ref":"Vix.Operator.html#%3C/2-image-comparison-rules"},{"type":"function","title":"Type Handling - Vix.Operator.</2","doc":"- Images are cast to the smallest common format before comparison\n- Supports mixed numeric types (e.g., integers with floats)\n- Works bidirectionally (image < number and number < image)","ref":"Vix.Operator.html#%3C/2-type-handling"},{"type":"function","title":"Examples - Vix.Operator.</2","doc":"","ref":"Vix.Operator.html#%3C/2-examples"},{"type":"function","title":"Basic Image Comparison - Vix.Operator.</2","doc":"```elixir\n# Comparing two images\niex> img = Image.build_image!(2, 2, [10, 15])   Image.shape(img)\n{2, 2, 2}\niex> Image.to_list!(img)\n[[[0, 255], [0, 255]], [[0, 255], [0, 255]]]\n```","ref":"Vix.Operator.html#%3C/2-basic-image-comparison"},{"type":"function","title":"Checking All Pixels - Vix.Operator.</2","doc":"```elixir\n# Using all?/2 to verify if all pixels match condition\niex> img = Image.build_image!(2, 2, [5])   all?(img, true)\ntrue\n```","ref":"Vix.Operator.html#%3C/2-checking-all-pixels"},{"type":"function","title":"Multi-band Image Operations - Vix.Operator.</2","doc":"```elixir\n# Different band count scenarios\niex> (Image.build_image!(10, 10, [10, 20, 30])   all?(true)\ntrue\niex> (Image.build_image!(10, 10, [10])   all?(true)\nfalse\n```","ref":"Vix.Operator.html#%3C/2-multi-band-image-operations"},{"type":"function","title":"Image vs. Number Comparison - Vix.Operator.</2","doc":"```elixir\n# Single number compared to all bands\niex> img = Image.build_image!(1, 2, [1, 10, 20]) < 5\niex> Image.to_list!(img)\n[[[255, 0, 0]], [[255, 0, 0]]]\n\n# comparing different types\niex> (Image.build_image!(10, 10, [10]) < 20.0) |> all?(true)\ntrue\n\n# List comparison with bands\niex> img = Image.build_image!(1, 1, [10, 20]) < [20, 10]\niex> Image.to_list!(img)\n[[[255, 0]]]\n```","ref":"Vix.Operator.html#%3C/2-image-vs-number-comparison"},{"type":"function","title":"Reverse Comparison - Vix.Operator.</2","doc":"```elixir\n# Numbers/lists on the left side\niex> (10.0   all?(true)\ntrue\niex> ([10, 20, 30]   all?(true)\ntrue\n```","ref":"Vix.Operator.html#%3C/2-reverse-comparison"},{"type":"function","title":"Fallback Behavior - Vix.Operator.</2","doc":"```elixir\n# Standard Kernel.  4 < 5\ntrue\n```","ref":"Vix.Operator.html#%3C/2-fallback-behavior"},{"type":"function","title":"Vix.Operator.<=/2","doc":"Performs Less_than_equal (<=) comparison between Images and numbers, returning the result as an Image.","ref":"Vix.Operator.html#%3C=/2"},{"type":"function","title":"Overview - Vix.Operator.<=/2","doc":"The operator compares Images and numbers, with the result being an Image where:\n- `0` represents `false`\n- `255` represents `true`\n\nWhen neither argument is an image, the operation delegates to `Kernel.<=/2`.","ref":"Vix.Operator.html#%3C=/2-overview"},{"type":"function","title":"Behavior - Vix.Operator.<=/2","doc":"","ref":"Vix.Operator.html#%3C=/2-behavior"},{"type":"function","title":"Image Comparison Rules - Vix.Operator.<=/2","doc":"- Single number: Applied to all image bands\n- List matching image bands: Each number maps to corresponding band\n- List size does not match bands: Creates multi-band output with either the image bands or the list is scaled up to match the other.\n- Two images: Uses `Operation.relational!(a, b, :VIPS_OPERATION_RELATIONAL_LESSEQ)`. Bands are scaled up to match each other.","ref":"Vix.Operator.html#%3C=/2-image-comparison-rules"},{"type":"function","title":"Type Handling - Vix.Operator.<=/2","doc":"- Images are cast to the smallest common format before comparison\n- Supports mixed numeric types (e.g., integers with floats)\n- Works bidirectionally (image < number and number < image)","ref":"Vix.Operator.html#%3C=/2-type-handling"},{"type":"function","title":"Examples - Vix.Operator.<=/2","doc":"","ref":"Vix.Operator.html#%3C=/2-examples"},{"type":"function","title":"Examples - Vix.Operator.<=/2","doc":"","ref":"Vix.Operator.html#%3C=/2-examples"},{"type":"function","title":"Basic Image Comparison - Vix.Operator.<=/2","doc":"```elixir\n# Comparing two images\niex> img = Image.build_image!(2, 2, [10, 15]) <= Image.build_image!(2, 2, [5, 20])\niex> Image.shape(img)\n{2, 2, 2}\niex> Image.to_list!(img)\n[[[0, 255], [0, 255]], [[0, 255], [0, 255]]]\n```","ref":"Vix.Operator.html#%3C=/2-basic-image-comparison"},{"type":"function","title":"Checking All Pixels - Vix.Operator.<=/2","doc":"```elixir\n# Using all?/2 to verify if all pixels match condition\niex> img = Image.build_image!(2, 2, [5]) <= Image.build_image!(2, 2, [10])\niex> all?(img, true)\ntrue\n```","ref":"Vix.Operator.html#%3C=/2-checking-all-pixels"},{"type":"function","title":"Multi-band Image Operations - Vix.Operator.<=/2","doc":"```elixir\n# Different band count scenarios\niex> (Image.build_image!(10, 10, [10, 20, 30]) <= Image.build_image!(10, 10, [20, 30, 40])) |> all?(true)\ntrue\niex> (Image.build_image!(10, 10, [20]) <= Image.build_image!(10, 10, [10, 20, 30])) |> all?(true)\nfalse\niex> (Image.build_image!(10, 10, [1, 2, 3]) <= Image.build_image!(10, 10, [6])) |> all?(true)\ntrue\n```","ref":"Vix.Operator.html#%3C=/2-multi-band-image-operations"},{"type":"function","title":"Image vs. Number Comparison - Vix.Operator.<=/2","doc":"```elixir\n# Single number compared to all bands\niex> img = Image.build_image!(1, 2, [5, 10, 15]) <= 5\niex> Image.to_list!(img)\n[[[255, 0, 0]], [[255, 0, 0]]]\n\n# Comparing with integer\niex> (Image.build_image!(10, 10, [4]) <= 2) |> all?(true)\nfalse\n\n# Comparing with float\niex> (Image.build_image!(10, 10, [4]) <= 4.0) |> all?(true)\ntrue\n\n# List comparison with bands\niex> img = Image.build_image!(1, 1, [10, 20]) <= [20, 10]\niex> Image.to_list!(img)\n[[[255, 0]]]\n```","ref":"Vix.Operator.html#%3C=/2-image-vs-number-comparison"},{"type":"function","title":"Reverse Comparison - Vix.Operator.<=/2","doc":"```elixir\n# Float on the left side\niex> (4.0 <= Image.build_image!(10, 10, [5])) |> all?(true)\ntrue\n\n# List on the left side\niex> ([10, 20, 30] <= Image.build_image!(10, 10, [20, 30, 40])) |> all?(true)\ntrue\n```","ref":"Vix.Operator.html#%3C=/2-reverse-comparison"},{"type":"function","title":"Fallback Behavior - Vix.Operator.<=/2","doc":"```elixir\n# Standard Kernel.<= behavior when no images involved\niex> 4 <= 5\ntrue\n```","ref":"Vix.Operator.html#%3C=/2-fallback-behavior"},{"type":"function","title":"Vix.Operator.==/2","doc":"Performs Equal (==) comparison between Images and numbers, returning the result as an Image.","ref":"Vix.Operator.html#==/2"},{"type":"function","title":"Overview - Vix.Operator.==/2","doc":"The operator compares Images and numbers, with the result being an Image where:\n- `0` represents `false`\n- `255` represents `true`\n\nWhen neither argument is an image, the operation delegates to `Kernel.==/2`.","ref":"Vix.Operator.html#==/2-overview"},{"type":"function","title":"Behavior - Vix.Operator.==/2","doc":"","ref":"Vix.Operator.html#==/2-behavior"},{"type":"function","title":"Image Comparison Rules - Vix.Operator.==/2","doc":"- Single number: Applied to all image bands\n- List matching image bands: Each number maps to corresponding band\n- List size does not match bands: Creates multi-band output with either the image bands or the list is scaled up to match the other.\n- Two images: Uses `Operation.relational!(a, b, :VIPS_OPERATION_RELATIONAL_EQUAL)`. Bands are scaled up to match each other.","ref":"Vix.Operator.html#==/2-image-comparison-rules"},{"type":"function","title":"Type Handling - Vix.Operator.==/2","doc":"- Images are cast to the smallest common format before comparison\n- Supports mixed numeric types (e.g., integers with floats)\n- Works bidirectionally (image < number and number < image)","ref":"Vix.Operator.html#==/2-type-handling"},{"type":"function","title":"Examples - Vix.Operator.==/2","doc":"","ref":"Vix.Operator.html#==/2-examples"},{"type":"function","title":"Examples - Vix.Operator.==/2","doc":"","ref":"Vix.Operator.html#==/2-examples"},{"type":"function","title":"Basic Image Comparison - Vix.Operator.==/2","doc":"```elixir\n# Comparing two images\niex> img = Image.build_image!(2, 2, [10, 20]) == Image.build_image!(2, 2, [20, 20])\niex> Image.shape(img)\n{2, 2, 2}\niex> Image.to_list!(img)\n[[[0, 255], [0, 255]], [[0, 255], [0, 255]]]\n```","ref":"Vix.Operator.html#==/2-basic-image-comparison"},{"type":"function","title":"Checking All Pixels - Vix.Operator.==/2","doc":"```elixir\n# Using all?/2 to verify if all pixels match condition\niex> img = Image.build_image!(2, 2, [10]) == Image.build_image!(2, 2, [10])\niex> all?(img, true)\ntrue\n```","ref":"Vix.Operator.html#==/2-checking-all-pixels"},{"type":"function","title":"Multi-band Image Operations - Vix.Operator.==/2","doc":"```elixir\n# Equal values across all bands\niex> (Image.build_image!(10, 10, [10, 20, 30]) == Image.build_image!(10, 10, [10, 20, 30])) |> all?(true)\ntrue\n\n# Single vs multi-band comparison\niex> (Image.build_image!(10, 10, [20]) == Image.build_image!(10, 10, [10, 20, 30])) |> all?(true)\nfalse\n\n# Same value across all bands equals single-band image\niex> (Image.build_image!(10, 10, [10, 10, 10]) == Image.build_image!(10, 10, [10])) |> all?(true)\ntrue\n```","ref":"Vix.Operator.html#==/2-multi-band-image-operations"},{"type":"function","title":"Image vs. Number Comparison - Vix.Operator.==/2","doc":"```elixir\n# Single number compared to all bands\niex> img = Image.build_image!(1, 2, [5, 10, 20]) == 5\niex> Image.to_list!(img)\n[[[255, 0, 0]], [[255, 0, 0]]]\n\n# Non-matching comparison\niex> (Image.build_image!(10, 10, [10]) == 5) |> all?(true)\nfalse\n\n# Float comparison (type coercion)\niex> (Image.build_image!(10, 10, [10]) == 10.0) |> all?(true)\ntrue\n\n# List comparison with bands\niex> img = Image.build_image!(1, 1, [10, 20]) == [10, 10]\niex> Image.to_list!(img)\n[[[255, 0]]]\n```","ref":"Vix.Operator.html#==/2-image-vs-number-comparison"},{"type":"function","title":"Reverse Comparison - Vix.Operator.==/2","doc":"```elixir\n# Float on the left side\niex> (10.0 == Image.build_image!(10, 10, [10])) |> all?(true)\ntrue\n\n# List on the left side\niex> ([10, 20, 30] == Image.build_image!(10, 10, [10, 20, 30])) |> all?(true)\ntrue\n```","ref":"Vix.Operator.html#==/2-reverse-comparison"},{"type":"function","title":"Fallback Behavior - Vix.Operator.==/2","doc":"```elixir\n# Standard Kernel.== behavior when no images involved\niex> 4 == 4\ntrue\n```","ref":"Vix.Operator.html#==/2-fallback-behavior"},{"type":"function","title":"Vix.Operator.>/2","doc":"Performs Greater_than (>) comparison between Images and numbers, returning the result as an Image.","ref":"Vix.Operator.html#%3E/2"},{"type":"function","title":"Overview - Vix.Operator.>/2","doc":"The operator compares Images and numbers, with the result being an Image where:\n- `0` represents `false`\n- `255` represents `true`\n\nWhen neither argument is an image, the operation delegates to `Kernel.>/2`.","ref":"Vix.Operator.html#%3E/2-overview"},{"type":"function","title":"Behavior - Vix.Operator.>/2","doc":"","ref":"Vix.Operator.html#%3E/2-behavior"},{"type":"function","title":"Image Comparison Rules - Vix.Operator.>/2","doc":"- Single number: Applied to all image bands\n- List matching image bands: Each number maps to corresponding band\n- List size does not match bands: Creates multi-band output with either the image bands or the list is scaled up to match the other.\n- Two images: Uses `Operation.relational!(a, b, :VIPS_OPERATION_RELATIONAL_MORE)`. Bands are scaled up to match each other.","ref":"Vix.Operator.html#%3E/2-image-comparison-rules"},{"type":"function","title":"Type Handling - Vix.Operator.>/2","doc":"- Images are cast to the smallest common format before comparison\n- Supports mixed numeric types (e.g., integers with floats)\n- Works bidirectionally (image < number and number < image)","ref":"Vix.Operator.html#%3E/2-type-handling"},{"type":"function","title":"Examples - Vix.Operator.>/2","doc":"","ref":"Vix.Operator.html#%3E/2-examples"},{"type":"function","title":"Examples - Vix.Operator.>/2","doc":"","ref":"Vix.Operator.html#%3E/2-examples"},{"type":"function","title":"Basic Image Comparison - Vix.Operator.>/2","doc":"```elixir\n# Comparing two images\niex> img = Image.build_image!(2, 2, [10, 15]) > Image.build_image!(2, 2, [5, 20])\niex> Image.shape(img)\n{2, 2, 2}\niex> Image.to_list!(img)\n[[[255, 0], [255, 0]], [[255, 0], [255, 0]]]\n```","ref":"Vix.Operator.html#%3E/2-basic-image-comparison"},{"type":"function","title":"Checking All Pixels - Vix.Operator.>/2","doc":"```elixir\n# Using all?/2 to verify if all pixels match condition\niex> img = Image.build_image!(2, 2, [10]) > Image.build_image!(2, 2, [5])\niex> all?(img, true)\ntrue\n```","ref":"Vix.Operator.html#%3E/2-checking-all-pixels"},{"type":"function","title":"Multi-band Image Operations - Vix.Operator.>/2","doc":"```elixir\n# Equal values comparison\niex> (Image.build_image!(10, 10, [10, 20, 30]) > Image.build_image!(10, 10, [10, 20, 30])) |> all?(true)\nfalse\n\n# Multi-band vs single-band comparison\niex> (Image.build_image!(10, 10, [10]) > Image.build_image!(10, 10, [20, 30, 40])) |> all?(true)\nfalse\n\n# Comparing with smaller value\niex> (Image.build_image!(10, 10, [10, 20, 30]) > Image.build_image!(10, 10, [5])) |> all?(true)\ntrue\n```","ref":"Vix.Operator.html#%3E/2-multi-band-image-operations"},{"type":"function","title":"Image vs. Number Comparison - Vix.Operator.>/2","doc":"```elixir\n# Single number compared to all bands\niex> img = Image.build_image!(1, 2, [5, 15, 25]) > 20\niex> Image.to_list!(img)\n[[[0, 0, 255]], [[0, 0, 255]]]\n\n# Comparing with integer\niex> (Image.build_image!(10, 10, [10]) > 20) |> all?(true)\nfalse\n\n# Comparing with float\niex> (Image.build_image!(10, 10, [20]) > 10.0) |> all?(true)\ntrue\n\n# List comparison with bands\niex> img = Image.build_image!(1, 1, [10, 20]) > [20, 10]\niex> Image.to_list!(img)\n[[[0, 255]]]\n```","ref":"Vix.Operator.html#%3E/2-image-vs-number-comparison"},{"type":"function","title":"Reverse Comparison - Vix.Operator.>/2","doc":"```elixir\n# Float on the left side\niex> (5.0 > Image.build_image!(10, 10, [4])) |> all?(true)\ntrue\n\n# List on the left side\niex> ([20, 30, 40] > Image.build_image!(10, 10, [10, 20, 30])) |> all?(true)\ntrue\n```","ref":"Vix.Operator.html#%3E/2-reverse-comparison"},{"type":"function","title":"Fallback Behavior - Vix.Operator.>/2","doc":"```elixir\n# Standard Kernel.> behavior when no images involved\niex> 5 > 4\ntrue\n```","ref":"Vix.Operator.html#%3E/2-fallback-behavior"},{"type":"function","title":"Vix.Operator.>=/2","doc":"Performs Greater_than_equal (>=) comparison between Images and numbers, returning the result as an Image.","ref":"Vix.Operator.html#%3E=/2"},{"type":"function","title":"Overview - Vix.Operator.>=/2","doc":"The operator compares Images and numbers, with the result being an Image where:\n- `0` represents `false`\n- `255` represents `true`\n\nWhen neither argument is an image, the operation delegates to `Kernel.>=/2`.","ref":"Vix.Operator.html#%3E=/2-overview"},{"type":"function","title":"Behavior - Vix.Operator.>=/2","doc":"","ref":"Vix.Operator.html#%3E=/2-behavior"},{"type":"function","title":"Image Comparison Rules - Vix.Operator.>=/2","doc":"- Single number: Applied to all image bands\n- List matching image bands: Each number maps to corresponding band\n- List size does not match bands: Creates multi-band output with either the image bands or the list is scaled up to match the other.\n- Two images: Uses `Operation.relational!(a, b, :VIPS_OPERATION_RELATIONAL_MOREEQ)`. Bands are scaled up to match each other.","ref":"Vix.Operator.html#%3E=/2-image-comparison-rules"},{"type":"function","title":"Type Handling - Vix.Operator.>=/2","doc":"- Images are cast to the smallest common format before comparison\n- Supports mixed numeric types (e.g., integers with floats)\n- Works bidirectionally (image < number and number < image)","ref":"Vix.Operator.html#%3E=/2-type-handling"},{"type":"function","title":"Examples - Vix.Operator.>=/2","doc":"","ref":"Vix.Operator.html#%3E=/2-examples"},{"type":"function","title":"Examples - Vix.Operator.>=/2","doc":"","ref":"Vix.Operator.html#%3E=/2-examples"},{"type":"function","title":"Basic Image Comparison - Vix.Operator.>=/2","doc":"```elixir\n# Comparing two images\niex> img = Image.build_image!(2, 2, [10, 15]) >= Image.build_image!(2, 2, [5, 20])\niex> Image.shape(img)\n{2, 2, 2}\niex> Image.to_list!(img)\n[[[255, 0], [255, 0]], [[255, 0], [255, 0]]]\n```","ref":"Vix.Operator.html#%3E=/2-basic-image-comparison"},{"type":"function","title":"Checking All Pixels - Vix.Operator.>=/2","doc":"```elixir\n# Using all?/2 to verify if all pixels match condition\niex> img = Image.build_image!(2, 2, [10]) >= Image.build_image!(2, 2, [5])\niex> all?(img, true)\ntrue\n```","ref":"Vix.Operator.html#%3E=/2-checking-all-pixels"},{"type":"function","title":"Multi-band Image Operations - Vix.Operator.>=/2","doc":"```elixir\n# Greater values comparison\niex> (Image.build_image!(10, 10, [20, 30, 40]) >= Image.build_image!(10, 10, [10, 20, 30])) |> all?(true)\ntrue\n\n# Equal values comparison\niex> (Image.build_image!(10, 10, [10, 20, 30]) >= Image.build_image!(10, 10, [10, 20, 30])) |> all?(true)\ntrue\n\n# Single vs multi-band comparison\niex> (Image.build_image!(10, 10, [20]) >= Image.build_image!(10, 10, [10, 20, 30])) |> all?(true)\nfalse\n\n# Multi vs single-band comparison\niex> (Image.build_image!(10, 10, [10, 20, 30]) >= Image.build_image!(10, 10, [10])) |> all?(true)\ntrue\n```","ref":"Vix.Operator.html#%3E=/2-multi-band-image-operations"},{"type":"function","title":"Image vs. Number Comparison - Vix.Operator.>=/2","doc":"```elixir\n# Single number compared to all bands\niex> img = Image.build_image!(1, 2, [5, 10, 15]) >= 10\niex> Image.to_list!(img)\n[[[0, 255, 255]], [[0, 255, 255]]]\n\n# Comparing with larger number\niex> (Image.build_image!(10, 10, [10]) >= 20) |> all?(true)\nfalse\n\n# Comparing with float\niex> (Image.build_image!(10, 10, [20]) >= 10.0) |> all?(true)\ntrue\n\n# List comparison with bands\niex> img = Image.build_image!(1, 1, [10, 20]) >= [20, 10]\niex> Image.to_list!(img)\n[[[0, 255]]]\n```","ref":"Vix.Operator.html#%3E=/2-image-vs-number-comparison"},{"type":"function","title":"Reverse Comparison - Vix.Operator.>=/2","doc":"```elixir\n# Float on the left side\niex> (10.0 >= Image.build_image!(10, 10, [5])) |> all?(true)\ntrue\n\n# List on the left side\niex> ([20, 30, 40] >= Image.build_image!(10, 10, [10, 20, 30])) |> all?(true)\ntrue\n```","ref":"Vix.Operator.html#%3E=/2-reverse-comparison"},{"type":"function","title":"Fallback Behavior - Vix.Operator.>=/2","doc":"```elixir\n# Standard Kernel.>= behavior when no images involved\niex> 5 >= 4\ntrue\n```","ref":"Vix.Operator.html#%3E=/2-fallback-behavior"},{"type":"function","title":"Vix.Operator.all?/2","doc":"Checks if all of the values are \"true\" (255) or \"false\" (0).\nUseful together with relational operators.","ref":"Vix.Operator.html#all?/2"},{"type":"function","title":"Examples - Vix.Operator.all?/2","doc":"Check if two images are equal\n\n```elixir\niex> all?(Image.build_image!(10, 20, [255, 255, 255]), true)\ntrue\niex> img = (Image.build_image!(10, 20, [50, 100, 150]) == Image.build_image!(10, 20, [50, 100, 150]))\niex> all?(img, true)\ntrue\niex> img = (Image.build_image!(10, 20, [100, 150, 200])   all?(img, true)\nfalse\niex> all?(img, false)\ntrue\n```","ref":"Vix.Operator.html#all?/2-examples"},{"type":"function","title":"Vix.Operator.xor/2","doc":"Performs Bitwise Boolean XOR Operation (xor) between Images and numbers, returning the result as an Image.","ref":"Vix.Operator.html#xor/2"},{"type":"function","title":"Overview - Vix.Operator.xor/2","doc":"The operation handles various input combinations:\n\n* Image xor Image\n* Image xor number(s)\n* number(s) xor Image","ref":"Vix.Operator.html#xor/2-overview"},{"type":"function","title":"Input Handling - Vix.Operator.xor/2","doc":"Values are cast up before operations. Float values are converted to integers","ref":"Vix.Operator.html#xor/2-input-handling"},{"type":"function","title":"Number Inputs - Vix.Operator.xor/2","doc":"- Single number: Applied to all image bands uniformly\n- Number list:\n  - If list size matches image bands: Each number applies to its respective band\n  - If list size does not match the image bands: Either the image bands or the list is scaled up to match the other.","ref":"Vix.Operator.html#xor/2-number-inputs"},{"type":"function","title":"Image Inputs - Vix.Operator.xor/2","doc":"- When both inputs are images: Uses `Operation.boolean!(a, b, :VIPS_OPERATION_BOOLEAN_EOR)`\n\n\n# Examples","ref":"Vix.Operator.html#xor/2-image-inputs"},{"type":"function","title":"Image XOR Image Operations - Vix.Operator.xor/2","doc":"```elixir\niex> img = xor(Image.build_image!(2, 1, [0, 255, 0]), Image.build_image!(2, 1, [0, 255, 255]))\niex> Image.shape(img)\n{2, 1, 3}\niex> Image.to_list!(img)\n[[[0, 0, 255], [0, 0, 255]]]\n\n# Identical Images\niex> xor(Image.build_image!(2, 2, [2, 4, 8]), Image.build_image!(2, 2, [2, 4, 8])) |> Image.to_list!()\n[[[0, 0, 0], [0, 0, 0]], [[0, 0, 0], [0, 0, 0]]]\n\n# Different dimensions\niex> img = xor(Image.build_image!(1, 1, [2]), Image.build_image!(1, 2, [2, 4, 8]))\niex> Image.shape(img)\n{1, 2, 3}\niex> Image.to_list!(img)\n[[[0, 6, 10]], [[2, 4, 8]]]\n```","ref":"Vix.Operator.html#xor/2-image-xor-image-operations"},{"type":"function","title":"Image XOR Number Operations - Vix.Operator.xor/2","doc":"```elixir\n# Single number comparison (applies to all bands)\niex> xor(Image.build_image!(1, 2, [2, 5, 3]), 6) |> Image.to_list!()\n[[[4, 3, 5]], [[4, 3, 5]]]\n\n# Float Comparison\niex> xor(Image.build_image!(1, 1, [10]), 6.0) |> Image.to_list!()\n[[[12]]]\n\n# List comparison (band-wise)\niex> xor(Image.build_image!(1, 1, [2, 2]), [1, 3]) |> Image.to_list!()\n[[[3, 1]]]\n```","ref":"Vix.Operator.html#xor/2-image-xor-number-operations"},{"type":"function","title":"Reverse Operations - Vix.Operator.xor/2","doc":"```elixir\n# Number XOR Image\niex> xor(10.0, Image.build_image!(1, 1, [5])) |> Image.to_list!()\n[[[15]]]\n\n# List XOR Image\niex> xor([2, 2], Image.build_image!(1, 1, [1, 3])) |> Image.to_list!()\n[[[3, 1]]]\n```","ref":"Vix.Operator.html#xor/2-reverse-operations"},{"type":"function","title":"Vix.Operator.||/2","doc":"Performs Bitwise Boolean OR Operation (||) between Images and numbers, returning the result as an Image.","ref":"Vix.Operator.html#%7C%7C/2"},{"type":"function","title":"Overview - Vix.Operator.||/2","doc":"The operation handles various input combinations:\n\n* Image || Image\n* Image || number(s)\n* number(s) || Image\n* non-Image values (falls back to `Kernel`)","ref":"Vix.Operator.html#%7C%7C/2-overview"},{"type":"function","title":"Input Handling - Vix.Operator.||/2","doc":"Values are cast up before operations. Float values are converted to integers","ref":"Vix.Operator.html#%7C%7C/2-input-handling"},{"type":"function","title":"Number Inputs - Vix.Operator.||/2","doc":"- Single number: Applied to all image bands uniformly\n- Number list:\n  - If list size matches image bands: Each number applies to its respective band\n  - If list size does not match the image bands: Either the image bands or the list is scaled up to match the other.","ref":"Vix.Operator.html#%7C%7C/2-number-inputs"},{"type":"function","title":"Image Inputs - Vix.Operator.||/2","doc":"- When both inputs are images: Uses `Operation.boolean!(a, b, :VIPS_OPERATION_BOOLEAN_OR)`\n\n\n# Examples","ref":"Vix.Operator.html#%7C%7C/2-image-inputs"},{"type":"function","title":"Image || Image Operations - Vix.Operator.||/2","doc":"```elixir\niex> img = Image.build_image!(2, 1, [0, 255, 0]) || Image.build_image!(2, 1, [0, 255, 255])\niex> Image.shape(img)\n{2, 1, 3}\niex> Image.to_list!(img)\n[[[0, 255, 255], [0, 255, 255]]]\n\n# Identical Images\niex> (Image.build_image!(2, 2, [2, 4, 8]) || Image.build_image!(2, 2, [2, 4, 8])) |> Image.to_list!()\n[[[2, 4, 8], [2, 4, 8]], [[2, 4, 8], [2, 4, 8]]]\n\n# Different dimensions\niex> img = Image.build_image!(1, 1, [2]) || Image.build_image!(1, 2, [2, 4, 8])\niex> Image.shape(img)\n{1, 2, 3}\niex> Image.to_list!(img)\n[[[2, 6, 10]], [[2, 4, 8]]]\n```","ref":"Vix.Operator.html#%7C%7C/2-image-image-operations"},{"type":"function","title":"Image || Number Operations - Vix.Operator.||/2","doc":"```elixir\n# Single number comparison (applies to all bands)\niex> (Image.build_image!(1, 2, [2, 4, 8]) || 4) |> Image.to_list!()\n[[[6, 4, 12]], [[6, 4, 12]]]\n\n# Float Comparison\niex> (Image.build_image!(1, 1, [4]) || 2.0) |> Image.to_list!()\n[[[6]]]\n\n# List comparison (band-wise)\niex> (Image.build_image!(1, 1, [2, 2]) || [1, 3]) |> Image.to_list!()\n[[[3, 3]]]\n```","ref":"Vix.Operator.html#%7C%7C/2-image-number-operations"},{"type":"function","title":"Reverse Operations - Vix.Operator.||/2","doc":"```elixir\n# Number || Image\niex> (4.0 || Image.build_image!(1, 1, [2])) |> Image.to_list!()\n[[[6]]]\n\n# List || Image\niex> ([2, 2] || Image.build_image!(1, 1, [1, 3])) |> Image.to_list!()\n[[[3, 3]]]\n```","ref":"Vix.Operator.html#%7C%7C/2-reverse-operations"},{"type":"function","title":"Kernel Fallback - Vix.Operator.||/2","doc":"```elixir\n# When neither argument is an image\niex> false || true\ntrue\n```","ref":"Vix.Operator.html#%7C%7C/2-kernel-fallback"},{"type":"module","title":"Vix.Tensor","doc":"Struct to hold raw pixel data returned by the libvips along with metadata about the binary.\n\nUseful for interoperability between other libraries like [Nx](https://hexdocs.pm/nx/Nx.html), [Evision](https://github.com/cocoa-xu/evision/).\n\nSee `Vix.Vips.Image.write_to_tensor/1` to convert an vix image to tensor.","ref":"Vix.Tensor.html"},{"type":"type","title":"Vix.Tensor.t/0","doc":"Struct to hold raw pixel data returned by the Libvips along with metadata about the binary.\n\n`:names` will always be `[:height, :width, :bands]`","ref":"Vix.Tensor.html#t:t/0"},{"type":"type","title":"Vix.Tensor.tensor_type/0","doc":"Type of the image pixel when image is represented as Tensor.\n\nThis type is useful for interoperability between different libraries. Type value is same as [`Nx.Type.t()`](https://hexdocs.pm/nx/Nx.Type.html)","ref":"Vix.Tensor.html#t:tensor_type/0"},{"type":"function","title":"Vix.Tensor.type/1","doc":"Convert Vix image pixel format to [Nx tensor type](https://hexdocs.pm/nx/Nx.Type.html#t:t/0)\n\nVix internally uses [libvips image\nformat](https://www.libvips.org/API/current/VipsImage.html#VipsBandFormat). To\nease the interoperability between Vix and other elixir libraries, we\ncan use this function.","ref":"Vix.Tensor.html#type/1"},{"type":"module","title":"Vix.Vips","doc":"Module for Vix.Vips.","ref":"Vix.Vips.html"},{"type":"function","title":"Vix.Vips.cache_get_max/0","doc":"Get the maximum number of operations we keep in cache.","ref":"Vix.Vips.html#cache_get_max/0"},{"type":"function","title":"Vix.Vips.cache_get_max_files/0","doc":"Get the maximum number of tracked files we allow before we start dropping cached operations.\n\nlibvips only tracks file descriptors it allocates, it can't track ones allocated by external libraries.","ref":"Vix.Vips.html#cache_get_max_files/0"},{"type":"function","title":"Vix.Vips.cache_get_max_mem/0","doc":"Get the maximum amount of tracked memory we allow before we start dropping cached operations.","ref":"Vix.Vips.html#cache_get_max_mem/0"},{"type":"function","title":"Vix.Vips.cache_set_max/1","doc":"Set the maximum number of operations we keep in cache.","ref":"Vix.Vips.html#cache_set_max/1"},{"type":"function","title":"Vix.Vips.cache_set_max_files/1","doc":"Set the maximum number of tracked files we allow before we start dropping cached operations.","ref":"Vix.Vips.html#cache_set_max_files/1"},{"type":"function","title":"Vix.Vips.cache_set_max_mem/1","doc":"Set the maximum amount of tracked memory we allow before we start dropping cached operations.\n\nlibvips only tracks file descriptors it allocates, it can't track ones allocated by external libraries.","ref":"Vix.Vips.html#cache_set_max_mem/1"},{"type":"function","title":"Vix.Vips.concurrency_get/0","doc":"Returns the number of worker threads that vips should use when running a VipsThreadPool.\n\nThe final value is clipped to the range 1 - 1024.","ref":"Vix.Vips.html#concurrency_get/0"},{"type":"function","title":"Vix.Vips.concurrency_set/1","doc":"Sets the number of worker threads that vips should use when running a VipsThreadPool.\n\nThe special value 0 means \"default\". In this case, the number of threads is set by the environment variable VIPS_CONCURRENCY, or if that is not set, the number of threads available on the host machine.","ref":"Vix.Vips.html#concurrency_set/1"},{"type":"function","title":"Vix.Vips.set_vips_leak_checking/1","doc":"Turn on or off vips leak checking","ref":"Vix.Vips.html#set_vips_leak_checking/1"},{"type":"function","title":"Vix.Vips.tracked_get_mem/0","doc":"Returns the number of bytes currently allocated by libvips.\n\nLibvips uses this figure to decide when to start dropping cache.","ref":"Vix.Vips.html#tracked_get_mem/0"},{"type":"function","title":"Vix.Vips.tracked_get_mem_highwater/0","doc":"Returns the largest number of bytes simultaneously allocated via libvips.\n\nHandy for estimating max memory requirements for a program.","ref":"Vix.Vips.html#tracked_get_mem_highwater/0"},{"type":"function","title":"Vix.Vips.version/0","doc":"Get installed vips version","ref":"Vix.Vips.html#version/0"},{"type":"module","title":"Vix.Vips.Image","doc":"Primary module for reading and writing image and image metadata.\n\nThis module allows you to read, write, manipulate and analyze images efficiently using the powerful\nlibvips image processing library. It offers operations like loading images, accessing metadata,\nand extracting image bands.","ref":"Vix.Vips.Image.html"},{"type":"module","title":"Basic Usage - Vix.Vips.Image","doc":"# Load an image from file\n    {:ok, image} = Image.new_from_file(\"path/to/image.jpg\")\n\n    # Create a new RGB image\n    {:ok, blank} = Image.build_image(width, height, [0, 0, 0])","ref":"Vix.Vips.Image.html#module-basic-usage"},{"type":"module","title":"Access Syntax (Image Slicing) - Vix.Vips.Image","doc":"The module implements Elixir's Access behavior, providing an intuitive way to slice and extract\nimage data across three dimensions: width, height, and bands (color channels).","ref":"Vix.Vips.Image.html#module-access-syntax-image-slicing"},{"type":"module","title":"Band Extraction - Vix.Vips.Image","doc":"Access individual color bands using integer indices:\n\n    # Get the red channel from an RGB image\n    red_channel = image[0]\n\n    # Get the alpha channel (last band) from an RGBA image\n    alpha = image[-1]","ref":"Vix.Vips.Image.html#module-band-extraction"},{"type":"module","title":"Band Ranges - Vix.Vips.Image","doc":"Extract multiple consecutive bands using ranges:\n\n    # Get red and green channels from RGB\n    red_green = image[0..1]\n\n    # Get all channels.\n    all_channels = image[0..-1//1]\n    # Same as `all_channels = image`","ref":"Vix.Vips.Image.html#module-band-ranges"},{"type":"module","title":"Dimensional Slicing - Vix.Vips.Image","doc":"Slice images across multiple dimensions using lists of the form [width, height, bands]:\n\n    # Get a 100x100 pixel square from the top-left corner\n    top_left = image[[0..99, 0..99]]\n\n    # Get the bottom-right 50x50 pixel square\n    bottom_right = image[[-50..-1, -50..-1]]\n\n    # Get the bottom-right 50x50 pixel square, and only green channel\n    bottom_right = image[[-50..-1, -50..-1, 1]]","ref":"Vix.Vips.Image.html#module-dimensional-slicing"},{"type":"module","title":"Named Dimension Access - Vix.Vips.Image","doc":"Use keyword lists for more explicit dimension specification:\n\n    # Get first 200 pixels in width, maintaining full height and bands\n    slice = image[[width: 0..199]]\n\n    # Get specific height range with all bands\n    middle = image[[height: 100..299]]\n\n    # Extract specific band\n    green = image[[band: 1]]\n\n    # Get a 100x100 pixel square from the top-left corner, and only red-green channels\n    bottom_right = image[[width: 0..99, height: 0..99, band: 0..1]]\n\nSee `Vix.Vips.Operation` for available image processing operations.","ref":"Vix.Vips.Image.html#module-named-dimension-access"},{"type":"function","title":"Vix.Vips.Image.bands/1","doc":"Get \"bands\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-bands) for more details regarding `bands` function","ref":"Vix.Vips.Image.html#bands/1"},{"type":"function","title":"Vix.Vips.Image.build_image/4","doc":"Creates a new image with specified dimensions and background values.\n\nTakes width, height, and a list of background values to create a new image. The background values\ndetermine both the number of bands and initial pixel values.","ref":"Vix.Vips.Image.html#build_image/4"},{"type":"function","title":"Parameters - Vix.Vips.Image.build_image/4","doc":"* `width` - Width of the image in pixels (positive integer)\n  * `height` - Height of the image in pixels (positive integer)\n  * `background` - List of numbers representing initial pixel values for each band. Defaults to [0, 0, 0]\n  * `opts` - Keyword list of options","ref":"Vix.Vips.Image.html#build_image/4-parameters"},{"type":"function","title":"Options - Vix.Vips.Image.build_image/4","doc":"* `:interpretation` - Color space interpretation. Can be a valid `vips_interpretation` or `:auto`.\n     When `:auto`, determined by number of bands:\n     * 1 band -> `:VIPS_INTERPRETATION_B_W`\n     * 3 bands -> `:VIPS_INTERPRETATION_RGB`\n     * 4 bands -> `:VIPS_INTERPRETATION_sRGB`\n     * other -> `:VIPS_INTERPRETATION_MULTIBAND`\n\n  * `:format` - Pixel value format. Can be a valid vips_format or `:auto`.\n     When `:auto`, determined by value ranges. For example:\n     * 0-255 -> `:VIPS_FORMAT_UCHAR`\n     * decimal values -> `:VIPS_FORMAT_DOUBLE`\n     * larger integers -> `:VIPS_FORMAT_INT`","ref":"Vix.Vips.Image.html#build_image/4-options"},{"type":"function","title":"Examples - Vix.Vips.Image.build_image/4","doc":"```elixir\niex> {:ok, %Image{ref: _} = img} = Image.build_image(1, 2, [10])\niex> Image.to_list(img)\n{:ok, [[[10]], [[10]]]}\niex> Image.shape(img)\n{1, 2, 1}\n```\n\nSets the interpretation based on the bands\n\n```elixir\niex> {:ok, img} = Image.build_image(1, 2, [10])\niex> Image.interpretation(img)\n:VIPS_INTERPRETATION_B_W\niex> {:ok, img} = Image.build_image(10, 10, [10, 10, 10])\niex> Image.interpretation(img)\n:VIPS_INTERPRETATION_RGB\niex> {:ok, img} = Image.build_image(10, 10, [10, 10, 10, 10])\niex> Image.interpretation(img)\n:VIPS_INTERPRETATION_sRGB\niex> {:ok, img} = Image.build_image(10, 10, [10, 10, 10, 10], interpretation: :VIPS_INTERPRETATION_MULTIBAND)\niex> Image.interpretation(img)\n:VIPS_INTERPRETATION_MULTIBAND\n```\n\nSets the band format based on the values\n\n```elixir\niex> {:ok, img} = Image.build_image(1, 2, [10, 9, 220])\niex> Image.format(img)\n:VIPS_FORMAT_UCHAR\niex> {:ok, img} = Image.build_image(10, 10, [10, -120, 200])\niex> Image.format(img)\n:VIPS_FORMAT_SHORT\niex> {:ok, img} = Image.build_image(10, 10, [10, -120, 1.0])\niex> Image.format(img)\n:VIPS_FORMAT_DOUBLE\niex> {:ok, img} = Image.build_image(10, 10, [10, -40000, 39])\niex> Image.format(img)\n:VIPS_FORMAT_INT\niex> {:ok, img} = Image.build_image(10, 10, [10, -80, 10], format: :VIPS_FORMAT_CHAR)\niex> Image.format(img)\n:VIPS_FORMAT_CHAR\n```","ref":"Vix.Vips.Image.html#build_image/4-examples"},{"type":"function","title":"Vix.Vips.Image.build_image!/3","doc":"Creates a new image with specified dimensions and background values.\n\nSimilar to `build_image/4` but raises `Image.Error` on failure instead of returning error tuple.","ref":"Vix.Vips.Image.html#build_image!/3"},{"type":"function","title":"Examples - Vix.Vips.Image.build_image!/3","doc":"```elixir\niex> img = Image.build_image!(1, 2, [10])\niex> Image.to_list(img)\n{:ok, [[[10]], [[10]]]}\niex> Image.shape(img)\n{1, 2, 1}\n```\n\nSee `build_image/4` for detailed documentation.","ref":"Vix.Vips.Image.html#build_image!/3-examples"},{"type":"function","title":"Vix.Vips.Image.coding/1","doc":"Get \"coding\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-coding) for more details regarding `coding` function","ref":"Vix.Vips.Image.html#coding/1"},{"type":"function","title":"Vix.Vips.Image.fetch/2","doc":"Extracts a band from an image using Access syntax.\n\nThis function implements the Access behaviour for images, enabling array-like\nsyntax for extracting bands and slices. See the module documentation for\ndetailed examples of Access syntax usage.","ref":"Vix.Vips.Image.html#fetch/2"},{"type":"function","title":"Parameters - Vix.Vips.Image.fetch/2","doc":"* `image` - The source image\n  * `band` - Integer index, Range, or list specifying what to extract","ref":"Vix.Vips.Image.html#fetch/2-parameters"},{"type":"function","title":"Returns - Vix.Vips.Image.fetch/2","doc":"* `{:ok, image}` with extracted data\n  * Raises ArgumentError for invalid access patterns\n\nAccess is read-only - `get_and_update/3` and `pop/2` are not supported.","ref":"Vix.Vips.Image.html#fetch/2-returns"},{"type":"function","title":"Examples - Vix.Vips.Image.fetch/2","doc":"# Get red channel\n    {:ok, red} = Image.fetch(rgb_image, 0)\n\n    # Get first two channels\n    {:ok, rg} = Image.fetch(rgb_image, 0..1)\n\n    # Get 100x100 region from top-left\n    {:ok, region} = Image.fetch(image, [0..99, 0..99])\n\n    # Get specific height range\n    {:ok, slice} = Image.fetch(image, [height: 100..199])\n\nSee `Vix.Vips.Image` module docs for more details","ref":"Vix.Vips.Image.html#fetch/2-examples"},{"type":"function","title":"Vix.Vips.Image.filename/1","doc":"Get \"filename\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-filename) for more details regarding `filename` function","ref":"Vix.Vips.Image.html#filename/1"},{"type":"function","title":"Vix.Vips.Image.format/1","doc":"Get \"format\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-format) for more details regarding `format` function","ref":"Vix.Vips.Image.html#format/1"},{"type":"function","title":"Vix.Vips.Image.get_pixel/3","doc":"Returns the pixel value for the passed position\n\nPixel value is a list of numbers. Size of the list depends on the\nnumber of bands in the image and number type will depend on the\nband format (see: `t:Vix.Vips.Operation.vips_band_format/0`).\n\nFor example for RGBA image with unsigned char band format the\nreturn value will be a list of integer of size 4.\n\nThis function is similar to `Vix.Vips.Operation.getpoint/3`,\ngetpoint always returns the value as `float` but get_pixel returns\nbased on the image band format.\n\n> #### Caution {: .warning}\n> Loop through lot of pixels using `get_pixel` can be expensive.\n> Use `extract_area` or Access syntax (slicing) instead","ref":"Vix.Vips.Image.html#get_pixel/3"},{"type":"function","title":"Vix.Vips.Image.get_pixel!/3","doc":"Same as `get_pixel/3`. Returns the pixel value on success or raise the error.","ref":"Vix.Vips.Image.html#get_pixel!/3"},{"type":"function","title":"Vix.Vips.Image.has_alpha?/1","doc":"Return a boolean indicating if an image has an alpha band.\n\nExample\n\n```elixir\n  {:ok, im} = Image.new_from_file(\"puppies.jpg\")\n\n  has_alpha? = Image.has_alpha?(im)\n```","ref":"Vix.Vips.Image.html#has_alpha?/1"},{"type":"function","title":"Vix.Vips.Image.header_field_names/1","doc":"Get all image header field names.\n\nSee https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-fields for more details","ref":"Vix.Vips.Image.html#header_field_names/1"},{"type":"function","title":"Vix.Vips.Image.header_value/2","doc":"Get image header value.\n\nThis is a generic function to get header value.\n\nCasts the value to appropriate type. Returned value can be integer, float, string, binary, list. Use `Vix.Vips.Image.header_value_as_string/2` to get string representation of any header value.\n\n```elixir\n{:ok, width} = Image.header_value(vips_image, \"width\")\n```","ref":"Vix.Vips.Image.html#header_value/2"},{"type":"function","title":"Vix.Vips.Image.header_value_as_string/2","doc":"Get image header value as string.\n\nThis is generic method to get string representation of a header value. If value is VipsBlob, then it returns base64 encoded data.\n\nSee: https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-as-string","ref":"Vix.Vips.Image.html#header_value_as_string/2"},{"type":"function","title":"Vix.Vips.Image.headers/1","doc":"Get all image header data as map. Headers includes metadata such as image height, width, bands.\n\nIf a header does not exists then value for that header will be set to `nil`.\n\nSee https://libvips.github.io/libvips/API/current/libvips-header.html for more details.","ref":"Vix.Vips.Image.html#headers/1"},{"type":"function","title":"Vix.Vips.Image.height/1","doc":"Get \"height\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-height) for more details regarding `height` function","ref":"Vix.Vips.Image.html#height/1"},{"type":"function","title":"Vix.Vips.Image.interpretation/1","doc":"Get \"interpretation\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-interpretation) for more details regarding `interpretation` function","ref":"Vix.Vips.Image.html#interpretation/1"},{"type":"function","title":"Vix.Vips.Image.mode/1","doc":"Get \"mode\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-mode) for more details regarding `mode` function","ref":"Vix.Vips.Image.html#mode/1"},{"type":"function","title":"Vix.Vips.Image.mutate/2","doc":"Mutate an image in-place. You have to pass a function which takes MutableImage as argument. Inside the callback function, you can call functions which modify the image, such as setting or removing metadata. See `Vix.Vips.MutableImage`\n\nReturn value of the callback must be one of:\n\n* The mutated image passed to the callback or\n* `:ok` or\n* `{:ok, some_result}`\n\nCall returns updated image.\n\nExample\n\n```elixir\n  {:ok, im} = Image.new_from_file(\"puppies.jpg\")\n\n  {:ok, new_im} =\n    Image.mutate(im, fn mut_image ->\n      :ok = MutableImage.update(mut_image, \"orientation\", 0)\n      :ok = MutableImage.set(mut_image, \"new-field\", :gint, 0)\n    end)\n```","ref":"Vix.Vips.Image.html#mutate/2"},{"type":"function","title":"Vix.Vips.Image.n_pages/1","doc":"Get \"n-pages\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-n-pages) for more details regarding `n_pages` function","ref":"Vix.Vips.Image.html#n_pages/1"},{"type":"function","title":"Vix.Vips.Image.new_from_binary/5","doc":"Creates a new image from raw pixel data with zero-copy performance.\n\nThis function wraps raw pixel data without copying, making it highly efficient for\nintegrating with other imaging libraries or processing pipelines. It's particularly\nuseful when working with raw pixel data from libraries like [`eVision`](https://github.com/cocoa-xu/evision) or\n[`Nx`](https://github.com/elixir-nx/).","ref":"Vix.Vips.Image.html#new_from_binary/5"},{"type":"function","title":"Parameters - Vix.Vips.Image.new_from_binary/5","doc":"* `bin` - Binary containing raw pixel data in left-to-right, top-to-bottom order\n* `width` - Image width in pixels\n* `height` - Image height in pixels\n* `bands` - Number of bands per pixel (e.g., 3 for RGB, 4 for RGBA)\n* `band_format` - Format of each band (typically `:VIPS_FORMAT_UCHAR`)","ref":"Vix.Vips.Image.html#new_from_binary/5-parameters"},{"type":"function","title":"Endianness Requirements - Vix.Vips.Image.new_from_binary/5","doc":"The binary data MUST be in native endianness. When using bitstring syntax, always\nspecify the `native` modifier:\n\n    # Correct - using native endianness\n    < >\n\n    # Incorrect - default big endian\n    < >\n\nSee [Elixir docs](https://hexdocs.pm/elixir/Kernel.SpecialForms.html#%3C%3C%3E%3E/1-endianness)\nfor more details.","ref":"Vix.Vips.Image.html#new_from_binary/5-endianness-requirements"},{"type":"function","title":"Examples - Vix.Vips.Image.new_from_binary/5","doc":"Creating an RGB image from raw pixel data\n\n```elixir\npixels = <<\n  255, 0, 0,    # Red pixel\n  0, 255, 0,    # Green pixel\n  0, 0, 255     # Blue pixel\n>>\n{:ok, image} = Image.new_from_binary(pixels, 3, 1, 3, :VIPS_FORMAT_UCHAR)\n```\n\nWorking with grayscale data:\n\n```elixir\ngray_data = <<128, 64, 32, 16>>  # 4 gray pixels\n{:ok, gray_image} = Image.new_from_binary(gray_data, 4, 1, 1, :VIPS_FORMAT_UCHAR)\n```\n\nCreating an RGB image from raw pixel data:\n\n    pixel_data = get_rgb_pixels() # Binary of RGB values\n    {:ok, image} = Image.new_from_binary(pixel_data, 640, 480, 3, :VIPS_FORMAT_UCHAR)\n\n\nFor loading formatted binary (JPEG, PNG, etc) see `new_from_buffer/2`.","ref":"Vix.Vips.Image.html#new_from_binary/5-examples"},{"type":"function","title":"Vix.Vips.Image.new_from_buffer/2","doc":"Creates a new image from formatted binary data (like JPEG, PNG, etc.).\n\nThis function attempts to automatically detect the image format from the binary data.\nIt's particularly useful when working with image data from network requests, databases,\nor other binary sources.","ref":"Vix.Vips.Image.html#new_from_buffer/2"},{"type":"function","title":"Parameters - Vix.Vips.Image.new_from_buffer/2","doc":"* `bin` - Binary data containing a formatted image (JPEG, PNG, etc.)\n* `opts` - Format-specific loading options (same as `new_from_file/2`)","ref":"Vix.Vips.Image.html#new_from_buffer/2-parameters"},{"type":"function","title":"Examples - Vix.Vips.Image.new_from_buffer/2","doc":"Basic usage with binary data:\n\n    {:ok, image} = Image.new_from_buffer(jpeg_binary)\n\nLoading with specific options:\n\n    {:ok, image} = Image.new_from_buffer(jpeg_binary, shrink: 2)\n\nWorking with HTTP responses:\n\n    {:ok, response} = HTTPClient.get(\"https://example.com/image.jpg\")\n    {:ok, image} = Image.new_from_buffer(response.body)","ref":"Vix.Vips.Image.html#new_from_buffer/2-examples"},{"type":"function","title":"Format-Specific Loading - Vix.Vips.Image.new_from_buffer/2","doc":"For known formats, you can use specific loaders from `Vix.Vips.Operation`:\n\n    {:ok, image} = Vix.Vips.Operation.jpegload_buffer(jpeg_binary, access: :VIPS_ACCESS_SEQUENTIAL)","ref":"Vix.Vips.Image.html#new_from_buffer/2-format-specific-loading"},{"type":"function","title":"Vix.Vips.Image.new_from_enum/2","doc":"Creates a new image by lazily reading from an Enumerable source.\n\nThis function is ideal for processing large images without loading the entire file into memory.\nIt detects the image format from the initial bytes and reads remaining data on-demand.","ref":"Vix.Vips.Image.html#new_from_enum/2"},{"type":"function","title":"Parameters - Vix.Vips.Image.new_from_enum/2","doc":"* `enum` - An Enumerable producing image data (e.g., File.stream!, HTTP chunks)\n* `opts` - Optional keyword list of format-specific options. To be backward compatible it also accepts options\nas a string in \"[name=value,...]\" format for the time being.","ref":"Vix.Vips.Image.html#new_from_enum/2-parameters"},{"type":"function","title":"Examples - Vix.Vips.Image.new_from_enum/2","doc":"Reading from a file stream:\n\n    {:ok, image} =\n      File.stream!(\"large_photo.jpg\", [], 65_536)\n      |> Image.new_from_enum()\n\nReading from a file with options:\n\n    {:ok, image} =\n      File.stream!(\"large_photo.jpg\", [], 65_536)\n      |> Image.new_from_enum(shrink: 2)\n\nProcessing S3 stream:\n\n    {:ok, image} =\n      ExAws.S3.download_file(\"bucket\", \"image.jpg\")\n      |> Stream.map(&process_chunk/1)\n      |> Image.new_from_enum()","ref":"Vix.Vips.Image.html#new_from_enum/2-examples"},{"type":"function","title":"Format Options - Vix.Vips.Image.new_from_enum/2","doc":"To see format-specific options, check [Operation](./search.html?q=load+-buffer+-filename+-profile) module.","ref":"Vix.Vips.Image.html#new_from_enum/2-format-options"},{"type":"function","title":"Vix.Vips.Image.new_from_file/1","doc":"","ref":"Vix.Vips.Image.html#new_from_file/1"},{"type":"function","title":"Vix.Vips.Image.new_from_file/2","doc":"Opens an image file for reading and returns a `t:Vix.Vips.Image.t/0` struct.\n\nThis function provides a high-level interface to load images from many format\ndepending on the libraries installed.","ref":"Vix.Vips.Image.html#new_from_file/2"},{"type":"function","title":"Options - Vix.Vips.Image.new_from_file/2","doc":"The `opts` parameter accepts format-specific loading options. Each format supports\ndifferent options which can be found in the [Operation](./search.html?q=load+-buffer+-filename+-profile)\nmodule documentation.","ref":"Vix.Vips.Image.html#new_from_file/2-options"},{"type":"function","title":"Examples - Vix.Vips.Image.new_from_file/2","doc":"```elixir\n# Basic usage:\n{:ok, %Image{} = image} = Image.new_from_file(\"photo.jpg\")\n\n# Loading with options (downsampling by factor of 2):\n{:ok, image} = Image.new_from_file(\"large_photo.jpg\", shrink: 2)\n\n# Loading a specific page from a multi-page TIFF\n{:ok, page} = Image.new_from_file(\"document.tiff\", page: 1)\n\n# Loading a PNG with specific options:\n{:ok, image} = Image.new_from_file(\"transparent.png\", access: :VIPS_ACCESS_SEQUENTIAL)\n```\n\nTo see all available options for a specific format, you can check the corresponding loader function. For example, `Vix.Vips.Operation.jpegload/2` documents all JPEG-specific options.","ref":"Vix.Vips.Image.html#new_from_file/2-examples"},{"type":"function","title":"Performance Notes - Vix.Vips.Image.new_from_file/2","doc":"The loading process is optimized - only the image header is initially loaded into memory.\nPixel data is decompressed on-demand when accessed, making this operation memory-efficient\nfor large images.","ref":"Vix.Vips.Image.html#new_from_file/2-performance-notes"},{"type":"function","title":"Advanced Usage - Vix.Vips.Image.new_from_file/2","doc":"For more control over the loading process, consider using format-specific loaders from\n`Vix.Vips.Operation`. For example:\n\n```elixir\n# Using specific JPEG loader\n{:ok, image} = Vix.Vips.Operation.jpegload(\"photo.jpg\", access: :VIPS_ACCESS_SEQUENTIAL)\n```","ref":"Vix.Vips.Image.html#new_from_file/2-advanced-usage"},{"type":"function","title":"Vix.Vips.Image.new_from_image/2","doc":"Creates a new image by cloning dimensions and properties from an existing image,\nfilling all bands with specified values.\n\nThe new image inherits the following properties from the source image:\n* Width and height\n* Format and color interpretation\n* Resolution\n* Offset","ref":"Vix.Vips.Image.html#new_from_image/2"},{"type":"function","title":"Parameters - Vix.Vips.Image.new_from_image/2","doc":"* `image` - Source image to clone properties from\n* `value` - List of numbers representing values for each band","ref":"Vix.Vips.Image.html#new_from_image/2-parameters"},{"type":"function","title":"Examples - Vix.Vips.Image.new_from_image/2","doc":"Create a solid red image with same dimensions as source:\n\n    {:ok, red_image} = Image.new_from_image(source_image, [255, 0, 0])\n\nCreate a semi-transparent overlay:\n\n    {:ok, overlay} = Image.new_from_image(source_image, [0, 0, 0, 128])","ref":"Vix.Vips.Image.html#new_from_image/2-examples"},{"type":"function","title":"Vix.Vips.Image.new_from_list/2","doc":"Make a VipsImage from 1D or 2D list.\n\nIf list is a single dimension then an image of height 1 will be with list\ncontent as values.\n\nIf list is 2D then 2D image will be created.\n\nOutput image will always be a one band image with `double` format.\n\n```elixir\n# 1D list\n{:ok, img2} = Image.new_from_list([0, 1, 0])\n\n# 2D list\n{:ok, img} = Image.new_from_list([[0, 1, 0], [1, 1, 1], [0, 1, 0]])\n```","ref":"Vix.Vips.Image.html#new_from_list/2"},{"type":"function","title":"Optional - Vix.Vips.Image.new_from_list/2","doc":"* scale - Default: 1\n* offset - Default: 0","ref":"Vix.Vips.Image.html#new_from_list/2-optional"},{"type":"function","title":"Vix.Vips.Image.new_matrix_from_array/4","doc":"Make a VipsImage from 2D list.\n\nThis is a convenience function makes an image which is a matrix: a one-band VIPS_FORMAT_DOUBLE image held in memory. Useful for vips operations such as `conv`.\n\n```elixir\n{:ok, mask} = Image.new_matrix_from_array(3, 3, [[0, 1, 0], [1, 1, 1], [0, 1, 0]])\n```","ref":"Vix.Vips.Image.html#new_matrix_from_array/4"},{"type":"function","title":"Optional - Vix.Vips.Image.new_matrix_from_array/4","doc":"* scale - Default: 1\n* offset - Default: 0","ref":"Vix.Vips.Image.html#new_matrix_from_array/4-optional"},{"type":"function","title":"Vix.Vips.Image.new_temp_file/1","doc":"Make a VipsImage which, when written to, will create a temporary file on disc.\n\nThe file will be automatically deleted when the image is destroyed. format is something like `\"%s.v\"` for a vips file.\n\nThe file is created in the temporary directory. This is set with the environment variable TMPDIR. If this is not set, then on Unix systems, vips will default to `/tmp`. On Windows, vips uses `GetTempPath()` to find the temporary directory.\n\n```elixir\nvips_image = Image.new_temp_file(\"%s.v\")\n```","ref":"Vix.Vips.Image.html#new_temp_file/1"},{"type":"function","title":"Vix.Vips.Image.offset/1","doc":"Get \"offset\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-offset) for more details regarding `offset` function","ref":"Vix.Vips.Image.html#offset/1"},{"type":"function","title":"Vix.Vips.Image.orientation/1","doc":"Get \"orientation\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-orientation) for more details regarding `orientation` function","ref":"Vix.Vips.Image.html#orientation/1"},{"type":"function","title":"Vix.Vips.Image.page_height/1","doc":"Get \"page-height\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-page-height) for more details regarding `page_height` function","ref":"Vix.Vips.Image.html#page_height/1"},{"type":"function","title":"Vix.Vips.Image.scale/1","doc":"Get \"scale\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-scale) for more details regarding `scale` function","ref":"Vix.Vips.Image.html#scale/1"},{"type":"function","title":"Vix.Vips.Image.shape/1","doc":"Returns 3 element tuple representing `{width, height, number_of_bands}`","ref":"Vix.Vips.Image.html#shape/1"},{"type":"function","title":"Examples - Vix.Vips.Image.shape/1","doc":"```elixir\niex> img = Image.build_image!(100, 200, [1, 2, 3])\niex> Image.shape(img)\n{100, 200, 3}\n```","ref":"Vix.Vips.Image.html#shape/1-examples"},{"type":"function","title":"Vix.Vips.Image.supported_saver_suffixes/0","doc":"Returns list of supported extension for *saving* the image.\n\nSupported suffix can be used to save image in a particular format.\nSee `write_to_file/2`.\n\nNote that the image format supported for saving the image and the\nformat supported for loading image might be different. For example\nSVG format can be loaded but can not be saved.","ref":"Vix.Vips.Image.html#supported_saver_suffixes/0"},{"type":"type","title":"Vix.Vips.Image.t/0","doc":"Represents an instance of VipsImage","ref":"Vix.Vips.Image.html#t:t/0"},{"type":"function","title":"Vix.Vips.Image.to_list/1","doc":"Converts an Image to a nested list.\n\nReturns a nested list of the shape `height x width x band`.\nFor example for an image with height 10, width 5, and 3 bands\nreturned value will be a list of length 10 (height), with each\nelement will be a list of length 5 (height), and each\nelement inside that will be a list of length 3 (bands).\n\n\n> #### Caution {: .warning}\n> This is meant to be used for very small images such as histograms, and\n> matrix. Depending on the image size it can generate and return a large\n> list leading to performance issues.\n\n\n```elixir\nhistogram =\n  Vix.Vips.Operation.black!(10, 50)\n  |> Vix.Vips.Operation.hist_find!()\n\nlist = Vix.Vips.Image.to_list(histogram)\n```","ref":"Vix.Vips.Image.html#to_list/1"},{"type":"function","title":"Vix.Vips.Image.to_list!/1","doc":"Same as `to_list!/1` but raises error instead of returning it.","ref":"Vix.Vips.Image.html#to_list!/1"},{"type":"function","title":"Vix.Vips.Image.width/1","doc":"Get \"width\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-width) for more details regarding `width` function","ref":"Vix.Vips.Image.html#width/1"},{"type":"function","title":"Vix.Vips.Image.write_to_binary/1","doc":"Extracts raw pixel data from a VIPS image as a binary term.\n\nThis is a lower-level alternative to `write_to_tensor/1` that returns only the\nraw binary data without the associated metadata. It's primarily intended for\ncases where you already know the image dimensions and format.","ref":"Vix.Vips.Image.html#write_to_binary/1"},{"type":"function","title":"Warning - Vix.Vips.Image.write_to_binary/1","doc":"It's recommended to use `write_to_tensor/1` instead of this function unless you\nhave a specific need for the raw binary data and already know:\n\n* Image dimensions (height × width)\n* Number of bands\n* Pixel data format\n* Data layout and organization","ref":"Vix.Vips.Image.html#write_to_binary/1-warning"},{"type":"function","title":"Examples - Vix.Vips.Image.write_to_binary/1","doc":"Extracting raw binary data:\n\n    {:ok, binary_data} = Image.write_to_binary(image)","ref":"Vix.Vips.Image.html#write_to_binary/1-examples"},{"type":"function","title":"Vix.Vips.Image.write_to_buffer/2","doc":"","ref":"Vix.Vips.Image.html#write_to_buffer/2"},{"type":"function","title":"Vix.Vips.Image.write_to_buffer/3","doc":"Converts a VIPS image to a binary representation in the specified format.\n\nThis function is similar to `write_to_file/3` but returns the encoded image\nas a binary instead of writing to a file. This is particularly useful for\nweb applications or when working with in-memory image processing pipelines.","ref":"Vix.Vips.Image.html#write_to_buffer/3"},{"type":"function","title":"Parameters - Vix.Vips.Image.write_to_buffer/3","doc":"* `image` - The source `t:Vix.Vips.Image.t/0` to convert\n* `suffix` - Format extension (e.g., \".jpg\", \".png\")\n* `opts` - Format-specific encoding options","ref":"Vix.Vips.Image.html#write_to_buffer/3-parameters"},{"type":"function","title":"Examples - Vix.Vips.Image.write_to_buffer/3","doc":"Basic conversion to different formats:\n\n    # Convert to JPEG binary\n    {:ok, jpeg_binary} = Image.write_to_buffer(image, \".jpg\")\n\n    # Convert to PNG binary\n    {:ok, png_binary} = Image.write_to_buffer(image, \".png\")\n\nConverting with quality settings:\n\n    # JPEG with 90% quality\n    {:ok, jpeg_binary} = Image.write_to_buffer(image, \".jpg\", Q: 90)\n\n    # PNG with maximum compression\n    {:ok, png_binary} = Image.write_to_buffer(image, \".png\", compression: 9)\n\nWeb application example:\n\n    def show_image(conn, %{\"id\" => id}) do\n      image = MyApp.get_image!(id)\n      {:ok, binary} = Image.write_to_buffer(image, \".jpg\", Q: 85)\n\n      conn\n      |> put_resp_content_type(\"image/jpeg\")\n      |> send_resp(200, binary)\n    end","ref":"Vix.Vips.Image.html#write_to_buffer/3-examples"},{"type":"function","title":"Vix.Vips.Image.write_to_file/2","doc":"","ref":"Vix.Vips.Image.html#write_to_file/2"},{"type":"function","title":"Vix.Vips.Image.write_to_file/3","doc":"Writes a VIPS image to a file in the format determined by the file extension.","ref":"Vix.Vips.Image.html#write_to_file/3"},{"type":"function","title":"Parameters - Vix.Vips.Image.write_to_file/3","doc":"* `image` - The source `t:Vix.Vips.Image.t/0` to save\n* `path` - Destination file path (format determined by extension)\n* `opts` - Format-specific saving options","ref":"Vix.Vips.Image.html#write_to_file/3-parameters"},{"type":"function","title":"Format Options - Vix.Vips.Image.write_to_file/3","doc":"Each format supports different saving options, which can be found in the\n[Operation](./search.html?q=save+-buffer+-filename+-profile) module documentation.","ref":"Vix.Vips.Image.html#write_to_file/3-format-options"},{"type":"function","title":"Examples - Vix.Vips.Image.write_to_file/3","doc":"Basic usage:\n\n    :ok = Image.write_to_file(image, \"output.jpg\")\n\nSaving with quality settings:\n\n    # JPEG with 90% quality\n    :ok = Image.write_to_file(image, \"output.jpg\", Q: 90)\n\n    # PNG with maximum compression\n    :ok = Image.write_to_file(image, \"output.png\", compression: 9)\n\nSaving with multiple options:\n\n    # JPEG with quality and metadata stripping\n    :ok = Image.write_to_file(image, \"output.jpg\", Q: 90, strip: true)","ref":"Vix.Vips.Image.html#write_to_file/3-examples"},{"type":"function","title":"Advanced Usage - Vix.Vips.Image.write_to_file/3","doc":"For more control, use format-specific savers from `Vix.Vips.Operation`:\n\n    # Using specific JPEG saver\n    :ok = Vix.Vips.Operation.jpegsave(image, \"output.jpg\", Q: 95)","ref":"Vix.Vips.Image.html#write_to_file/3-advanced-usage"},{"type":"function","title":"Vix.Vips.Image.write_to_stream/2","doc":"","ref":"Vix.Vips.Image.html#write_to_stream/2"},{"type":"function","title":"Vix.Vips.Image.write_to_stream/3","doc":"Creates a Stream that lazily writes image data in the specified format.\n\nThis function is particularly useful for handling large images or when streaming\ndirectly to storage/network without intermediate files.","ref":"Vix.Vips.Image.html#write_to_stream/3"},{"type":"function","title":"Parameters - Vix.Vips.Image.write_to_stream/3","doc":"* `image` - The source image to stream\n* `suffix` - Output format suffix. (e.g., \".jpg\", \".png\")\n* `opts` - Optional keyword list of format-specific options (e.g., `[Q: 90]`)","ref":"Vix.Vips.Image.html#write_to_stream/3-parameters"},{"type":"function","title":"Examples - Vix.Vips.Image.write_to_stream/3","doc":"Basic streaming to file:\n\n    {:ok, image} = Image.new_from_file(\"input.jpg\")\n\n    :ok =\n      Image.write_to_stream(image, \".png\")\n      |> Stream.into(File.stream!(\"output.png\"))\n      |> Stream.run()\n\nStreaming with quality options:\n\n    :ok =\n      Image.write_to_stream(image, \".jpg\", Q: 90, strip: true)\n      |> Stream.into(File.stream!(\"output.jpg\"))\n      |> Stream.run()\n\nStreaming to S3:\n\n    :ok =\n      Image.write_to_stream(image, \".png\")\n      |> Stream.each(&upload_chunk_to_s3/1)\n      |> Stream.run()","ref":"Vix.Vips.Image.html#write_to_stream/3-examples"},{"type":"function","title":"Format Options - Vix.Vips.Image.write_to_stream/3","doc":"Each format supports different saving options. View available options in\n[Operation](./search.html?q=save+buffer+-filename+-profile) module.","ref":"Vix.Vips.Image.html#write_to_stream/3-format-options"},{"type":"function","title":"Vix.Vips.Image.write_to_tensor/1","doc":"Extracts raw pixel data from a VIPS image as a `Vix.Tensor` structure.\n\nThis function provides access to the underlying pixel data in a format suitable\nfor interoperability with other image processing or machine learning libraries.","ref":"Vix.Vips.Image.html#write_to_tensor/1"},{"type":"function","title":"Image Structure - Vix.Vips.Image.write_to_tensor/1","doc":"VIPS images are three-dimensional arrays with the following dimensions:\n* Width: The horizontal size (up to 2^31 pixels)\n* Height: The vertical size (up to 2^31 pixels)\n* Bands: The number of channels per pixel (e.g., 3 for RGB, 4 for RGBA)","ref":"Vix.Vips.Image.html#write_to_tensor/1-image-structure"},{"type":"function","title":"Data Format - Vix.Vips.Image.write_to_tensor/1","doc":"VIPS supports 10 different numeric formats for pixel values, ranging from\n8-bit unsigned integers to 128-bit double complex numbers. Images are treated\nas uninterpreted arrays of numbers - there's no inherent difference between\ndifferent color spaces with the same number of bands (e.g., RGBA vs CMYK).","ref":"Vix.Vips.Image.html#write_to_tensor/1-data-format"},{"type":"function","title":"Performance Notes - Vix.Vips.Image.write_to_tensor/1","doc":"Depending on the caching mechanism and image construction, VIPS may need to run all\nthe operations in the pipeline to produce the pixel data.","ref":"Vix.Vips.Image.html#write_to_tensor/1-performance-notes"},{"type":"function","title":"Endianness Considerations - Vix.Vips.Image.write_to_tensor/1","doc":"The binary data in the tensor uses native endianness. When processing this\ndata using bitstring syntax, always specify the `native` modifier:\n\n    # Correct - using native endianness\n    < >\n\n    # Incorrect - default big endian\n    < >\n\nSee [Elixir docs](https://hexdocs.pm/elixir/Kernel.SpecialForms.html#%3C%3C%3E%3E/1-endianness) for more details.","ref":"Vix.Vips.Image.html#write_to_tensor/1-endianness-considerations"},{"type":"function","title":"Examples - Vix.Vips.Image.write_to_tensor/1","doc":"Converting an image to a tensor:\n\n    {:ok, tensor} = Image.write_to_tensor(rgb_image)\n    %Vix.Tensor{\n      data: < >,\n      shape: {height, width, 3},\n      names: [:height, :width, :bands],\n      type: :u8\n    } = tensor","ref":"Vix.Vips.Image.html#write_to_tensor/1-examples"},{"type":"function","title":"Vix.Vips.Image.xoffset/1","doc":"Get \"xoffset\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-xoffset) for more details regarding `xoffset` function","ref":"Vix.Vips.Image.html#xoffset/1"},{"type":"function","title":"Vix.Vips.Image.xres/1","doc":"Get \"xres\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-xres) for more details regarding `xres` function","ref":"Vix.Vips.Image.html#xres/1"},{"type":"function","title":"Vix.Vips.Image.yoffset/1","doc":"Get \"yoffset\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-yoffset) for more details regarding `yoffset` function","ref":"Vix.Vips.Image.html#yoffset/1"},{"type":"function","title":"Vix.Vips.Image.yres/1","doc":"Get \"yres\" of the image\n\n> #### More details {: .tip}\n>\n> See [libvips docs](https://libvips.github.io/libvips/API/current/libvips-header.html#vips-image-get-yres) for more details regarding `yres` function","ref":"Vix.Vips.Image.html#yres/1"},{"type":"module","title":"Vix.Vips.Interpolate","doc":"Make interpolators for operators like `affine` and `mapim`.","ref":"Vix.Vips.Interpolate.html"},{"type":"function","title":"Vix.Vips.Interpolate.new/1","doc":"Make a new interpolator by name.\n\nMake a new interpolator from the libvips class nickname. For example:\n\n```elixir\n{:ok, interpolate} = Interpolate.new(\"bilindear\")\n```\n\nYou can get a list of all supported interpolators from the command-line with:\n\n```shell\n$ vips -l interpolate\n```\n\nSee for example `affine`.","ref":"Vix.Vips.Interpolate.html#new/1"},{"type":"function","title":"Vix.Vips.Interpolate.new!/1","doc":"Make a new interpolator by name.\n\nMake a new interpolator from the libvips class nickname. For example:\n\n```elixir\ninterpolate = Interpolate.new!(\"bilindear\")\n```\n\nYou can get a list of all supported interpolators from the command-line with:\n\n```shell\n$ vips -l interpolate\n```\n\nSee for example `affine`.","ref":"Vix.Vips.Interpolate.html#new!/1"},{"type":"type","title":"Vix.Vips.Interpolate.t/0","doc":"Represents an instance of VipsInterpolate","ref":"Vix.Vips.Interpolate.html#t:t/0"},{"type":"module","title":"Vix.Vips.MutableImage","doc":"Vips Mutable Image\n\nSee `Vix.Vips.Image.mutate/2`","ref":"Vix.Vips.MutableImage.html"},{"type":"function","title":"Vix.Vips.MutableImage.bands/1","doc":"Return the number of bands of a mutable image.","ref":"Vix.Vips.MutableImage.html#bands/1"},{"type":"function","title":"Vix.Vips.MutableImage.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Vix.Vips.MutableImage.html#child_spec/1"},{"type":"function","title":"Vix.Vips.MutableImage.get/2","doc":"Returns metadata from the image","ref":"Vix.Vips.MutableImage.html#get/2"},{"type":"function","title":"Vix.Vips.MutableImage.has_alpha?/1","doc":"Return a boolean indicating if a mutable image\nhas an alpha band.","ref":"Vix.Vips.MutableImage.html#has_alpha?/1"},{"type":"function","title":"Vix.Vips.MutableImage.height/1","doc":"Return the height of a mutable image.","ref":"Vix.Vips.MutableImage.html#height/1"},{"type":"function","title":"Vix.Vips.MutableImage.remove/2","doc":"Remove a metadata item from an image.","ref":"Vix.Vips.MutableImage.html#remove/2"},{"type":"function","title":"Vix.Vips.MutableImage.set/4","doc":"Create a metadata item on an image of the specified type.\nVix converts value to specified GType\n\nSupported GTypes\n  * `:gint`\n  * `:guint`\n  * `:gdouble`\n  * `:gboolean`\n  * `:gchararray`\n  * `:VipsArrayInt`\n  * `:VipsArrayDouble`\n  * `:VipsArrayImage`\n  * `:VipsRefString`\n  * `:VipsBlob`\n  * `:VipsImage`\n  * `:VipsInterpolate`","ref":"Vix.Vips.MutableImage.html#set/4"},{"type":"function","title":"Vix.Vips.MutableImage.shape/1","doc":"Return the shape of the image as\n`{width, height, bands}`.","ref":"Vix.Vips.MutableImage.html#shape/1"},{"type":"type","title":"Vix.Vips.MutableImage.t/0","doc":"Represents a mutable instance of VipsImage","ref":"Vix.Vips.MutableImage.html#t:t/0"},{"type":"function","title":"Vix.Vips.MutableImage.update/3","doc":"Set the value of existing metadata item on an image. Value is converted to match existing value GType","ref":"Vix.Vips.MutableImage.html#update/3"},{"type":"function","title":"Vix.Vips.MutableImage.width/1","doc":"Return the width of a mutable image.","ref":"Vix.Vips.MutableImage.html#width/1"},{"type":"module","title":"Vix.Vips.MutableOperation","doc":"Module for Vix.Vips.MutableOperation.","ref":"Vix.Vips.MutableOperation.html"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_circle/6","doc":"Draw a circle on an image","ref":"Vix.Vips.MutableOperation.html#draw_circle/6"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_circle/6","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * cx - Centre of draw_circle\n  * cy - Centre of draw_circle\n  * radius - Radius in pixels","ref":"Vix.Vips.MutableOperation.html#draw_circle/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_circle/6","doc":"* fill - Draw a solid object. Default: `false`","ref":"Vix.Vips.MutableOperation.html#draw_circle/6-optional"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_circle!/6","doc":"Draw a circle on an image","ref":"Vix.Vips.MutableOperation.html#draw_circle!/6"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_circle!/6","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * cx - Centre of draw_circle\n  * cy - Centre of draw_circle\n  * radius - Radius in pixels","ref":"Vix.Vips.MutableOperation.html#draw_circle!/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_circle!/6","doc":"* fill - Draw a solid object. Default: `false`","ref":"Vix.Vips.MutableOperation.html#draw_circle!/6-optional"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_flood/5","doc":"Flood-fill an area","ref":"Vix.Vips.MutableOperation.html#draw_flood/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_flood/5","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * x - DrawFlood start point\n  * y - DrawFlood start point","ref":"Vix.Vips.MutableOperation.html#draw_flood/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_flood/5","doc":"* equal - DrawFlood while equal to edge. Default: `false`\n* test - Test pixels in this image.","ref":"Vix.Vips.MutableOperation.html#draw_flood/5-optional"},{"type":"function","title":"Returns - Vix.Vips.MutableOperation.draw_flood/5","doc":"Operation returns a tuple\n\n\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* height - Height of modified area. (`integer()`)\n* width - Width of modified area. (`integer()`)\n* top - Top edge of modified area. (`integer()`)\n* left - Left edge of modified area. (`integer()`)","ref":"Vix.Vips.MutableOperation.html#draw_flood/5-returns"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_flood!/5","doc":"Flood-fill an area","ref":"Vix.Vips.MutableOperation.html#draw_flood!/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_flood!/5","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * x - DrawFlood start point\n  * y - DrawFlood start point","ref":"Vix.Vips.MutableOperation.html#draw_flood!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_flood!/5","doc":"* equal - DrawFlood while equal to edge. Default: `false`\n* test - Test pixels in this image.","ref":"Vix.Vips.MutableOperation.html#draw_flood!/5-optional"},{"type":"function","title":"Returns - Vix.Vips.MutableOperation.draw_flood!/5","doc":"Operation returns a tuple\n\n\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* height - Height of modified area. (`integer()`)\n* width - Width of modified area. (`integer()`)\n* top - Top edge of modified area. (`integer()`)\n* left - Left edge of modified area. (`integer()`)","ref":"Vix.Vips.MutableOperation.html#draw_flood!/5-returns"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_image/5","doc":"Paint an image into another image","ref":"Vix.Vips.MutableOperation.html#draw_image/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_image/5","doc":"* image - Image to draw on\n  * sub - Sub-image to insert into main image\n  * x - Draw image here\n  * y - Draw image here","ref":"Vix.Vips.MutableOperation.html#draw_image/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_image/5","doc":"* mode - Combining mode. Default: `:VIPS_COMBINE_MODE_SET`","ref":"Vix.Vips.MutableOperation.html#draw_image/5-optional"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_image!/5","doc":"Paint an image into another image","ref":"Vix.Vips.MutableOperation.html#draw_image!/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_image!/5","doc":"* image - Image to draw on\n  * sub - Sub-image to insert into main image\n  * x - Draw image here\n  * y - Draw image here","ref":"Vix.Vips.MutableOperation.html#draw_image!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_image!/5","doc":"* mode - Combining mode. Default: `:VIPS_COMBINE_MODE_SET`","ref":"Vix.Vips.MutableOperation.html#draw_image!/5-optional"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_line/6","doc":"Draw a line on an image","ref":"Vix.Vips.MutableOperation.html#draw_line/6"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_line/6","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * x1 - Start of draw_line\n  * y1 - Start of draw_line\n  * x2 - End of draw_line\n  * y2 - End of draw_line","ref":"Vix.Vips.MutableOperation.html#draw_line/6-arguments"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_line!/6","doc":"Draw a line on an image","ref":"Vix.Vips.MutableOperation.html#draw_line!/6"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_line!/6","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * x1 - Start of draw_line\n  * y1 - Start of draw_line\n  * x2 - End of draw_line\n  * y2 - End of draw_line","ref":"Vix.Vips.MutableOperation.html#draw_line!/6-arguments"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_mask/5","doc":"Draw a mask on an image","ref":"Vix.Vips.MutableOperation.html#draw_mask/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_mask/5","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * mask - Mask of pixels to draw\n  * x - Draw mask here\n  * y - Draw mask here","ref":"Vix.Vips.MutableOperation.html#draw_mask/5-arguments"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_mask!/5","doc":"Draw a mask on an image","ref":"Vix.Vips.MutableOperation.html#draw_mask!/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_mask!/5","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * mask - Mask of pixels to draw\n  * x - Draw mask here\n  * y - Draw mask here","ref":"Vix.Vips.MutableOperation.html#draw_mask!/5-arguments"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_rect/7","doc":"Paint a rectangle on an image","ref":"Vix.Vips.MutableOperation.html#draw_rect/7"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_rect/7","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * left - Rect to fill\n  * top - Rect to fill\n  * width - Rect to fill\n  * height - Rect to fill","ref":"Vix.Vips.MutableOperation.html#draw_rect/7-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_rect/7","doc":"* fill - Draw a solid object. Default: `false`","ref":"Vix.Vips.MutableOperation.html#draw_rect/7-optional"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_rect!/7","doc":"Paint a rectangle on an image","ref":"Vix.Vips.MutableOperation.html#draw_rect!/7"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_rect!/7","doc":"* image - Image to draw on\n  * ink - Color for pixels\n  * left - Rect to fill\n  * top - Rect to fill\n  * width - Rect to fill\n  * height - Rect to fill","ref":"Vix.Vips.MutableOperation.html#draw_rect!/7-arguments"},{"type":"function","title":"Optional - Vix.Vips.MutableOperation.draw_rect!/7","doc":"* fill - Draw a solid object. Default: `false`","ref":"Vix.Vips.MutableOperation.html#draw_rect!/7-optional"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_smudge/5","doc":"Blur a rectangle on an image","ref":"Vix.Vips.MutableOperation.html#draw_smudge/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_smudge/5","doc":"* image - Image to draw on\n  * left - Rect to fill\n  * top - Rect to fill\n  * width - Rect to fill\n  * height - Rect to fill","ref":"Vix.Vips.MutableOperation.html#draw_smudge/5-arguments"},{"type":"function","title":"Vix.Vips.MutableOperation.draw_smudge!/5","doc":"Blur a rectangle on an image","ref":"Vix.Vips.MutableOperation.html#draw_smudge!/5"},{"type":"function","title":"Arguments - Vix.Vips.MutableOperation.draw_smudge!/5","doc":"* image - Image to draw on\n  * left - Rect to fill\n  * top - Rect to fill\n  * width - Rect to fill\n  * height - Rect to fill","ref":"Vix.Vips.MutableOperation.html#draw_smudge!/5-arguments"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_access/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_access/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_align/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_align/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_angle45/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_angle45/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_angle/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_angle/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_band_format/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_band_format/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_blend_mode/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_blend_mode/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_coding/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_coding/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_combine/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_combine/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_combine_mode/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_combine_mode/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_compass_direction/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_compass_direction/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_demand_style/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_demand_style/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_direction/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_direction/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_extend/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_extend/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_fail_on/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_fail_on/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_dz_container/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_dz_container/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_dz_depth/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_dz_depth/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_dz_layout/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_dz_layout/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_flags/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_flags/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_heif_compression/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_heif_compression/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_heif_encoder/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_heif_encoder/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_keep/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_keep/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_png_filter/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_png_filter/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_subsample/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_subsample/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_tiff_compression/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_tiff_compression/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_tiff_predictor/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_tiff_predictor/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_tiff_resunit/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_tiff_resunit/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_foreign_webp_preset/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_foreign_webp_preset/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_intent/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_intent/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_interesting/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_interesting/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_interpretation/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_interpretation/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_kernel/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_kernel/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_boolean/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_boolean/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_complex2/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_complex2/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_complex/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_complex/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_complexget/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_complexget/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_math2/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_math2/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_math/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_math/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_morphology/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_morphology/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_relational/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_relational/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_operation_round/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_operation_round/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_pcs/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_pcs/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_precision/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_precision/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_region_shrink/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_region_shrink/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_size/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_size/0"},{"type":"type","title":"Vix.Vips.MutableOperation.vips_text_wrap/0","doc":"","ref":"Vix.Vips.MutableOperation.html#t:vips_text_wrap/0"},{"type":"module","title":"Vix.Vips.Operation","doc":"Provides access to VIPS operations for image processing.\n\nThis module exposes VIPS operations as Elixir functions, allowing you to perform\nvarious image processing tasks like resizing, color manipulation, filtering,\nand format conversion.","ref":"Vix.Vips.Operation.html"},{"type":"module","title":"Quick Start - Vix.Vips.Operation","doc":"Here's a simple example to resize an image:\n\n    # Load and resize an image to 500px width, maintaining aspect ratio\n    {:ok, image} = Operation.thumbnail(\"input.jpg\", 500)","ref":"Vix.Vips.Operation.html#module-quick-start"},{"type":"module","title":"Working with Operations - Vix.Vips.Operation","doc":"Operations in Vix can be grouped into several categories:\n\n* **Loading/Saving** - `Vix.Vips.Image`, `thumbnail/2`, and format specific functions.\n* **Resizing** - `resize/2`, `thumbnail/2`, `smartcrop/3`\n* **Color Management** - `colourspace/2`, `icc_transform/2`\n* **Filters & Effects** - `gaussblur/2`, `sharpen/2`\n* **Composition** - `composite/3`, `join/3`, `insert/4`\n\nMost operations follow a consistent pattern:\n\n1. Load your image\n2. Apply one or more operations\n3. Save the result","ref":"Vix.Vips.Operation.html#module-working-with-operations"},{"type":"module","title":"Common Examples - Vix.Vips.Operation","doc":"# Basic image resizing while preserving aspect ratio\n    {:ok, image} = Vix.Vips.Image.new_from_file(\"input.jpg\")\n    # scale down by 50%\n    {:ok, resized} = Operation.resize(image, scale: 0.5)\n    :ok = Vix.Vips.Image.write_to_file(resized, \"output.jpg\")\n\n    # Convert to grayscale and apply Gaussian blur\n    {:ok, image} = Vix.Vips.Image.new_from_file(\"input.jpg\")\n    {:ok, gray} = Operation.colourspace(image, :VIPS_INTERPRETATION_B_W)\n    {:ok, blurred} = Operation.gaussblur(gray, 3.0)","ref":"Vix.Vips.Operation.html#module-common-examples"},{"type":"module","title":"Advanced Usage - Vix.Vips.Operation","doc":"","ref":"Vix.Vips.Operation.html#module-advanced-usage"},{"type":"module","title":"Smart Cropping for Thumbnails - Vix.Vips.Operation","doc":"# Generate a smart-cropped thumbnail focusing on interesting areas\n    {:ok, thumb} = Operation.thumbnail(\"input.jpg\", 300,\n      crop: :attention,  # Uses image analysis to find interesting areas\n      height: 300,      # Force square thumbnail\n    )","ref":"Vix.Vips.Operation.html#module-smart-cropping-for-thumbnails"},{"type":"module","title":"Complex Image Composition - Vix.Vips.Operation","doc":"# Create a watermarked image with transparency\n    {:ok, base} = Vix.Vips.Image.new_from_file(\"photo.jpg\")\n    {:ok, watermark} = Vix.Vips.Image.new_from_file(\"watermark.png\")\n    {:ok, composed} = Operation.composite2(base, watermark,\n      :VIPS_BLEND_MODE_OVER,  # Blend mode\n      x: 20,         # Offset from left\n      y: 20,         # Offset from top\n      opacity: 0.8   # Watermark transparency\n    )","ref":"Vix.Vips.Operation.html#module-complex-image-composition"},{"type":"module","title":"Color Management - Vix.Vips.Operation","doc":"# Convert between color spaces with ICC profiles\n    {:ok, image} = Vix.Vips.Image.new_from_file(\"input.jpg\")\n    {:ok, converted} = Operation.icc_transform(image,\n      \"sRGB.icc\",     # Target color profile\n      \"input-profile\": \"Adobe-RGB.icc\"\n    )\n\n\n>","ref":"Vix.Vips.Operation.html#module-color-management"},{"type":"module","title":"Performance Tips {: .tip} - Vix.Vips.Operation","doc":">\n> * Use `thumbnail/2` instead of `resize/2` when possible - it's optimized for common cases\n> * Chain operations to avoid intermediate file I/O\n> * For batch processing, reuse loaded ICC profiles and watermarks\n> * Consider using sequential mode for large images","ref":"Vix.Vips.Operation.html#module-performance-tips-tip"},{"type":"module","title":"Additional Resources - Vix.Vips.Operation","doc":"* [VIPS Documentation](https://www.libvips.org/API/current/)\n\n<!-- TODO: Add section about memory management best practices -->\n<!-- TODO: Add examples for animation handling -->\n<!-- TODO: Document format-specific options for loading/saving -->\n<!-- TODO: Add common recipes for web image optimization -->","ref":"Vix.Vips.Operation.html#module-additional-resources"},{"type":"function","title":"Vix.Vips.Operation.abs/1","doc":"Absolute value of an image","ref":"Vix.Vips.Operation.html#abs/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.abs/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#abs/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.abs!/1","doc":"Absolute value of an image","ref":"Vix.Vips.Operation.html#abs!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.abs!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#abs!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.add/2","doc":"Add two images","ref":"Vix.Vips.Operation.html#add/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.add/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#add/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.add!/2","doc":"Add two images","ref":"Vix.Vips.Operation.html#add!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.add!/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#add!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.affine/3","doc":"Affine transform of an image","ref":"Vix.Vips.Operation.html#affine/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.affine/3","doc":"* input - Input image argument\n  * matrix - Transformation matrix","ref":"Vix.Vips.Operation.html#affine/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.affine/3","doc":"* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BACKGROUND`\n* premultiplied - Images have premultiplied alpha. Default: `false`\n* background - Background value. Default: `nil`\n* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* ody - Vertical output displacement. Default: `0.0`\n* odx - Horizontal output displacement. Default: `0.0`\n* oarea - Area of output to generate. Default: `nil`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#affine/3-optional"},{"type":"function","title":"Vix.Vips.Operation.affine!/3","doc":"Affine transform of an image","ref":"Vix.Vips.Operation.html#affine!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.affine!/3","doc":"* input - Input image argument\n  * matrix - Transformation matrix","ref":"Vix.Vips.Operation.html#affine!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.affine!/3","doc":"* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BACKGROUND`\n* premultiplied - Images have premultiplied alpha. Default: `false`\n* background - Background value. Default: `nil`\n* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* ody - Vertical output displacement. Default: `0.0`\n* odx - Horizontal output displacement. Default: `0.0`\n* oarea - Area of output to generate. Default: `nil`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#affine!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.arrayjoin/2","doc":"Join an array of images","ref":"Vix.Vips.Operation.html#arrayjoin/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.arrayjoin/2","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#arrayjoin/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.arrayjoin/2","doc":"* vspacing - Vertical spacing between images. Default: `1`\n* hspacing - Horizontal spacing between images. Default: `1`\n* valign - Align on the top, centre or bottom. Default: `:VIPS_ALIGN_LOW`\n* halign - Align on the left, centre or right. Default: `:VIPS_ALIGN_LOW`\n* background - Colour for new pixels. Default: `nil`\n* shim - Pixels between images. Default: `0`\n* across - Number of images across grid. Default: `1`","ref":"Vix.Vips.Operation.html#arrayjoin/2-optional"},{"type":"function","title":"Vix.Vips.Operation.arrayjoin!/2","doc":"Join an array of images","ref":"Vix.Vips.Operation.html#arrayjoin!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.arrayjoin!/2","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#arrayjoin!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.arrayjoin!/2","doc":"* vspacing - Vertical spacing between images. Default: `1`\n* hspacing - Horizontal spacing between images. Default: `1`\n* valign - Align on the top, centre or bottom. Default: `:VIPS_ALIGN_LOW`\n* halign - Align on the left, centre or right. Default: `:VIPS_ALIGN_LOW`\n* background - Colour for new pixels. Default: `nil`\n* shim - Pixels between images. Default: `0`\n* across - Number of images across grid. Default: `1`","ref":"Vix.Vips.Operation.html#arrayjoin!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.autorot/1","doc":"Autorotate image by exif tag","ref":"Vix.Vips.Operation.html#autorot/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.autorot/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#autorot/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.autorot/1","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flip - Whether the image was flipped or not. (`boolean()`)\n* angle - Angle image was rotated by. (`vips_angle`)","ref":"Vix.Vips.Operation.html#autorot/1-returns"},{"type":"function","title":"Vix.Vips.Operation.autorot!/1","doc":"Autorotate image by exif tag","ref":"Vix.Vips.Operation.html#autorot!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.autorot!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#autorot!/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.autorot!/1","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flip - Whether the image was flipped or not. (`boolean()`)\n* angle - Angle image was rotated by. (`vips_angle`)","ref":"Vix.Vips.Operation.html#autorot!/1-returns"},{"type":"function","title":"Vix.Vips.Operation.avg/1","doc":"Find image average","ref":"Vix.Vips.Operation.html#avg/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.avg/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#avg/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.avg!/1","doc":"Find image average","ref":"Vix.Vips.Operation.html#avg!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.avg!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#avg!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandbool/2","doc":"Boolean operation across image bands","ref":"Vix.Vips.Operation.html#bandbool/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandbool/2","doc":"* input - Input image argument\n  * boolean - Boolean to perform","ref":"Vix.Vips.Operation.html#bandbool/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandbool!/2","doc":"Boolean operation across image bands","ref":"Vix.Vips.Operation.html#bandbool!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandbool!/2","doc":"* input - Input image argument\n  * boolean - Boolean to perform","ref":"Vix.Vips.Operation.html#bandbool!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandfold/2","doc":"Fold up x axis into bands","ref":"Vix.Vips.Operation.html#bandfold/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandfold/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#bandfold/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.bandfold/2","doc":"* factor - Fold by this factor. Default: `0`","ref":"Vix.Vips.Operation.html#bandfold/2-optional"},{"type":"function","title":"Vix.Vips.Operation.bandfold!/2","doc":"Fold up x axis into bands","ref":"Vix.Vips.Operation.html#bandfold!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandfold!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#bandfold!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.bandfold!/2","doc":"* factor - Fold by this factor. Default: `0`","ref":"Vix.Vips.Operation.html#bandfold!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.bandjoin/1","doc":"Bandwise join a set of images","ref":"Vix.Vips.Operation.html#bandjoin/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandjoin/1","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#bandjoin/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandjoin!/1","doc":"Bandwise join a set of images","ref":"Vix.Vips.Operation.html#bandjoin!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandjoin!/1","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#bandjoin!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandjoin_const/2","doc":"Append a constant band to an image","ref":"Vix.Vips.Operation.html#bandjoin_const/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandjoin_const/2","doc":"* input - Input image\n  * c - Array of constants to add","ref":"Vix.Vips.Operation.html#bandjoin_const/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandjoin_const!/2","doc":"Append a constant band to an image","ref":"Vix.Vips.Operation.html#bandjoin_const!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandjoin_const!/2","doc":"* input - Input image\n  * c - Array of constants to add","ref":"Vix.Vips.Operation.html#bandjoin_const!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandmean/1","doc":"Band-wise average","ref":"Vix.Vips.Operation.html#bandmean/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandmean/1","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#bandmean/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandmean!/1","doc":"Band-wise average","ref":"Vix.Vips.Operation.html#bandmean!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandmean!/1","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#bandmean!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.bandrank/2","doc":"Band-wise rank of a set of images","ref":"Vix.Vips.Operation.html#bandrank/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandrank/2","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#bandrank/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.bandrank/2","doc":"* index - Select this band element from sorted list. Default: `-1`","ref":"Vix.Vips.Operation.html#bandrank/2-optional"},{"type":"function","title":"Vix.Vips.Operation.bandrank!/2","doc":"Band-wise rank of a set of images","ref":"Vix.Vips.Operation.html#bandrank!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandrank!/2","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#bandrank!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.bandrank!/2","doc":"* index - Select this band element from sorted list. Default: `-1`","ref":"Vix.Vips.Operation.html#bandrank!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.bandunfold/2","doc":"Unfold image bands into x axis","ref":"Vix.Vips.Operation.html#bandunfold/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandunfold/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#bandunfold/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.bandunfold/2","doc":"* factor - Unfold by this factor. Default: `0`","ref":"Vix.Vips.Operation.html#bandunfold/2-optional"},{"type":"function","title":"Vix.Vips.Operation.bandunfold!/2","doc":"Unfold image bands into x axis","ref":"Vix.Vips.Operation.html#bandunfold!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.bandunfold!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#bandunfold!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.bandunfold!/2","doc":"* factor - Unfold by this factor. Default: `0`","ref":"Vix.Vips.Operation.html#bandunfold!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.black/3","doc":"Make a black image","ref":"Vix.Vips.Operation.html#black/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.black/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#black/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.black/3","doc":"* bands - Number of bands in image. Default: `1`","ref":"Vix.Vips.Operation.html#black/3-optional"},{"type":"function","title":"Vix.Vips.Operation.black!/3","doc":"Make a black image","ref":"Vix.Vips.Operation.html#black!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.black!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#black!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.black!/3","doc":"* bands - Number of bands in image. Default: `1`","ref":"Vix.Vips.Operation.html#black!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.boolean/3","doc":"Boolean operation on two images","ref":"Vix.Vips.Operation.html#boolean/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.boolean/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * boolean - Boolean to perform","ref":"Vix.Vips.Operation.html#boolean/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.boolean!/3","doc":"Boolean operation on two images","ref":"Vix.Vips.Operation.html#boolean!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.boolean!/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * boolean - Boolean to perform","ref":"Vix.Vips.Operation.html#boolean!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.boolean_const/3","doc":"Boolean operations against a constant","ref":"Vix.Vips.Operation.html#boolean_const/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.boolean_const/3","doc":"* input - Input image\n  * boolean - Boolean to perform\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#boolean_const/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.boolean_const!/3","doc":"Boolean operations against a constant","ref":"Vix.Vips.Operation.html#boolean_const!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.boolean_const!/3","doc":"* input - Input image\n  * boolean - Boolean to perform\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#boolean_const!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.buildlut/1","doc":"Build a look-up table","ref":"Vix.Vips.Operation.html#buildlut/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.buildlut/1","doc":"* input - Matrix of XY coordinates","ref":"Vix.Vips.Operation.html#buildlut/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.buildlut!/1","doc":"Build a look-up table","ref":"Vix.Vips.Operation.html#buildlut!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.buildlut!/1","doc":"* input - Matrix of XY coordinates","ref":"Vix.Vips.Operation.html#buildlut!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.byteswap/1","doc":"Byteswap an image","ref":"Vix.Vips.Operation.html#byteswap/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.byteswap/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#byteswap/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.byteswap!/1","doc":"Byteswap an image","ref":"Vix.Vips.Operation.html#byteswap!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.byteswap!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#byteswap!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.cache/2","doc":"Cache an image","ref":"Vix.Vips.Operation.html#cache/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cache/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#cache/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.cache/2","doc":"* tile-width - Tile width in pixels. Default: `128`\n* tile-height - Tile height in pixels. Default: `128`\n* max-tiles - Maximum number of tiles to cache. Default: `1000`","ref":"Vix.Vips.Operation.html#cache/2-optional"},{"type":"function","title":"Vix.Vips.Operation.cache!/2","doc":"Cache an image","ref":"Vix.Vips.Operation.html#cache!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cache!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#cache!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.cache!/2","doc":"* tile-width - Tile width in pixels. Default: `128`\n* tile-height - Tile height in pixels. Default: `128`\n* max-tiles - Maximum number of tiles to cache. Default: `1000`","ref":"Vix.Vips.Operation.html#cache!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.canny/2","doc":"Canny edge detector","ref":"Vix.Vips.Operation.html#canny/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.canny/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#canny/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.canny/2","doc":"* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`\n* sigma - Sigma of Gaussian. Default: `1.4`","ref":"Vix.Vips.Operation.html#canny/2-optional"},{"type":"function","title":"Vix.Vips.Operation.canny!/2","doc":"Canny edge detector","ref":"Vix.Vips.Operation.html#canny!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.canny!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#canny!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.canny!/2","doc":"* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`\n* sigma - Sigma of Gaussian. Default: `1.4`","ref":"Vix.Vips.Operation.html#canny!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.case/2","doc":"Use pixel values to pick cases from an array of images","ref":"Vix.Vips.Operation.html#case/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.case/2","doc":"* index - Index image\n  * cases - Array of case images","ref":"Vix.Vips.Operation.html#case/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.case!/2","doc":"Use pixel values to pick cases from an array of images","ref":"Vix.Vips.Operation.html#case!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.case!/2","doc":"* index - Index image\n  * cases - Array of case images","ref":"Vix.Vips.Operation.html#case!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.cast/3","doc":"Cast an image","ref":"Vix.Vips.Operation.html#cast/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cast/3","doc":"* input - Input image\n  * format - Format to cast to","ref":"Vix.Vips.Operation.html#cast/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.cast/3","doc":"* shift - Shift integer values up and down. Default: `false`","ref":"Vix.Vips.Operation.html#cast/3-optional"},{"type":"function","title":"Vix.Vips.Operation.cast!/3","doc":"Cast an image","ref":"Vix.Vips.Operation.html#cast!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cast!/3","doc":"* input - Input image\n  * format - Format to cast to","ref":"Vix.Vips.Operation.html#cast!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.cast!/3","doc":"* shift - Shift integer values up and down. Default: `false`","ref":"Vix.Vips.Operation.html#cast!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.cmc2lch/1","doc":"Transform lch to cmc","ref":"Vix.Vips.Operation.html#cmc2lch/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cmc2lch/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#cmc2lch/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.cmc2lch!/1","doc":"Transform lch to cmc","ref":"Vix.Vips.Operation.html#cmc2lch!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cmc2lch!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#cmc2lch!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.cmyk2xyz/1","doc":"Transform cmyk to xyz","ref":"Vix.Vips.Operation.html#cmyk2xyz/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cmyk2xyz/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#cmyk2xyz/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.cmyk2xyz!/1","doc":"Transform cmyk to xyz","ref":"Vix.Vips.Operation.html#cmyk2xyz!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.cmyk2xyz!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#cmyk2xyz!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.colourspace/3","doc":"Convert to a new colorspace","ref":"Vix.Vips.Operation.html#colourspace/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.colourspace/3","doc":"* input - Input image\n  * space - Destination color space","ref":"Vix.Vips.Operation.html#colourspace/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.colourspace/3","doc":"* source-space - Source color space. Default: `:VIPS_INTERPRETATION_sRGB`","ref":"Vix.Vips.Operation.html#colourspace/3-optional"},{"type":"function","title":"Vix.Vips.Operation.colourspace!/3","doc":"Convert to a new colorspace","ref":"Vix.Vips.Operation.html#colourspace!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.colourspace!/3","doc":"* input - Input image\n  * space - Destination color space","ref":"Vix.Vips.Operation.html#colourspace!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.colourspace!/3","doc":"* source-space - Source color space. Default: `:VIPS_INTERPRETATION_sRGB`","ref":"Vix.Vips.Operation.html#colourspace!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.compass/3","doc":"Convolve with rotating mask","ref":"Vix.Vips.Operation.html#compass/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.compass/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#compass/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.compass/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`\n* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`\n* combine - Combine convolution results like this. Default: `:VIPS_COMBINE_MAX`\n* angle - Rotate mask by this much between convolutions. Default: `:VIPS_ANGLE45_D90`\n* times - Rotate and convolve this many times. Default: `2`","ref":"Vix.Vips.Operation.html#compass/3-optional"},{"type":"function","title":"Vix.Vips.Operation.compass!/3","doc":"Convolve with rotating mask","ref":"Vix.Vips.Operation.html#compass!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.compass!/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#compass!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.compass!/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`\n* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`\n* combine - Combine convolution results like this. Default: `:VIPS_COMBINE_MAX`\n* angle - Rotate mask by this much between convolutions. Default: `:VIPS_ANGLE45_D90`\n* times - Rotate and convolve this many times. Default: `2`","ref":"Vix.Vips.Operation.html#compass!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.complex2/3","doc":"Complex binary operations on two images","ref":"Vix.Vips.Operation.html#complex2/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complex2/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * cmplx - Binary complex operation to perform","ref":"Vix.Vips.Operation.html#complex2/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.complex2!/3","doc":"Complex binary operations on two images","ref":"Vix.Vips.Operation.html#complex2!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complex2!/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * cmplx - Binary complex operation to perform","ref":"Vix.Vips.Operation.html#complex2!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.complex/2","doc":"Perform a complex operation on an image","ref":"Vix.Vips.Operation.html#complex/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complex/2","doc":"* input - Input image\n  * cmplx - Complex to perform","ref":"Vix.Vips.Operation.html#complex/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.complex!/2","doc":"Perform a complex operation on an image","ref":"Vix.Vips.Operation.html#complex!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complex!/2","doc":"* input - Input image\n  * cmplx - Complex to perform","ref":"Vix.Vips.Operation.html#complex!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.complexform/2","doc":"Form a complex image from two real images","ref":"Vix.Vips.Operation.html#complexform/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complexform/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#complexform/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.complexform!/2","doc":"Form a complex image from two real images","ref":"Vix.Vips.Operation.html#complexform!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complexform!/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#complexform!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.complexget/2","doc":"Get a component from a complex image","ref":"Vix.Vips.Operation.html#complexget/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complexget/2","doc":"* input - Input image\n  * get - Complex to perform","ref":"Vix.Vips.Operation.html#complexget/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.complexget!/2","doc":"Get a component from a complex image","ref":"Vix.Vips.Operation.html#complexget!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.complexget!/2","doc":"* input - Input image\n  * get - Complex to perform","ref":"Vix.Vips.Operation.html#complexget!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.composite2/4","doc":"Blend a pair of images with a blend mode","ref":"Vix.Vips.Operation.html#composite2/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.composite2/4","doc":"* base - Base image\n  * overlay - Overlay image\n  * mode - VipsBlendMode to join with","ref":"Vix.Vips.Operation.html#composite2/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.composite2/4","doc":"* premultiplied - Images have premultiplied alpha. Default: `false`\n* compositing-space - Composite images in this colour space. Default: `:VIPS_INTERPRETATION_sRGB`\n* y - y position of overlay. Default: `0`\n* x - x position of overlay. Default: `0`","ref":"Vix.Vips.Operation.html#composite2/4-optional"},{"type":"function","title":"Vix.Vips.Operation.composite2!/4","doc":"Blend a pair of images with a blend mode","ref":"Vix.Vips.Operation.html#composite2!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.composite2!/4","doc":"* base - Base image\n  * overlay - Overlay image\n  * mode - VipsBlendMode to join with","ref":"Vix.Vips.Operation.html#composite2!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.composite2!/4","doc":"* premultiplied - Images have premultiplied alpha. Default: `false`\n* compositing-space - Composite images in this colour space. Default: `:VIPS_INTERPRETATION_sRGB`\n* y - y position of overlay. Default: `0`\n* x - x position of overlay. Default: `0`","ref":"Vix.Vips.Operation.html#composite2!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.composite/3","doc":"Blend an array of images with an array of blend modes","ref":"Vix.Vips.Operation.html#composite/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.composite/3","doc":"* input - Array of input images\n  * mode - Array of VipsBlendMode to join with","ref":"Vix.Vips.Operation.html#composite/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.composite/3","doc":"* premultiplied - Images have premultiplied alpha. Default: `false`\n* compositing-space - Composite images in this colour space. Default: `:VIPS_INTERPRETATION_sRGB`\n* y - Array of y coordinates to join at. Default: `nil`\n* x - Array of x coordinates to join at. Default: `nil`","ref":"Vix.Vips.Operation.html#composite/3-optional"},{"type":"function","title":"Vix.Vips.Operation.composite!/3","doc":"Blend an array of images with an array of blend modes","ref":"Vix.Vips.Operation.html#composite!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.composite!/3","doc":"* input - Array of input images\n  * mode - Array of VipsBlendMode to join with","ref":"Vix.Vips.Operation.html#composite!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.composite!/3","doc":"* premultiplied - Images have premultiplied alpha. Default: `false`\n* compositing-space - Composite images in this colour space. Default: `:VIPS_INTERPRETATION_sRGB`\n* y - Array of y coordinates to join at. Default: `nil`\n* x - Array of x coordinates to join at. Default: `nil`","ref":"Vix.Vips.Operation.html#composite!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.conv/3","doc":"Convolution operation","ref":"Vix.Vips.Operation.html#conv/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.conv/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#conv/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.conv/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`\n* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`","ref":"Vix.Vips.Operation.html#conv/3-optional"},{"type":"function","title":"Vix.Vips.Operation.conv!/3","doc":"Convolution operation","ref":"Vix.Vips.Operation.html#conv!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.conv!/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#conv!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.conv!/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`\n* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`","ref":"Vix.Vips.Operation.html#conv!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.conva/3","doc":"Approximate integer convolution","ref":"Vix.Vips.Operation.html#conva/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.conva/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#conva/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.conva/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`","ref":"Vix.Vips.Operation.html#conva/3-optional"},{"type":"function","title":"Vix.Vips.Operation.conva!/3","doc":"Approximate integer convolution","ref":"Vix.Vips.Operation.html#conva!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.conva!/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#conva!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.conva!/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`","ref":"Vix.Vips.Operation.html#conva!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.convasep/3","doc":"Approximate separable integer convolution","ref":"Vix.Vips.Operation.html#convasep/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convasep/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convasep/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.convasep/3","doc":"* layers - Use this many layers in approximation. Default: `5`","ref":"Vix.Vips.Operation.html#convasep/3-optional"},{"type":"function","title":"Vix.Vips.Operation.convasep!/3","doc":"Approximate separable integer convolution","ref":"Vix.Vips.Operation.html#convasep!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convasep!/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convasep!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.convasep!/3","doc":"* layers - Use this many layers in approximation. Default: `5`","ref":"Vix.Vips.Operation.html#convasep!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.convf/2","doc":"Float convolution operation","ref":"Vix.Vips.Operation.html#convf/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convf/2","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convf/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.convf!/2","doc":"Float convolution operation","ref":"Vix.Vips.Operation.html#convf!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convf!/2","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convf!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.convi/2","doc":"Int convolution operation","ref":"Vix.Vips.Operation.html#convi/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convi/2","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convi/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.convi!/2","doc":"Int convolution operation","ref":"Vix.Vips.Operation.html#convi!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convi!/2","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convi!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.convsep/3","doc":"Separable convolution operation","ref":"Vix.Vips.Operation.html#convsep/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convsep/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convsep/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.convsep/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`\n* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`","ref":"Vix.Vips.Operation.html#convsep/3-optional"},{"type":"function","title":"Vix.Vips.Operation.convsep!/3","doc":"Separable convolution operation","ref":"Vix.Vips.Operation.html#convsep!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.convsep!/3","doc":"* input - Input image argument\n  * mask - Input matrix image","ref":"Vix.Vips.Operation.html#convsep!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.convsep!/3","doc":"* cluster - Cluster lines closer than this in approximation. Default: `1`\n* layers - Use this many layers in approximation. Default: `5`\n* precision - Convolve with this precision. Default: `:VIPS_PRECISION_FLOAT`","ref":"Vix.Vips.Operation.html#convsep!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.copy/2","doc":"Copy an image","ref":"Vix.Vips.Operation.html#copy/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.copy/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#copy/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.copy/2","doc":"* yoffset - Vertical offset of origin. Default: `0`\n* xoffset - Horizontal offset of origin. Default: `0`\n* yres - Vertical resolution in pixels/mm. Default: `0.0`\n* xres - Horizontal resolution in pixels/mm. Default: `0.0`\n* interpretation - Pixel interpretation. Default: `:VIPS_INTERPRETATION_MULTIBAND`\n* coding - Pixel coding. Default: `:VIPS_CODING_NONE`\n* format - Pixel format in image. Default: `:VIPS_FORMAT_UCHAR`\n* bands - Number of bands in image. Default: `0`\n* height - Image height in pixels. Default: `0`\n* width - Image width in pixels. Default: `0`\n* swap - Swap bytes in image between little and big-endian. Default: `false`","ref":"Vix.Vips.Operation.html#copy/2-optional"},{"type":"function","title":"Vix.Vips.Operation.copy!/2","doc":"Copy an image","ref":"Vix.Vips.Operation.html#copy!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.copy!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#copy!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.copy!/2","doc":"* yoffset - Vertical offset of origin. Default: `0`\n* xoffset - Horizontal offset of origin. Default: `0`\n* yres - Vertical resolution in pixels/mm. Default: `0.0`\n* xres - Horizontal resolution in pixels/mm. Default: `0.0`\n* interpretation - Pixel interpretation. Default: `:VIPS_INTERPRETATION_MULTIBAND`\n* coding - Pixel coding. Default: `:VIPS_CODING_NONE`\n* format - Pixel format in image. Default: `:VIPS_FORMAT_UCHAR`\n* bands - Number of bands in image. Default: `0`\n* height - Image height in pixels. Default: `0`\n* width - Image width in pixels. Default: `0`\n* swap - Swap bytes in image between little and big-endian. Default: `false`","ref":"Vix.Vips.Operation.html#copy!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.countlines/2","doc":"Count lines in an image","ref":"Vix.Vips.Operation.html#countlines/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.countlines/2","doc":"* input - Input image argument\n  * direction - Countlines left-right or up-down","ref":"Vix.Vips.Operation.html#countlines/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.countlines!/2","doc":"Count lines in an image","ref":"Vix.Vips.Operation.html#countlines!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.countlines!/2","doc":"* input - Input image argument\n  * direction - Countlines left-right or up-down","ref":"Vix.Vips.Operation.html#countlines!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.csvload/2","doc":"Load csv","ref":"Vix.Vips.Operation.html#csvload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.csvload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#csvload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.csvload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* separator - Set of separator characters. Default: `\";,\\t\"`\n* whitespace - Set of whitespace characters. Default: `\" \"`\n* lines - Read this many lines from the file. Default: `0`\n* skip - Skip this many lines at the start of the file. Default: `0`","ref":"Vix.Vips.Operation.html#csvload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.csvload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#csvload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.csvload!/2","doc":"Load csv","ref":"Vix.Vips.Operation.html#csvload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.csvload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#csvload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.csvload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* separator - Set of separator characters. Default: `\";,\\t\"`\n* whitespace - Set of whitespace characters. Default: `\" \"`\n* lines - Read this many lines from the file. Default: `0`\n* skip - Skip this many lines at the start of the file. Default: `0`","ref":"Vix.Vips.Operation.html#csvload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.csvload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#csvload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.csvsave/3","doc":"Save image to csv","ref":"Vix.Vips.Operation.html#csvsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.csvsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#csvsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.csvsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* separator - Separator characters. Default: `\"\\t\"`","ref":"Vix.Vips.Operation.html#csvsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.csvsave!/3","doc":"Save image to csv","ref":"Vix.Vips.Operation.html#csvsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.csvsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#csvsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.csvsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* separator - Separator characters. Default: `\"\\t\"`","ref":"Vix.Vips.Operation.html#csvsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.de00/2","doc":"Calculate de00","ref":"Vix.Vips.Operation.html#de00/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.de00/2","doc":"* left - Left-hand input image\n  * right - Right-hand input image","ref":"Vix.Vips.Operation.html#de00/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.de00!/2","doc":"Calculate de00","ref":"Vix.Vips.Operation.html#de00!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.de00!/2","doc":"* left - Left-hand input image\n  * right - Right-hand input image","ref":"Vix.Vips.Operation.html#de00!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.de76/2","doc":"Calculate de76","ref":"Vix.Vips.Operation.html#de76/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.de76/2","doc":"* left - Left-hand input image\n  * right - Right-hand input image","ref":"Vix.Vips.Operation.html#de76/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.de76!/2","doc":"Calculate de76","ref":"Vix.Vips.Operation.html#de76!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.de76!/2","doc":"* left - Left-hand input image\n  * right - Right-hand input image","ref":"Vix.Vips.Operation.html#de76!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.decmc/2","doc":"Calculate decmc","ref":"Vix.Vips.Operation.html#decmc/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.decmc/2","doc":"* left - Left-hand input image\n  * right - Right-hand input image","ref":"Vix.Vips.Operation.html#decmc/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.decmc!/2","doc":"Calculate decmc","ref":"Vix.Vips.Operation.html#decmc!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.decmc!/2","doc":"* left - Left-hand input image\n  * right - Right-hand input image","ref":"Vix.Vips.Operation.html#decmc!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.deviate/1","doc":"Find image standard deviation","ref":"Vix.Vips.Operation.html#deviate/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.deviate/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#deviate/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.deviate!/1","doc":"Find image standard deviation","ref":"Vix.Vips.Operation.html#deviate!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.deviate!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#deviate!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.divide/2","doc":"Divide two images","ref":"Vix.Vips.Operation.html#divide/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.divide/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#divide/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.divide!/2","doc":"Divide two images","ref":"Vix.Vips.Operation.html#divide!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.divide!/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#divide!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.dzsave/3","doc":"Save image to deepzoom file","ref":"Vix.Vips.Operation.html#dzsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.dzsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#dzsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.dzsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* basename - Base name to save to. Default: `nil`\n* no-strip - Don't strip tile metadata. Default: `false`\n* Q - Q factor. Default: `75`\n* id - Resource ID. Default: `\"https://example.com/iiif\"`\n* skip-blanks - Skip tiles which are nearly equal to the background. Default: `-1`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* compression - ZIP deflate compression level. Default: `0`\n* properties - Write a properties file to the output directory. Default: `false`\n* container - Pyramid container type. Default: `:VIPS_FOREIGN_DZ_CONTAINER_FS`\n* angle - Rotate image during save. Default: `:VIPS_ANGLE_D0`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONEPIXEL`\n* centre - Center image in tile. Default: `false`\n* tile-width - Tile width in pixels. Default: `254`\n* tile-height - Tile height in pixels. Default: `254`\n* tile-size - Tile size in pixels. Default: `254`\n* overlap - Tile overlap in pixels. Default: `1`\n* suffix - Filename suffix for tiles. Default: `\".jpeg\"`\n* layout - Directory layout. Default: `:VIPS_FOREIGN_DZ_LAYOUT_DZ`\n* imagename - Image name. Default: `nil`\n* dirname - Directory name to save to. Default: `nil`","ref":"Vix.Vips.Operation.html#dzsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.dzsave!/3","doc":"Save image to deepzoom file","ref":"Vix.Vips.Operation.html#dzsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.dzsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#dzsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.dzsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* basename - Base name to save to. Default: `nil`\n* no-strip - Don't strip tile metadata. Default: `false`\n* Q - Q factor. Default: `75`\n* id - Resource ID. Default: `\"https://example.com/iiif\"`\n* skip-blanks - Skip tiles which are nearly equal to the background. Default: `-1`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* compression - ZIP deflate compression level. Default: `0`\n* properties - Write a properties file to the output directory. Default: `false`\n* container - Pyramid container type. Default: `:VIPS_FOREIGN_DZ_CONTAINER_FS`\n* angle - Rotate image during save. Default: `:VIPS_ANGLE_D0`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONEPIXEL`\n* centre - Center image in tile. Default: `false`\n* tile-width - Tile width in pixels. Default: `254`\n* tile-height - Tile height in pixels. Default: `254`\n* tile-size - Tile size in pixels. Default: `254`\n* overlap - Tile overlap in pixels. Default: `1`\n* suffix - Filename suffix for tiles. Default: `\".jpeg\"`\n* layout - Directory layout. Default: `:VIPS_FOREIGN_DZ_LAYOUT_DZ`\n* imagename - Image name. Default: `nil`\n* dirname - Directory name to save to. Default: `nil`","ref":"Vix.Vips.Operation.html#dzsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.dzsave_buffer/2","doc":"Save image to dz buffer","ref":"Vix.Vips.Operation.html#dzsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.dzsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#dzsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.dzsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* basename - Base name to save to. Default: `nil`\n* no-strip - Don't strip tile metadata. Default: `false`\n* Q - Q factor. Default: `75`\n* id - Resource ID. Default: `\"https://example.com/iiif\"`\n* skip-blanks - Skip tiles which are nearly equal to the background. Default: `-1`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* compression - ZIP deflate compression level. Default: `0`\n* properties - Write a properties file to the output directory. Default: `false`\n* container - Pyramid container type. Default: `:VIPS_FOREIGN_DZ_CONTAINER_FS`\n* angle - Rotate image during save. Default: `:VIPS_ANGLE_D0`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONEPIXEL`\n* centre - Center image in tile. Default: `false`\n* tile-width - Tile width in pixels. Default: `254`\n* tile-height - Tile height in pixels. Default: `254`\n* tile-size - Tile size in pixels. Default: `254`\n* overlap - Tile overlap in pixels. Default: `1`\n* suffix - Filename suffix for tiles. Default: `\".jpeg\"`\n* layout - Directory layout. Default: `:VIPS_FOREIGN_DZ_LAYOUT_DZ`\n* imagename - Image name. Default: `nil`\n* dirname - Directory name to save to. Default: `nil`","ref":"Vix.Vips.Operation.html#dzsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.dzsave_buffer!/2","doc":"Save image to dz buffer","ref":"Vix.Vips.Operation.html#dzsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.dzsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#dzsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.dzsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* basename - Base name to save to. Default: `nil`\n* no-strip - Don't strip tile metadata. Default: `false`\n* Q - Q factor. Default: `75`\n* id - Resource ID. Default: `\"https://example.com/iiif\"`\n* skip-blanks - Skip tiles which are nearly equal to the background. Default: `-1`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* compression - ZIP deflate compression level. Default: `0`\n* properties - Write a properties file to the output directory. Default: `false`\n* container - Pyramid container type. Default: `:VIPS_FOREIGN_DZ_CONTAINER_FS`\n* angle - Rotate image during save. Default: `:VIPS_ANGLE_D0`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONEPIXEL`\n* centre - Center image in tile. Default: `false`\n* tile-width - Tile width in pixels. Default: `254`\n* tile-height - Tile height in pixels. Default: `254`\n* tile-size - Tile size in pixels. Default: `254`\n* overlap - Tile overlap in pixels. Default: `1`\n* suffix - Filename suffix for tiles. Default: `\".jpeg\"`\n* layout - Directory layout. Default: `:VIPS_FOREIGN_DZ_LAYOUT_DZ`\n* imagename - Image name. Default: `nil`\n* dirname - Directory name to save to. Default: `nil`","ref":"Vix.Vips.Operation.html#dzsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.embed/6","doc":"Embed an image in a larger image","ref":"Vix.Vips.Operation.html#embed/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.embed/6","doc":"* input - Input image\n  * x - Left edge of input in output\n  * y - Top edge of input in output\n  * width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#embed/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.embed/6","doc":"* background - Color for background pixels. Default: `nil`\n* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BLACK`","ref":"Vix.Vips.Operation.html#embed/6-optional"},{"type":"function","title":"Vix.Vips.Operation.embed!/6","doc":"Embed an image in a larger image","ref":"Vix.Vips.Operation.html#embed!/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.embed!/6","doc":"* input - Input image\n  * x - Left edge of input in output\n  * y - Top edge of input in output\n  * width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#embed!/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.embed!/6","doc":"* background - Color for background pixels. Default: `nil`\n* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BLACK`","ref":"Vix.Vips.Operation.html#embed!/6-optional"},{"type":"function","title":"Vix.Vips.Operation.extract_area/5","doc":"Extract an area from an image","ref":"Vix.Vips.Operation.html#extract_area/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.extract_area/5","doc":"* input - Input image\n  * left - Left edge of extract area\n  * top - Top edge of extract area\n  * width - Width of extract area\n  * height - Height of extract area","ref":"Vix.Vips.Operation.html#extract_area/5-arguments"},{"type":"function","title":"Vix.Vips.Operation.extract_area!/5","doc":"Extract an area from an image","ref":"Vix.Vips.Operation.html#extract_area!/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.extract_area!/5","doc":"* input - Input image\n  * left - Left edge of extract area\n  * top - Top edge of extract area\n  * width - Width of extract area\n  * height - Height of extract area","ref":"Vix.Vips.Operation.html#extract_area!/5-arguments"},{"type":"function","title":"Vix.Vips.Operation.extract_band/3","doc":"Extract band from an image","ref":"Vix.Vips.Operation.html#extract_band/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.extract_band/3","doc":"* input - Input image\n  * band - Band to extract","ref":"Vix.Vips.Operation.html#extract_band/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.extract_band/3","doc":"* n - Number of bands to extract. Default: `1`","ref":"Vix.Vips.Operation.html#extract_band/3-optional"},{"type":"function","title":"Vix.Vips.Operation.extract_band!/3","doc":"Extract band from an image","ref":"Vix.Vips.Operation.html#extract_band!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.extract_band!/3","doc":"* input - Input image\n  * band - Band to extract","ref":"Vix.Vips.Operation.html#extract_band!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.extract_band!/3","doc":"* n - Number of bands to extract. Default: `1`","ref":"Vix.Vips.Operation.html#extract_band!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.eye/3","doc":"Make an image showing the eye's spatial response","ref":"Vix.Vips.Operation.html#eye/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.eye/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#eye/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.eye/3","doc":"* factor - Maximum spatial frequency. Default: `0.5`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#eye/3-optional"},{"type":"function","title":"Vix.Vips.Operation.eye!/3","doc":"Make an image showing the eye's spatial response","ref":"Vix.Vips.Operation.html#eye!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.eye!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#eye!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.eye!/3","doc":"* factor - Maximum spatial frequency. Default: `0.5`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#eye!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.falsecolour/1","doc":"False-color an image","ref":"Vix.Vips.Operation.html#falsecolour/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.falsecolour/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#falsecolour/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.falsecolour!/1","doc":"False-color an image","ref":"Vix.Vips.Operation.html#falsecolour!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.falsecolour!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#falsecolour!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.fastcor/2","doc":"Fast correlation","ref":"Vix.Vips.Operation.html#fastcor/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.fastcor/2","doc":"* input - Input image argument\n  * ref - Input reference image","ref":"Vix.Vips.Operation.html#fastcor/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.fastcor!/2","doc":"Fast correlation","ref":"Vix.Vips.Operation.html#fastcor!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.fastcor!/2","doc":"* input - Input image argument\n  * ref - Input reference image","ref":"Vix.Vips.Operation.html#fastcor!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.fill_nearest/1","doc":"Fill image zeros with nearest non-zero pixel","ref":"Vix.Vips.Operation.html#fill_nearest/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.fill_nearest/1","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#fill_nearest/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.fill_nearest/1","doc":"Operation returns a tuple\n\n* out - Value of nearest non-zero pixel. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* distance - Distance to nearest non-zero pixel. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#fill_nearest/1-returns"},{"type":"function","title":"Vix.Vips.Operation.fill_nearest!/1","doc":"Fill image zeros with nearest non-zero pixel","ref":"Vix.Vips.Operation.html#fill_nearest!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.fill_nearest!/1","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#fill_nearest!/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.fill_nearest!/1","doc":"Operation returns a tuple\n\n* out - Value of nearest non-zero pixel. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* distance - Distance to nearest non-zero pixel. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#fill_nearest!/1-returns"},{"type":"function","title":"Vix.Vips.Operation.find_trim/2","doc":"Search an image for non-edge areas","ref":"Vix.Vips.Operation.html#find_trim/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.find_trim/2","doc":"* input - Image to find_trim","ref":"Vix.Vips.Operation.html#find_trim/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.find_trim/2","doc":"* line-art - Enable line art mode. Default: `false`\n* background - Color for background pixels. Default: `nil`\n* threshold - Object threshold. Default: `10.0`","ref":"Vix.Vips.Operation.html#find_trim/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.find_trim/2","doc":"Operation returns a tuple\n\n* left - Left edge of image. (`integer()`)\n* top - Top edge of extract area. (`integer()`)\n* width - Width of extract area. (`integer()`)\n* height - Height of extract area. (`integer()`)","ref":"Vix.Vips.Operation.html#find_trim/2-returns"},{"type":"function","title":"Vix.Vips.Operation.find_trim!/2","doc":"Search an image for non-edge areas","ref":"Vix.Vips.Operation.html#find_trim!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.find_trim!/2","doc":"* input - Image to find_trim","ref":"Vix.Vips.Operation.html#find_trim!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.find_trim!/2","doc":"* line-art - Enable line art mode. Default: `false`\n* background - Color for background pixels. Default: `nil`\n* threshold - Object threshold. Default: `10.0`","ref":"Vix.Vips.Operation.html#find_trim!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.find_trim!/2","doc":"Operation returns a tuple\n\n* left - Left edge of image. (`integer()`)\n* top - Top edge of extract area. (`integer()`)\n* width - Width of extract area. (`integer()`)\n* height - Height of extract area. (`integer()`)","ref":"Vix.Vips.Operation.html#find_trim!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.flatten/2","doc":"Flatten alpha out of an image","ref":"Vix.Vips.Operation.html#flatten/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.flatten/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#flatten/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.flatten/2","doc":"* max-alpha - Maximum value of alpha channel. Default: `255.0`\n* background - Background value. Default: `nil`","ref":"Vix.Vips.Operation.html#flatten/2-optional"},{"type":"function","title":"Vix.Vips.Operation.flatten!/2","doc":"Flatten alpha out of an image","ref":"Vix.Vips.Operation.html#flatten!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.flatten!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#flatten!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.flatten!/2","doc":"* max-alpha - Maximum value of alpha channel. Default: `255.0`\n* background - Background value. Default: `nil`","ref":"Vix.Vips.Operation.html#flatten!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.flip/2","doc":"Flip an image","ref":"Vix.Vips.Operation.html#flip/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.flip/2","doc":"* input - Input image\n  * direction - Direction to flip image","ref":"Vix.Vips.Operation.html#flip/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.flip!/2","doc":"Flip an image","ref":"Vix.Vips.Operation.html#flip!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.flip!/2","doc":"* input - Input image\n  * direction - Direction to flip image","ref":"Vix.Vips.Operation.html#flip!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.float2rad/1","doc":"Transform float rgb to radiance coding","ref":"Vix.Vips.Operation.html#float2rad/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.float2rad/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#float2rad/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.float2rad!/1","doc":"Transform float rgb to radiance coding","ref":"Vix.Vips.Operation.html#float2rad!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.float2rad!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#float2rad!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.fractsurf/3","doc":"Make a fractal surface","ref":"Vix.Vips.Operation.html#fractsurf/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.fractsurf/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * fractal-dimension - Fractal dimension","ref":"Vix.Vips.Operation.html#fractsurf/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.fractsurf!/3","doc":"Make a fractal surface","ref":"Vix.Vips.Operation.html#fractsurf!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.fractsurf!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * fractal-dimension - Fractal dimension","ref":"Vix.Vips.Operation.html#fractsurf!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.freqmult/2","doc":"Frequency-domain filtering","ref":"Vix.Vips.Operation.html#freqmult/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.freqmult/2","doc":"* input - Input image\n  * mask - Input mask image","ref":"Vix.Vips.Operation.html#freqmult/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.freqmult!/2","doc":"Frequency-domain filtering","ref":"Vix.Vips.Operation.html#freqmult!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.freqmult!/2","doc":"* input - Input image\n  * mask - Input mask image","ref":"Vix.Vips.Operation.html#freqmult!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.gamma/2","doc":"Gamma an image","ref":"Vix.Vips.Operation.html#gamma/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gamma/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#gamma/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gamma/2","doc":"* exponent - Gamma factor. Default: `2.4`","ref":"Vix.Vips.Operation.html#gamma/2-optional"},{"type":"function","title":"Vix.Vips.Operation.gamma!/2","doc":"Gamma an image","ref":"Vix.Vips.Operation.html#gamma!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gamma!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#gamma!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gamma!/2","doc":"* exponent - Gamma factor. Default: `2.4`","ref":"Vix.Vips.Operation.html#gamma!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.gaussblur/3","doc":"Gaussian blur","ref":"Vix.Vips.Operation.html#gaussblur/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gaussblur/3","doc":"* input - Input image\n  * sigma - Sigma of Gaussian","ref":"Vix.Vips.Operation.html#gaussblur/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gaussblur/3","doc":"* precision - Convolve with this precision. Default: `:VIPS_PRECISION_INTEGER`\n* min-ampl - Minimum amplitude of Gaussian. Default: `0.2`","ref":"Vix.Vips.Operation.html#gaussblur/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gaussblur!/3","doc":"Gaussian blur","ref":"Vix.Vips.Operation.html#gaussblur!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gaussblur!/3","doc":"* input - Input image\n  * sigma - Sigma of Gaussian","ref":"Vix.Vips.Operation.html#gaussblur!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gaussblur!/3","doc":"* precision - Convolve with this precision. Default: `:VIPS_PRECISION_INTEGER`\n* min-ampl - Minimum amplitude of Gaussian. Default: `0.2`","ref":"Vix.Vips.Operation.html#gaussblur!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gaussmat/3","doc":"Make a gaussian image","ref":"Vix.Vips.Operation.html#gaussmat/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gaussmat/3","doc":"* sigma - Sigma of Gaussian\n  * min-ampl - Minimum amplitude of Gaussian","ref":"Vix.Vips.Operation.html#gaussmat/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gaussmat/3","doc":"* precision - Generate with this precision. Default: `:VIPS_PRECISION_INTEGER`\n* integer - Generate integer Gaussian. Default: `false`\n* separable - Generate separable Gaussian. Default: `false`","ref":"Vix.Vips.Operation.html#gaussmat/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gaussmat!/3","doc":"Make a gaussian image","ref":"Vix.Vips.Operation.html#gaussmat!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gaussmat!/3","doc":"* sigma - Sigma of Gaussian\n  * min-ampl - Minimum amplitude of Gaussian","ref":"Vix.Vips.Operation.html#gaussmat!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gaussmat!/3","doc":"* precision - Generate with this precision. Default: `:VIPS_PRECISION_INTEGER`\n* integer - Generate integer Gaussian. Default: `false`\n* separable - Generate separable Gaussian. Default: `false`","ref":"Vix.Vips.Operation.html#gaussmat!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gaussnoise/3","doc":"Make a gaussnoise image","ref":"Vix.Vips.Operation.html#gaussnoise/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gaussnoise/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#gaussnoise/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gaussnoise/3","doc":"* seed - Random number seed. Default: `0`\n* mean - Mean of pixels in generated image. Default: `128.0`\n* sigma - Standard deviation of pixels in generated image. Default: `30.0`","ref":"Vix.Vips.Operation.html#gaussnoise/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gaussnoise!/3","doc":"Make a gaussnoise image","ref":"Vix.Vips.Operation.html#gaussnoise!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gaussnoise!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#gaussnoise!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gaussnoise!/3","doc":"* seed - Random number seed. Default: `0`\n* mean - Mean of pixels in generated image. Default: `128.0`\n* sigma - Standard deviation of pixels in generated image. Default: `30.0`","ref":"Vix.Vips.Operation.html#gaussnoise!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.getpoint/3","doc":"Read a point from an image","ref":"Vix.Vips.Operation.html#getpoint/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.getpoint/3","doc":"* input - Input image\n  * x - Point to read\n  * y - Point to read","ref":"Vix.Vips.Operation.html#getpoint/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.getpoint!/3","doc":"Read a point from an image","ref":"Vix.Vips.Operation.html#getpoint!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.getpoint!/3","doc":"* input - Input image\n  * x - Point to read\n  * y - Point to read","ref":"Vix.Vips.Operation.html#getpoint!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.gifload/2","doc":"Load gif with libnsgif","ref":"Vix.Vips.Operation.html#gifload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#gifload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* page - First page to load. Default: `0`\n* n - Number of pages to load, -1 for all. Default: `1`","ref":"Vix.Vips.Operation.html#gifload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.gifload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#gifload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.gifload!/2","doc":"Load gif with libnsgif","ref":"Vix.Vips.Operation.html#gifload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#gifload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* page - First page to load. Default: `0`\n* n - Number of pages to load, -1 for all. Default: `1`","ref":"Vix.Vips.Operation.html#gifload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.gifload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#gifload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.gifload_buffer/2","doc":"Load gif with libnsgif","ref":"Vix.Vips.Operation.html#gifload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#gifload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* page - First page to load. Default: `0`\n* n - Number of pages to load, -1 for all. Default: `1`","ref":"Vix.Vips.Operation.html#gifload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.gifload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#gifload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.gifload_buffer!/2","doc":"Load gif with libnsgif","ref":"Vix.Vips.Operation.html#gifload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#gifload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* page - First page to load. Default: `0`\n* n - Number of pages to load, -1 for all. Default: `1`","ref":"Vix.Vips.Operation.html#gifload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.gifload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#gifload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.gifsave/3","doc":"Save as gif","ref":"Vix.Vips.Operation.html#gifsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#gifsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* reoptimise - Reoptimise colour palettes. Default: `false`\n* interlace - Generate an interlaced (progressive) GIF. Default: `false`\n* interpalette-maxerror - Maximum inter-palette error for palette reusage. Default: `3.0`\n* reuse - Reuse palette from input. Default: `false`\n* interframe-maxerror - Maximum inter-frame error for transparency. Default: `0.0`\n* bitdepth - Number of bits per pixel. Default: `8`\n* effort - Quantisation effort. Default: `7`\n* dither - Amount of dithering. Default: `1.0`","ref":"Vix.Vips.Operation.html#gifsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gifsave!/3","doc":"Save as gif","ref":"Vix.Vips.Operation.html#gifsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#gifsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* reoptimise - Reoptimise colour palettes. Default: `false`\n* interlace - Generate an interlaced (progressive) GIF. Default: `false`\n* interpalette-maxerror - Maximum inter-palette error for palette reusage. Default: `3.0`\n* reuse - Reuse palette from input. Default: `false`\n* interframe-maxerror - Maximum inter-frame error for transparency. Default: `0.0`\n* bitdepth - Number of bits per pixel. Default: `8`\n* effort - Quantisation effort. Default: `7`\n* dither - Amount of dithering. Default: `1.0`","ref":"Vix.Vips.Operation.html#gifsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.gifsave_buffer/2","doc":"Save as gif","ref":"Vix.Vips.Operation.html#gifsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#gifsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* reoptimise - Reoptimise colour palettes. Default: `false`\n* interlace - Generate an interlaced (progressive) GIF. Default: `false`\n* interpalette-maxerror - Maximum inter-palette error for palette reusage. Default: `3.0`\n* reuse - Reuse palette from input. Default: `false`\n* interframe-maxerror - Maximum inter-frame error for transparency. Default: `0.0`\n* bitdepth - Number of bits per pixel. Default: `8`\n* effort - Quantisation effort. Default: `7`\n* dither - Amount of dithering. Default: `1.0`","ref":"Vix.Vips.Operation.html#gifsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.gifsave_buffer!/2","doc":"Save as gif","ref":"Vix.Vips.Operation.html#gifsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gifsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#gifsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gifsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* reoptimise - Reoptimise colour palettes. Default: `false`\n* interlace - Generate an interlaced (progressive) GIF. Default: `false`\n* interpalette-maxerror - Maximum inter-palette error for palette reusage. Default: `3.0`\n* reuse - Reuse palette from input. Default: `false`\n* interframe-maxerror - Maximum inter-frame error for transparency. Default: `0.0`\n* bitdepth - Number of bits per pixel. Default: `8`\n* effort - Quantisation effort. Default: `7`\n* dither - Amount of dithering. Default: `1.0`","ref":"Vix.Vips.Operation.html#gifsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.globalbalance/2","doc":"Global balance an image mosaic","ref":"Vix.Vips.Operation.html#globalbalance/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.globalbalance/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#globalbalance/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.globalbalance/2","doc":"* int-output - Integer output. Default: `false`\n* gamma - Image gamma. Default: `1.6`","ref":"Vix.Vips.Operation.html#globalbalance/2-optional"},{"type":"function","title":"Vix.Vips.Operation.globalbalance!/2","doc":"Global balance an image mosaic","ref":"Vix.Vips.Operation.html#globalbalance!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.globalbalance!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#globalbalance!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.globalbalance!/2","doc":"* int-output - Integer output. Default: `false`\n* gamma - Image gamma. Default: `1.6`","ref":"Vix.Vips.Operation.html#globalbalance!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.gravity/5","doc":"Place an image within a larger image with a certain gravity","ref":"Vix.Vips.Operation.html#gravity/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gravity/5","doc":"* input - Input image\n  * direction - Direction to place image within width/height\n  * width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#gravity/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gravity/5","doc":"* background - Color for background pixels. Default: `nil`\n* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BLACK`","ref":"Vix.Vips.Operation.html#gravity/5-optional"},{"type":"function","title":"Vix.Vips.Operation.gravity!/5","doc":"Place an image within a larger image with a certain gravity","ref":"Vix.Vips.Operation.html#gravity!/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.gravity!/5","doc":"* input - Input image\n  * direction - Direction to place image within width/height\n  * width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#gravity!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.gravity!/5","doc":"* background - Color for background pixels. Default: `nil`\n* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BLACK`","ref":"Vix.Vips.Operation.html#gravity!/5-optional"},{"type":"function","title":"Vix.Vips.Operation.grey/3","doc":"Make a grey ramp image","ref":"Vix.Vips.Operation.html#grey/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.grey/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#grey/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.grey/3","doc":"* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#grey/3-optional"},{"type":"function","title":"Vix.Vips.Operation.grey!/3","doc":"Make a grey ramp image","ref":"Vix.Vips.Operation.html#grey!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.grey!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#grey!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.grey!/3","doc":"* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#grey!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.grid/4","doc":"Grid an image","ref":"Vix.Vips.Operation.html#grid/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.grid/4","doc":"* input - Input image\n  * tile-height - Chop into tiles this high\n  * across - Number of tiles across\n  * down - Number of tiles down","ref":"Vix.Vips.Operation.html#grid/4-arguments"},{"type":"function","title":"Vix.Vips.Operation.grid!/4","doc":"Grid an image","ref":"Vix.Vips.Operation.html#grid!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.grid!/4","doc":"* input - Input image\n  * tile-height - Chop into tiles this high\n  * across - Number of tiles across\n  * down - Number of tiles down","ref":"Vix.Vips.Operation.html#grid!/4-arguments"},{"type":"function","title":"Vix.Vips.Operation.heifload/2","doc":"Load a heif image","ref":"Vix.Vips.Operation.html#heifload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#heifload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* thumbnail - Fetch thumbnail image. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#heifload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.heifload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#heifload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.heifload!/2","doc":"Load a heif image","ref":"Vix.Vips.Operation.html#heifload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#heifload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* thumbnail - Fetch thumbnail image. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#heifload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.heifload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#heifload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.heifload_buffer/2","doc":"Load a heif image","ref":"Vix.Vips.Operation.html#heifload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#heifload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* thumbnail - Fetch thumbnail image. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#heifload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.heifload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#heifload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.heifload_buffer!/2","doc":"Load a heif image","ref":"Vix.Vips.Operation.html#heifload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#heifload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* thumbnail - Fetch thumbnail image. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#heifload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.heifload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#heifload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.heifsave/3","doc":"Save image in heif format","ref":"Vix.Vips.Operation.html#heifsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#heifsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* encoder - Select encoder to use. Default: `:VIPS_FOREIGN_HEIF_ENCODER_AUTO`\n* speed - CPU effort. Default: `5`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* effort - CPU effort. Default: `4`\n* compression - Compression format. Default: `:VIPS_FOREIGN_HEIF_COMPRESSION_HEVC`\n* lossless - Enable lossless compression. Default: `false`\n* bitdepth - Number of bits per pixel. Default: `8`\n* Q - Q factor. Default: `50`","ref":"Vix.Vips.Operation.html#heifsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.heifsave!/3","doc":"Save image in heif format","ref":"Vix.Vips.Operation.html#heifsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#heifsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* encoder - Select encoder to use. Default: `:VIPS_FOREIGN_HEIF_ENCODER_AUTO`\n* speed - CPU effort. Default: `5`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* effort - CPU effort. Default: `4`\n* compression - Compression format. Default: `:VIPS_FOREIGN_HEIF_COMPRESSION_HEVC`\n* lossless - Enable lossless compression. Default: `false`\n* bitdepth - Number of bits per pixel. Default: `8`\n* Q - Q factor. Default: `50`","ref":"Vix.Vips.Operation.html#heifsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.heifsave_buffer/2","doc":"Save image in heif format","ref":"Vix.Vips.Operation.html#heifsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#heifsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* encoder - Select encoder to use. Default: `:VIPS_FOREIGN_HEIF_ENCODER_AUTO`\n* speed - CPU effort. Default: `5`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* effort - CPU effort. Default: `4`\n* compression - Compression format. Default: `:VIPS_FOREIGN_HEIF_COMPRESSION_HEVC`\n* lossless - Enable lossless compression. Default: `false`\n* bitdepth - Number of bits per pixel. Default: `8`\n* Q - Q factor. Default: `50`","ref":"Vix.Vips.Operation.html#heifsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.heifsave_buffer!/2","doc":"Save image in heif format","ref":"Vix.Vips.Operation.html#heifsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.heifsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#heifsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.heifsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* encoder - Select encoder to use. Default: `:VIPS_FOREIGN_HEIF_ENCODER_AUTO`\n* speed - CPU effort. Default: `5`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* effort - CPU effort. Default: `4`\n* compression - Compression format. Default: `:VIPS_FOREIGN_HEIF_COMPRESSION_HEVC`\n* lossless - Enable lossless compression. Default: `false`\n* bitdepth - Number of bits per pixel. Default: `8`\n* Q - Q factor. Default: `50`","ref":"Vix.Vips.Operation.html#heifsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_cum/1","doc":"Form cumulative histogram","ref":"Vix.Vips.Operation.html#hist_cum/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_cum/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_cum/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_cum!/1","doc":"Form cumulative histogram","ref":"Vix.Vips.Operation.html#hist_cum!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_cum!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_cum!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_entropy/1","doc":"Estimate image entropy","ref":"Vix.Vips.Operation.html#hist_entropy/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_entropy/1","doc":"* input - Input histogram image","ref":"Vix.Vips.Operation.html#hist_entropy/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_entropy!/1","doc":"Estimate image entropy","ref":"Vix.Vips.Operation.html#hist_entropy!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_entropy!/1","doc":"* input - Input histogram image","ref":"Vix.Vips.Operation.html#hist_entropy!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_equal/2","doc":"Histogram equalisation","ref":"Vix.Vips.Operation.html#hist_equal/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_equal/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_equal/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_equal/2","doc":"* band - Equalise with this band. Default: `-1`","ref":"Vix.Vips.Operation.html#hist_equal/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_equal!/2","doc":"Histogram equalisation","ref":"Vix.Vips.Operation.html#hist_equal!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_equal!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_equal!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_equal!/2","doc":"* band - Equalise with this band. Default: `-1`","ref":"Vix.Vips.Operation.html#hist_equal!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_find/2","doc":"Find image histogram","ref":"Vix.Vips.Operation.html#hist_find/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_find/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_find/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_find/2","doc":"* band - Find histogram of band. Default: `-1`","ref":"Vix.Vips.Operation.html#hist_find/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_find!/2","doc":"Find image histogram","ref":"Vix.Vips.Operation.html#hist_find!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_find!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_find!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_find!/2","doc":"* band - Find histogram of band. Default: `-1`","ref":"Vix.Vips.Operation.html#hist_find!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_find_indexed/3","doc":"Find indexed image histogram","ref":"Vix.Vips.Operation.html#hist_find_indexed/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_find_indexed/3","doc":"* input - Input image\n  * index - Index image","ref":"Vix.Vips.Operation.html#hist_find_indexed/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_find_indexed/3","doc":"* combine - Combine bins like this. Default: `:VIPS_COMBINE_SUM`","ref":"Vix.Vips.Operation.html#hist_find_indexed/3-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_find_indexed!/3","doc":"Find indexed image histogram","ref":"Vix.Vips.Operation.html#hist_find_indexed!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_find_indexed!/3","doc":"* input - Input image\n  * index - Index image","ref":"Vix.Vips.Operation.html#hist_find_indexed!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_find_indexed!/3","doc":"* combine - Combine bins like this. Default: `:VIPS_COMBINE_SUM`","ref":"Vix.Vips.Operation.html#hist_find_indexed!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_find_ndim/2","doc":"Find n-dimensional image histogram","ref":"Vix.Vips.Operation.html#hist_find_ndim/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_find_ndim/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_find_ndim/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_find_ndim/2","doc":"* bins - Number of bins in each dimension. Default: `10`","ref":"Vix.Vips.Operation.html#hist_find_ndim/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_find_ndim!/2","doc":"Find n-dimensional image histogram","ref":"Vix.Vips.Operation.html#hist_find_ndim!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_find_ndim!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_find_ndim!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_find_ndim!/2","doc":"* bins - Number of bins in each dimension. Default: `10`","ref":"Vix.Vips.Operation.html#hist_find_ndim!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_ismonotonic/1","doc":"Test for monotonicity","ref":"Vix.Vips.Operation.html#hist_ismonotonic/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_ismonotonic/1","doc":"* input - Input histogram image","ref":"Vix.Vips.Operation.html#hist_ismonotonic/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_ismonotonic!/1","doc":"Test for monotonicity","ref":"Vix.Vips.Operation.html#hist_ismonotonic!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_ismonotonic!/1","doc":"* input - Input histogram image","ref":"Vix.Vips.Operation.html#hist_ismonotonic!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_local/4","doc":"Local histogram equalisation","ref":"Vix.Vips.Operation.html#hist_local/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_local/4","doc":"* input - Input image\n  * width - Window width in pixels\n  * height - Window height in pixels","ref":"Vix.Vips.Operation.html#hist_local/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_local/4","doc":"* max-slope - Maximum slope (CLAHE). Default: `0`","ref":"Vix.Vips.Operation.html#hist_local/4-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_local!/4","doc":"Local histogram equalisation","ref":"Vix.Vips.Operation.html#hist_local!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_local!/4","doc":"* input - Input image\n  * width - Window width in pixels\n  * height - Window height in pixels","ref":"Vix.Vips.Operation.html#hist_local!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hist_local!/4","doc":"* max-slope - Maximum slope (CLAHE). Default: `0`","ref":"Vix.Vips.Operation.html#hist_local!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.hist_match/2","doc":"Match two histograms","ref":"Vix.Vips.Operation.html#hist_match/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_match/2","doc":"* input - Input histogram\n  * ref - Reference histogram","ref":"Vix.Vips.Operation.html#hist_match/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_match!/2","doc":"Match two histograms","ref":"Vix.Vips.Operation.html#hist_match!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_match!/2","doc":"* input - Input histogram\n  * ref - Reference histogram","ref":"Vix.Vips.Operation.html#hist_match!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_norm/1","doc":"Normalise histogram","ref":"Vix.Vips.Operation.html#hist_norm/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_norm/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_norm/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_norm!/1","doc":"Normalise histogram","ref":"Vix.Vips.Operation.html#hist_norm!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_norm!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_norm!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_plot/1","doc":"Plot histogram","ref":"Vix.Vips.Operation.html#hist_plot/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_plot/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_plot/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hist_plot!/1","doc":"Plot histogram","ref":"Vix.Vips.Operation.html#hist_plot!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hist_plot!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hist_plot!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hough_circle/2","doc":"Find hough circle transform","ref":"Vix.Vips.Operation.html#hough_circle/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hough_circle/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hough_circle/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hough_circle/2","doc":"* max-radius - Largest radius to search for. Default: `20`\n* min-radius - Smallest radius to search for. Default: `10`\n* scale - Scale down dimensions by this factor. Default: `3`","ref":"Vix.Vips.Operation.html#hough_circle/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hough_circle!/2","doc":"Find hough circle transform","ref":"Vix.Vips.Operation.html#hough_circle!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hough_circle!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hough_circle!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hough_circle!/2","doc":"* max-radius - Largest radius to search for. Default: `20`\n* min-radius - Smallest radius to search for. Default: `10`\n* scale - Scale down dimensions by this factor. Default: `3`","ref":"Vix.Vips.Operation.html#hough_circle!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hough_line/2","doc":"Find hough line transform","ref":"Vix.Vips.Operation.html#hough_line/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hough_line/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hough_line/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hough_line/2","doc":"* height - Vertical size of parameter space. Default: `256`\n* width - Horizontal size of parameter space. Default: `256`","ref":"Vix.Vips.Operation.html#hough_line/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hough_line!/2","doc":"Find hough line transform","ref":"Vix.Vips.Operation.html#hough_line!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hough_line!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hough_line!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.hough_line!/2","doc":"* height - Vertical size of parameter space. Default: `256`\n* width - Horizontal size of parameter space. Default: `256`","ref":"Vix.Vips.Operation.html#hough_line!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.hsv2srgb/1","doc":"Transform hsv to srgb","ref":"Vix.Vips.Operation.html#hsv2srgb/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hsv2srgb/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hsv2srgb/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.hsv2srgb!/1","doc":"Transform hsv to srgb","ref":"Vix.Vips.Operation.html#hsv2srgb!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.hsv2srgb!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#hsv2srgb!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.icc_export/2","doc":"Output to device with icc profile","ref":"Vix.Vips.Operation.html#icc_export/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.icc_export/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#icc_export/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.icc_export/2","doc":"* depth - Output device space depth in bits. Default: `8`\n* output-profile - Filename to load output profile from. Default: `nil`\n* black-point-compensation - Enable black point compensation. Default: `false`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* pcs - Set Profile Connection Space. Default: `:VIPS_PCS_LAB`","ref":"Vix.Vips.Operation.html#icc_export/2-optional"},{"type":"function","title":"Vix.Vips.Operation.icc_export!/2","doc":"Output to device with icc profile","ref":"Vix.Vips.Operation.html#icc_export!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.icc_export!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#icc_export!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.icc_export!/2","doc":"* depth - Output device space depth in bits. Default: `8`\n* output-profile - Filename to load output profile from. Default: `nil`\n* black-point-compensation - Enable black point compensation. Default: `false`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* pcs - Set Profile Connection Space. Default: `:VIPS_PCS_LAB`","ref":"Vix.Vips.Operation.html#icc_export!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.icc_import/2","doc":"Import from device with icc profile","ref":"Vix.Vips.Operation.html#icc_import/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.icc_import/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#icc_import/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.icc_import/2","doc":"* input-profile - Filename to load input profile from. Default: `nil`\n* embedded - Use embedded input profile, if available. Default: `false`\n* black-point-compensation - Enable black point compensation. Default: `false`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* pcs - Set Profile Connection Space. Default: `:VIPS_PCS_LAB`","ref":"Vix.Vips.Operation.html#icc_import/2-optional"},{"type":"function","title":"Vix.Vips.Operation.icc_import!/2","doc":"Import from device with icc profile","ref":"Vix.Vips.Operation.html#icc_import!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.icc_import!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#icc_import!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.icc_import!/2","doc":"* input-profile - Filename to load input profile from. Default: `nil`\n* embedded - Use embedded input profile, if available. Default: `false`\n* black-point-compensation - Enable black point compensation. Default: `false`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* pcs - Set Profile Connection Space. Default: `:VIPS_PCS_LAB`","ref":"Vix.Vips.Operation.html#icc_import!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.icc_transform/3","doc":"Transform between devices with icc profiles","ref":"Vix.Vips.Operation.html#icc_transform/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.icc_transform/3","doc":"* input - Input image\n  * output-profile - Filename to load output profile from","ref":"Vix.Vips.Operation.html#icc_transform/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.icc_transform/3","doc":"* depth - Output device space depth in bits. Default: `8`\n* input-profile - Filename to load input profile from. Default: `nil`\n* embedded - Use embedded input profile, if available. Default: `false`\n* black-point-compensation - Enable black point compensation. Default: `false`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* pcs - Set Profile Connection Space. Default: `:VIPS_PCS_LAB`","ref":"Vix.Vips.Operation.html#icc_transform/3-optional"},{"type":"function","title":"Vix.Vips.Operation.icc_transform!/3","doc":"Transform between devices with icc profiles","ref":"Vix.Vips.Operation.html#icc_transform!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.icc_transform!/3","doc":"* input - Input image\n  * output-profile - Filename to load output profile from","ref":"Vix.Vips.Operation.html#icc_transform!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.icc_transform!/3","doc":"* depth - Output device space depth in bits. Default: `8`\n* input-profile - Filename to load input profile from. Default: `nil`\n* embedded - Use embedded input profile, if available. Default: `false`\n* black-point-compensation - Enable black point compensation. Default: `false`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* pcs - Set Profile Connection Space. Default: `:VIPS_PCS_LAB`","ref":"Vix.Vips.Operation.html#icc_transform!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.identity/1","doc":"Make a 1d image where pixel values are indexes","ref":"Vix.Vips.Operation.html#identity/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.identity/1","doc":"","ref":"Vix.Vips.Operation.html#identity/1-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.identity/1","doc":"* size - Size of 16-bit LUT. Default: `65536`\n* ushort - Create a 16-bit LUT. Default: `false`\n* bands - Number of bands in LUT. Default: `1`","ref":"Vix.Vips.Operation.html#identity/1-optional"},{"type":"function","title":"Vix.Vips.Operation.identity!/1","doc":"Make a 1d image where pixel values are indexes","ref":"Vix.Vips.Operation.html#identity!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.identity!/1","doc":"","ref":"Vix.Vips.Operation.html#identity!/1-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.identity!/1","doc":"* size - Size of 16-bit LUT. Default: `65536`\n* ushort - Create a 16-bit LUT. Default: `false`\n* bands - Number of bands in LUT. Default: `1`","ref":"Vix.Vips.Operation.html#identity!/1-optional"},{"type":"function","title":"Vix.Vips.Operation.ifthenelse/4","doc":"Ifthenelse an image","ref":"Vix.Vips.Operation.html#ifthenelse/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.ifthenelse/4","doc":"* cond - Condition input image\n  * in1 - Source for TRUE pixels\n  * in2 - Source for FALSE pixels","ref":"Vix.Vips.Operation.html#ifthenelse/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.ifthenelse/4","doc":"* blend - Blend smoothly between then and else parts. Default: `false`","ref":"Vix.Vips.Operation.html#ifthenelse/4-optional"},{"type":"function","title":"Vix.Vips.Operation.ifthenelse!/4","doc":"Ifthenelse an image","ref":"Vix.Vips.Operation.html#ifthenelse!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.ifthenelse!/4","doc":"* cond - Condition input image\n  * in1 - Source for TRUE pixels\n  * in2 - Source for FALSE pixels","ref":"Vix.Vips.Operation.html#ifthenelse!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.ifthenelse!/4","doc":"* blend - Blend smoothly between then and else parts. Default: `false`","ref":"Vix.Vips.Operation.html#ifthenelse!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.insert/5","doc":"Insert image @sub into @main at @x, @y","ref":"Vix.Vips.Operation.html#insert/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.insert/5","doc":"* main - Main input image\n  * sub - Sub-image to insert into main image\n  * x - Left edge of sub in main\n  * y - Top edge of sub in main","ref":"Vix.Vips.Operation.html#insert/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.insert/5","doc":"* background - Color for new pixels. Default: `nil`\n* expand - Expand output to hold all of both inputs. Default: `false`","ref":"Vix.Vips.Operation.html#insert/5-optional"},{"type":"function","title":"Vix.Vips.Operation.insert!/5","doc":"Insert image @sub into @main at @x, @y","ref":"Vix.Vips.Operation.html#insert!/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.insert!/5","doc":"* main - Main input image\n  * sub - Sub-image to insert into main image\n  * x - Left edge of sub in main\n  * y - Top edge of sub in main","ref":"Vix.Vips.Operation.html#insert!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.insert!/5","doc":"* background - Color for new pixels. Default: `nil`\n* expand - Expand output to hold all of both inputs. Default: `false`","ref":"Vix.Vips.Operation.html#insert!/5-optional"},{"type":"function","title":"Vix.Vips.Operation.invert/1","doc":"Invert an image","ref":"Vix.Vips.Operation.html#invert/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.invert/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#invert/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.invert!/1","doc":"Invert an image","ref":"Vix.Vips.Operation.html#invert!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.invert!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#invert!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.invertlut/2","doc":"Build an inverted look-up table","ref":"Vix.Vips.Operation.html#invertlut/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.invertlut/2","doc":"* input - Matrix of XY coordinates","ref":"Vix.Vips.Operation.html#invertlut/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.invertlut/2","doc":"* size - LUT size to generate. Default: `256`","ref":"Vix.Vips.Operation.html#invertlut/2-optional"},{"type":"function","title":"Vix.Vips.Operation.invertlut!/2","doc":"Build an inverted look-up table","ref":"Vix.Vips.Operation.html#invertlut!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.invertlut!/2","doc":"* input - Matrix of XY coordinates","ref":"Vix.Vips.Operation.html#invertlut!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.invertlut!/2","doc":"* size - LUT size to generate. Default: `256`","ref":"Vix.Vips.Operation.html#invertlut!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.join/4","doc":"Join a pair of images","ref":"Vix.Vips.Operation.html#join/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.join/4","doc":"* in1 - First input image\n  * in2 - Second input image\n  * direction - Join left-right or up-down","ref":"Vix.Vips.Operation.html#join/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.join/4","doc":"* align - Align on the low, centre or high coordinate edge. Default: `:VIPS_ALIGN_LOW`\n* background - Colour for new pixels. Default: `nil`\n* shim - Pixels between images. Default: `0`\n* expand - Expand output to hold all of both inputs. Default: `false`","ref":"Vix.Vips.Operation.html#join/4-optional"},{"type":"function","title":"Vix.Vips.Operation.join!/4","doc":"Join a pair of images","ref":"Vix.Vips.Operation.html#join!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.join!/4","doc":"* in1 - First input image\n  * in2 - Second input image\n  * direction - Join left-right or up-down","ref":"Vix.Vips.Operation.html#join!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.join!/4","doc":"* align - Align on the low, centre or high coordinate edge. Default: `:VIPS_ALIGN_LOW`\n* background - Colour for new pixels. Default: `nil`\n* shim - Pixels between images. Default: `0`\n* expand - Expand output to hold all of both inputs. Default: `false`","ref":"Vix.Vips.Operation.html#join!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.jpegload/2","doc":"Load jpeg from file","ref":"Vix.Vips.Operation.html#jpegload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#jpegload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* shrink - Shrink factor on load. Default: `1`","ref":"Vix.Vips.Operation.html#jpegload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.jpegload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#jpegload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.jpegload!/2","doc":"Load jpeg from file","ref":"Vix.Vips.Operation.html#jpegload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#jpegload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* shrink - Shrink factor on load. Default: `1`","ref":"Vix.Vips.Operation.html#jpegload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.jpegload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#jpegload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.jpegload_buffer/2","doc":"Load jpeg from buffer","ref":"Vix.Vips.Operation.html#jpegload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#jpegload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* shrink - Shrink factor on load. Default: `1`","ref":"Vix.Vips.Operation.html#jpegload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.jpegload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#jpegload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.jpegload_buffer!/2","doc":"Load jpeg from buffer","ref":"Vix.Vips.Operation.html#jpegload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#jpegload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`\n* autorotate - Rotate image using exif orientation. Default: `false`\n* shrink - Shrink factor on load. Default: `1`","ref":"Vix.Vips.Operation.html#jpegload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.jpegload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#jpegload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.jpegsave/3","doc":"Save image to jpeg file","ref":"Vix.Vips.Operation.html#jpegsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#jpegsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* restart-interval - Add restart markers every specified number of mcu. Default: `0`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* quant-table - Use predefined quantization table with given index. Default: `0`\n* optimize-scans - Split spectrum of DCT coefficients into separate scans. Default: `false`\n* overshoot-deringing - Apply overshooting to samples with extreme values. Default: `false`\n* trellis-quant - Apply trellis quantisation to each 8x8 block. Default: `false`\n* no-subsample - Disable chroma subsample. Default: `false`\n* interlace - Generate an interlaced (progressive) jpeg. Default: `false`\n* optimize-coding - Compute optimal Huffman coding tables. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#jpegsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.jpegsave!/3","doc":"Save image to jpeg file","ref":"Vix.Vips.Operation.html#jpegsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#jpegsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* restart-interval - Add restart markers every specified number of mcu. Default: `0`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* quant-table - Use predefined quantization table with given index. Default: `0`\n* optimize-scans - Split spectrum of DCT coefficients into separate scans. Default: `false`\n* overshoot-deringing - Apply overshooting to samples with extreme values. Default: `false`\n* trellis-quant - Apply trellis quantisation to each 8x8 block. Default: `false`\n* no-subsample - Disable chroma subsample. Default: `false`\n* interlace - Generate an interlaced (progressive) jpeg. Default: `false`\n* optimize-coding - Compute optimal Huffman coding tables. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#jpegsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.jpegsave_buffer/2","doc":"Save image to jpeg buffer","ref":"Vix.Vips.Operation.html#jpegsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#jpegsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* restart-interval - Add restart markers every specified number of mcu. Default: `0`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* quant-table - Use predefined quantization table with given index. Default: `0`\n* optimize-scans - Split spectrum of DCT coefficients into separate scans. Default: `false`\n* overshoot-deringing - Apply overshooting to samples with extreme values. Default: `false`\n* trellis-quant - Apply trellis quantisation to each 8x8 block. Default: `false`\n* no-subsample - Disable chroma subsample. Default: `false`\n* interlace - Generate an interlaced (progressive) jpeg. Default: `false`\n* optimize-coding - Compute optimal Huffman coding tables. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#jpegsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.jpegsave_buffer!/2","doc":"Save image to jpeg buffer","ref":"Vix.Vips.Operation.html#jpegsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#jpegsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* restart-interval - Add restart markers every specified number of mcu. Default: `0`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* quant-table - Use predefined quantization table with given index. Default: `0`\n* optimize-scans - Split spectrum of DCT coefficients into separate scans. Default: `false`\n* overshoot-deringing - Apply overshooting to samples with extreme values. Default: `false`\n* trellis-quant - Apply trellis quantisation to each 8x8 block. Default: `false`\n* no-subsample - Disable chroma subsample. Default: `false`\n* interlace - Generate an interlaced (progressive) jpeg. Default: `false`\n* optimize-coding - Compute optimal Huffman coding tables. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#jpegsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.jpegsave_mime/2","doc":"Save image to jpeg mime","ref":"Vix.Vips.Operation.html#jpegsave_mime/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegsave_mime/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#jpegsave_mime/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegsave_mime/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* restart-interval - Add restart markers every specified number of mcu. Default: `0`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* quant-table - Use predefined quantization table with given index. Default: `0`\n* optimize-scans - Split spectrum of DCT coefficients into separate scans. Default: `false`\n* overshoot-deringing - Apply overshooting to samples with extreme values. Default: `false`\n* trellis-quant - Apply trellis quantisation to each 8x8 block. Default: `false`\n* no-subsample - Disable chroma subsample. Default: `false`\n* interlace - Generate an interlaced (progressive) jpeg. Default: `false`\n* optimize-coding - Compute optimal Huffman coding tables. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#jpegsave_mime/2-optional"},{"type":"function","title":"Vix.Vips.Operation.jpegsave_mime!/2","doc":"Save image to jpeg mime","ref":"Vix.Vips.Operation.html#jpegsave_mime!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.jpegsave_mime!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#jpegsave_mime!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.jpegsave_mime!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* restart-interval - Add restart markers every specified number of mcu. Default: `0`\n* subsample-mode - Select chroma subsample operation mode. Default: `:VIPS_FOREIGN_SUBSAMPLE_AUTO`\n* quant-table - Use predefined quantization table with given index. Default: `0`\n* optimize-scans - Split spectrum of DCT coefficients into separate scans. Default: `false`\n* overshoot-deringing - Apply overshooting to samples with extreme values. Default: `false`\n* trellis-quant - Apply trellis quantisation to each 8x8 block. Default: `false`\n* no-subsample - Disable chroma subsample. Default: `false`\n* interlace - Generate an interlaced (progressive) jpeg. Default: `false`\n* optimize-coding - Compute optimal Huffman coding tables. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#jpegsave_mime!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.lab2labq/1","doc":"Transform float lab to labq coding","ref":"Vix.Vips.Operation.html#lab2labq/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2labq/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2labq/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lab2labq!/1","doc":"Transform float lab to labq coding","ref":"Vix.Vips.Operation.html#lab2labq!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2labq!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2labq!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lab2labs/1","doc":"Transform float lab to signed short","ref":"Vix.Vips.Operation.html#lab2labs/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2labs/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2labs/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lab2labs!/1","doc":"Transform float lab to signed short","ref":"Vix.Vips.Operation.html#lab2labs!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2labs!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2labs!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lab2lch/1","doc":"Transform lab to lch","ref":"Vix.Vips.Operation.html#lab2lch/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2lch/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2lch/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lab2lch!/1","doc":"Transform lab to lch","ref":"Vix.Vips.Operation.html#lab2lch!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2lch!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2lch!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lab2xyz/2","doc":"Transform cielab to xyz","ref":"Vix.Vips.Operation.html#lab2xyz/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2xyz/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2xyz/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.lab2xyz/2","doc":"* temp - Color temperature. Default: `nil`","ref":"Vix.Vips.Operation.html#lab2xyz/2-optional"},{"type":"function","title":"Vix.Vips.Operation.lab2xyz!/2","doc":"Transform cielab to xyz","ref":"Vix.Vips.Operation.html#lab2xyz!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lab2xyz!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lab2xyz!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.lab2xyz!/2","doc":"* temp - Color temperature. Default: `nil`","ref":"Vix.Vips.Operation.html#lab2xyz!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.labelregions/1","doc":"Label regions in an image","ref":"Vix.Vips.Operation.html#labelregions/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labelregions/1","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#labelregions/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.labelregions/1","doc":"Operation returns a tuple\n\n* mask - Mask of region labels. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* segments - Number of discrete contiguous regions. (`integer()`)","ref":"Vix.Vips.Operation.html#labelregions/1-returns"},{"type":"function","title":"Vix.Vips.Operation.labelregions!/1","doc":"Label regions in an image","ref":"Vix.Vips.Operation.html#labelregions!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labelregions!/1","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#labelregions!/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.labelregions!/1","doc":"Operation returns a tuple\n\n* mask - Mask of region labels. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* segments - Number of discrete contiguous regions. (`integer()`)","ref":"Vix.Vips.Operation.html#labelregions!/1-returns"},{"type":"function","title":"Vix.Vips.Operation.labq2lab/1","doc":"Unpack a labq image to float lab","ref":"Vix.Vips.Operation.html#labq2lab/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labq2lab/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labq2lab/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labq2lab!/1","doc":"Unpack a labq image to float lab","ref":"Vix.Vips.Operation.html#labq2lab!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labq2lab!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labq2lab!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labq2labs/1","doc":"Unpack a labq image to short lab","ref":"Vix.Vips.Operation.html#labq2labs/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labq2labs/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labq2labs/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labq2labs!/1","doc":"Unpack a labq image to short lab","ref":"Vix.Vips.Operation.html#labq2labs!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labq2labs!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labq2labs!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labq2srgb/1","doc":"Convert a labq image to srgb","ref":"Vix.Vips.Operation.html#labq2srgb/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labq2srgb/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labq2srgb/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labq2srgb!/1","doc":"Convert a labq image to srgb","ref":"Vix.Vips.Operation.html#labq2srgb!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labq2srgb!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labq2srgb!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labs2lab/1","doc":"Transform signed short lab to float","ref":"Vix.Vips.Operation.html#labs2lab/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labs2lab/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labs2lab/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labs2lab!/1","doc":"Transform signed short lab to float","ref":"Vix.Vips.Operation.html#labs2lab!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labs2lab!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labs2lab!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labs2labq/1","doc":"Transform short lab to labq coding","ref":"Vix.Vips.Operation.html#labs2labq/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labs2labq/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labs2labq/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.labs2labq!/1","doc":"Transform short lab to labq coding","ref":"Vix.Vips.Operation.html#labs2labq!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.labs2labq!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#labs2labq!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lch2cmc/1","doc":"Transform lch to cmc","ref":"Vix.Vips.Operation.html#lch2cmc/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lch2cmc/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lch2cmc/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lch2cmc!/1","doc":"Transform lch to cmc","ref":"Vix.Vips.Operation.html#lch2cmc!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lch2cmc!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lch2cmc!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lch2lab/1","doc":"Transform lch to lab","ref":"Vix.Vips.Operation.html#lch2lab/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lch2lab/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lch2lab/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.lch2lab!/1","doc":"Transform lch to lab","ref":"Vix.Vips.Operation.html#lch2lab!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.lch2lab!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#lch2lab!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.linear/4","doc":"Calculate (a * in + b)","ref":"Vix.Vips.Operation.html#linear/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.linear/4","doc":"* input - Input image\n  * a - Multiply by this\n  * b - Add this","ref":"Vix.Vips.Operation.html#linear/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.linear/4","doc":"* uchar - Output should be uchar. Default: `false`","ref":"Vix.Vips.Operation.html#linear/4-optional"},{"type":"function","title":"Vix.Vips.Operation.linear!/4","doc":"Calculate (a * in + b)","ref":"Vix.Vips.Operation.html#linear!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.linear!/4","doc":"* input - Input image\n  * a - Multiply by this\n  * b - Add this","ref":"Vix.Vips.Operation.html#linear!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.linear!/4","doc":"* uchar - Output should be uchar. Default: `false`","ref":"Vix.Vips.Operation.html#linear!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.linecache/2","doc":"Cache an image as a set of lines","ref":"Vix.Vips.Operation.html#linecache/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.linecache/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#linecache/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.linecache/2","doc":"* persistent - Keep cache between evaluations. Default: `false`\n* threaded - Allow threaded access. Default: `false`\n* access - Expected access pattern. Default: `:VIPS_ACCESS_RANDOM`\n* tile-height - Tile height in pixels. Default: `128`","ref":"Vix.Vips.Operation.html#linecache/2-optional"},{"type":"function","title":"Vix.Vips.Operation.linecache!/2","doc":"Cache an image as a set of lines","ref":"Vix.Vips.Operation.html#linecache!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.linecache!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#linecache!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.linecache!/2","doc":"* persistent - Keep cache between evaluations. Default: `false`\n* threaded - Allow threaded access. Default: `false`\n* access - Expected access pattern. Default: `:VIPS_ACCESS_RANDOM`\n* tile-height - Tile height in pixels. Default: `128`","ref":"Vix.Vips.Operation.html#linecache!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.logmat/3","doc":"Make a laplacian of gaussian image","ref":"Vix.Vips.Operation.html#logmat/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.logmat/3","doc":"* sigma - Radius of Gaussian\n  * min-ampl - Minimum amplitude of Gaussian","ref":"Vix.Vips.Operation.html#logmat/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.logmat/3","doc":"* precision - Generate with this precision. Default: `:VIPS_PRECISION_INTEGER`\n* integer - Generate integer Gaussian. Default: `false`\n* separable - Generate separable Gaussian. Default: `false`","ref":"Vix.Vips.Operation.html#logmat/3-optional"},{"type":"function","title":"Vix.Vips.Operation.logmat!/3","doc":"Make a laplacian of gaussian image","ref":"Vix.Vips.Operation.html#logmat!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.logmat!/3","doc":"* sigma - Radius of Gaussian\n  * min-ampl - Minimum amplitude of Gaussian","ref":"Vix.Vips.Operation.html#logmat!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.logmat!/3","doc":"* precision - Generate with this precision. Default: `:VIPS_PRECISION_INTEGER`\n* integer - Generate integer Gaussian. Default: `false`\n* separable - Generate separable Gaussian. Default: `false`","ref":"Vix.Vips.Operation.html#logmat!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.mapim/3","doc":"Resample with a map image","ref":"Vix.Vips.Operation.html#mapim/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mapim/3","doc":"* input - Input image argument\n  * index - Index pixels with this","ref":"Vix.Vips.Operation.html#mapim/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mapim/3","doc":"* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BACKGROUND`\n* premultiplied - Images have premultiplied alpha. Default: `false`\n* background - Background value. Default: `nil`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#mapim/3-optional"},{"type":"function","title":"Vix.Vips.Operation.mapim!/3","doc":"Resample with a map image","ref":"Vix.Vips.Operation.html#mapim!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mapim!/3","doc":"* input - Input image argument\n  * index - Index pixels with this","ref":"Vix.Vips.Operation.html#mapim!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mapim!/3","doc":"* extend - How to generate the extra pixels. Default: `:VIPS_EXTEND_BACKGROUND`\n* premultiplied - Images have premultiplied alpha. Default: `false`\n* background - Background value. Default: `nil`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#mapim!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.maplut/3","doc":"Map an image though a lut","ref":"Vix.Vips.Operation.html#maplut/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.maplut/3","doc":"* input - Input image\n  * lut - Look-up table image","ref":"Vix.Vips.Operation.html#maplut/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.maplut/3","doc":"* band - Apply one-band lut to this band of in. Default: `-1`","ref":"Vix.Vips.Operation.html#maplut/3-optional"},{"type":"function","title":"Vix.Vips.Operation.maplut!/3","doc":"Map an image though a lut","ref":"Vix.Vips.Operation.html#maplut!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.maplut!/3","doc":"* input - Input image\n  * lut - Look-up table image","ref":"Vix.Vips.Operation.html#maplut!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.maplut!/3","doc":"* band - Apply one-band lut to this band of in. Default: `-1`","ref":"Vix.Vips.Operation.html#maplut!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_butterworth/6","doc":"Make a butterworth filter","ref":"Vix.Vips.Operation.html#mask_butterworth/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_butterworth/6","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * order - Filter order\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_butterworth/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_butterworth/6","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_butterworth/6-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_butterworth!/6","doc":"Make a butterworth filter","ref":"Vix.Vips.Operation.html#mask_butterworth!/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_butterworth!/6","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * order - Filter order\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_butterworth!/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_butterworth!/6","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_butterworth!/6-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_butterworth_band/8","doc":"Make a butterworth_band filter","ref":"Vix.Vips.Operation.html#mask_butterworth_band/8"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_butterworth_band/8","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * order - Filter order\n  * frequency-cutoff-x - Frequency cutoff x\n  * frequency-cutoff-y - Frequency cutoff y\n  * radius - Radius of circle\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_butterworth_band/8-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_butterworth_band/8","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_butterworth_band/8-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_butterworth_band!/8","doc":"Make a butterworth_band filter","ref":"Vix.Vips.Operation.html#mask_butterworth_band!/8"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_butterworth_band!/8","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * order - Filter order\n  * frequency-cutoff-x - Frequency cutoff x\n  * frequency-cutoff-y - Frequency cutoff y\n  * radius - Radius of circle\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_butterworth_band!/8-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_butterworth_band!/8","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_butterworth_band!/8-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_butterworth_ring/7","doc":"Make a butterworth ring filter","ref":"Vix.Vips.Operation.html#mask_butterworth_ring/7"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_butterworth_ring/7","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * order - Filter order\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff\n  * ringwidth - Ringwidth","ref":"Vix.Vips.Operation.html#mask_butterworth_ring/7-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_butterworth_ring/7","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_butterworth_ring/7-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_butterworth_ring!/7","doc":"Make a butterworth ring filter","ref":"Vix.Vips.Operation.html#mask_butterworth_ring!/7"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_butterworth_ring!/7","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * order - Filter order\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff\n  * ringwidth - Ringwidth","ref":"Vix.Vips.Operation.html#mask_butterworth_ring!/7-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_butterworth_ring!/7","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_butterworth_ring!/7-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_fractal/4","doc":"Make fractal filter","ref":"Vix.Vips.Operation.html#mask_fractal/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_fractal/4","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * fractal-dimension - Fractal dimension","ref":"Vix.Vips.Operation.html#mask_fractal/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_fractal/4","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_fractal/4-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_fractal!/4","doc":"Make fractal filter","ref":"Vix.Vips.Operation.html#mask_fractal!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_fractal!/4","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * fractal-dimension - Fractal dimension","ref":"Vix.Vips.Operation.html#mask_fractal!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_fractal!/4","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_fractal!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_gaussian/5","doc":"Make a gaussian filter","ref":"Vix.Vips.Operation.html#mask_gaussian/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_gaussian/5","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_gaussian/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_gaussian/5","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_gaussian/5-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_gaussian!/5","doc":"Make a gaussian filter","ref":"Vix.Vips.Operation.html#mask_gaussian!/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_gaussian!/5","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_gaussian!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_gaussian!/5","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_gaussian!/5-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_gaussian_band/7","doc":"Make a gaussian filter","ref":"Vix.Vips.Operation.html#mask_gaussian_band/7"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_gaussian_band/7","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff-x - Frequency cutoff x\n  * frequency-cutoff-y - Frequency cutoff y\n  * radius - Radius of circle\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_gaussian_band/7-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_gaussian_band/7","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_gaussian_band/7-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_gaussian_band!/7","doc":"Make a gaussian filter","ref":"Vix.Vips.Operation.html#mask_gaussian_band!/7"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_gaussian_band!/7","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff-x - Frequency cutoff x\n  * frequency-cutoff-y - Frequency cutoff y\n  * radius - Radius of circle\n  * amplitude-cutoff - Amplitude cutoff","ref":"Vix.Vips.Operation.html#mask_gaussian_band!/7-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_gaussian_band!/7","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_gaussian_band!/7-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_gaussian_ring/6","doc":"Make a gaussian ring filter","ref":"Vix.Vips.Operation.html#mask_gaussian_ring/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_gaussian_ring/6","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff\n  * ringwidth - Ringwidth","ref":"Vix.Vips.Operation.html#mask_gaussian_ring/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_gaussian_ring/6","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_gaussian_ring/6-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_gaussian_ring!/6","doc":"Make a gaussian ring filter","ref":"Vix.Vips.Operation.html#mask_gaussian_ring!/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_gaussian_ring!/6","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff\n  * amplitude-cutoff - Amplitude cutoff\n  * ringwidth - Ringwidth","ref":"Vix.Vips.Operation.html#mask_gaussian_ring!/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_gaussian_ring!/6","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_gaussian_ring!/6-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_ideal/4","doc":"Make an ideal filter","ref":"Vix.Vips.Operation.html#mask_ideal/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_ideal/4","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff","ref":"Vix.Vips.Operation.html#mask_ideal/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_ideal/4","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_ideal/4-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_ideal!/4","doc":"Make an ideal filter","ref":"Vix.Vips.Operation.html#mask_ideal!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_ideal!/4","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff","ref":"Vix.Vips.Operation.html#mask_ideal!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_ideal!/4","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_ideal!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_ideal_band/6","doc":"Make an ideal band filter","ref":"Vix.Vips.Operation.html#mask_ideal_band/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_ideal_band/6","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff-x - Frequency cutoff x\n  * frequency-cutoff-y - Frequency cutoff y\n  * radius - Radius of circle","ref":"Vix.Vips.Operation.html#mask_ideal_band/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_ideal_band/6","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_ideal_band/6-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_ideal_band!/6","doc":"Make an ideal band filter","ref":"Vix.Vips.Operation.html#mask_ideal_band!/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_ideal_band!/6","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff-x - Frequency cutoff x\n  * frequency-cutoff-y - Frequency cutoff y\n  * radius - Radius of circle","ref":"Vix.Vips.Operation.html#mask_ideal_band!/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_ideal_band!/6","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_ideal_band!/6-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_ideal_ring/5","doc":"Make an ideal ring filter","ref":"Vix.Vips.Operation.html#mask_ideal_ring/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_ideal_ring/5","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff\n  * ringwidth - Ringwidth","ref":"Vix.Vips.Operation.html#mask_ideal_ring/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_ideal_ring/5","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_ideal_ring/5-optional"},{"type":"function","title":"Vix.Vips.Operation.mask_ideal_ring!/5","doc":"Make an ideal ring filter","ref":"Vix.Vips.Operation.html#mask_ideal_ring!/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mask_ideal_ring!/5","doc":"* width - Image width in pixels\n  * height - Image height in pixels\n  * frequency-cutoff - Frequency cutoff\n  * ringwidth - Ringwidth","ref":"Vix.Vips.Operation.html#mask_ideal_ring!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mask_ideal_ring!/5","doc":"* optical - Rotate quadrants to optical space. Default: `false`\n* reject - Invert the sense of the filter. Default: `false`\n* nodc - Remove DC component. Default: `false`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#mask_ideal_ring!/5-optional"},{"type":"function","title":"Vix.Vips.Operation.match/11","doc":"First-order match of two images","ref":"Vix.Vips.Operation.html#match/11"},{"type":"function","title":"Arguments - Vix.Vips.Operation.match/11","doc":"* ref - Reference image\n  * sec - Secondary image\n  * xr1 - Position of first reference tie-point\n  * yr1 - Position of first reference tie-point\n  * xs1 - Position of first secondary tie-point\n  * ys1 - Position of first secondary tie-point\n  * xr2 - Position of second reference tie-point\n  * yr2 - Position of second reference tie-point\n  * xs2 - Position of second secondary tie-point\n  * ys2 - Position of second secondary tie-point","ref":"Vix.Vips.Operation.html#match/11-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.match/11","doc":"* interpolate - Interpolate pixels with this. \n* search - Search to improve tie-points. Default: `false`\n* harea - Half area size. Default: `1`\n* hwindow - Half window size. Default: `1`","ref":"Vix.Vips.Operation.html#match/11-optional"},{"type":"function","title":"Vix.Vips.Operation.match!/11","doc":"First-order match of two images","ref":"Vix.Vips.Operation.html#match!/11"},{"type":"function","title":"Arguments - Vix.Vips.Operation.match!/11","doc":"* ref - Reference image\n  * sec - Secondary image\n  * xr1 - Position of first reference tie-point\n  * yr1 - Position of first reference tie-point\n  * xs1 - Position of first secondary tie-point\n  * ys1 - Position of first secondary tie-point\n  * xr2 - Position of second reference tie-point\n  * yr2 - Position of second reference tie-point\n  * xs2 - Position of second secondary tie-point\n  * ys2 - Position of second secondary tie-point","ref":"Vix.Vips.Operation.html#match!/11-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.match!/11","doc":"* interpolate - Interpolate pixels with this. \n* search - Search to improve tie-points. Default: `false`\n* harea - Half area size. Default: `1`\n* hwindow - Half window size. Default: `1`","ref":"Vix.Vips.Operation.html#match!/11-optional"},{"type":"function","title":"Vix.Vips.Operation.math2/3","doc":"Binary math operations","ref":"Vix.Vips.Operation.html#math2/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.math2/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * math2 - Math to perform","ref":"Vix.Vips.Operation.html#math2/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.math2!/3","doc":"Binary math operations","ref":"Vix.Vips.Operation.html#math2!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.math2!/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * math2 - Math to perform","ref":"Vix.Vips.Operation.html#math2!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.math2_const/3","doc":"Binary math operations with a constant","ref":"Vix.Vips.Operation.html#math2_const/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.math2_const/3","doc":"* input - Input image\n  * math2 - Math to perform\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#math2_const/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.math2_const!/3","doc":"Binary math operations with a constant","ref":"Vix.Vips.Operation.html#math2_const!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.math2_const!/3","doc":"* input - Input image\n  * math2 - Math to perform\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#math2_const!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.math/2","doc":"Apply a math operation to an image","ref":"Vix.Vips.Operation.html#math/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.math/2","doc":"* input - Input image\n  * math - Math to perform","ref":"Vix.Vips.Operation.html#math/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.math!/2","doc":"Apply a math operation to an image","ref":"Vix.Vips.Operation.html#math!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.math!/2","doc":"* input - Input image\n  * math - Math to perform","ref":"Vix.Vips.Operation.html#math!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.matrixinvert/1","doc":"Invert an matrix","ref":"Vix.Vips.Operation.html#matrixinvert/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixinvert/1","doc":"* input - An square matrix","ref":"Vix.Vips.Operation.html#matrixinvert/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.matrixinvert!/1","doc":"Invert an matrix","ref":"Vix.Vips.Operation.html#matrixinvert!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixinvert!/1","doc":"* input - An square matrix","ref":"Vix.Vips.Operation.html#matrixinvert!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.matrixload/2","doc":"Load matrix","ref":"Vix.Vips.Operation.html#matrixload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#matrixload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.matrixload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`","ref":"Vix.Vips.Operation.html#matrixload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.matrixload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#matrixload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.matrixload!/2","doc":"Load matrix","ref":"Vix.Vips.Operation.html#matrixload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#matrixload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.matrixload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`","ref":"Vix.Vips.Operation.html#matrixload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.matrixload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#matrixload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.matrixprint/2","doc":"Print matrix","ref":"Vix.Vips.Operation.html#matrixprint/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixprint/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#matrixprint/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.matrixprint/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#matrixprint/2-optional"},{"type":"function","title":"Vix.Vips.Operation.matrixprint!/2","doc":"Print matrix","ref":"Vix.Vips.Operation.html#matrixprint!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixprint!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#matrixprint!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.matrixprint!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#matrixprint!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.matrixsave/3","doc":"Save image to matrix","ref":"Vix.Vips.Operation.html#matrixsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#matrixsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.matrixsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#matrixsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.matrixsave!/3","doc":"Save image to matrix","ref":"Vix.Vips.Operation.html#matrixsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.matrixsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#matrixsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.matrixsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#matrixsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.max/2","doc":"Find image maximum","ref":"Vix.Vips.Operation.html#max/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.max/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#max/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.max/2","doc":"* size - Number of maximum values to find. Default: `10`","ref":"Vix.Vips.Operation.html#max/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.max/2","doc":"Operation returns a tuple\n\n* out - Output value. (`float()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* y-array - Array of vertical positions. (`list(integer())`)\n* x-array - Array of horizontal positions. (`list(integer())`)\n* out-array - Array of output values. (`list(float())`)\n* y - Vertical position of maximum. (`integer()`)\n* x - Horizontal position of maximum. (`integer()`)","ref":"Vix.Vips.Operation.html#max/2-returns"},{"type":"function","title":"Vix.Vips.Operation.max!/2","doc":"Find image maximum","ref":"Vix.Vips.Operation.html#max!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.max!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#max!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.max!/2","doc":"* size - Number of maximum values to find. Default: `10`","ref":"Vix.Vips.Operation.html#max!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.max!/2","doc":"Operation returns a tuple\n\n* out - Output value. (`float()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* y-array - Array of vertical positions. (`list(integer())`)\n* x-array - Array of horizontal positions. (`list(integer())`)\n* out-array - Array of output values. (`list(float())`)\n* y - Vertical position of maximum. (`integer()`)\n* x - Horizontal position of maximum. (`integer()`)","ref":"Vix.Vips.Operation.html#max!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.measure/4","doc":"Measure a set of patches on a color chart","ref":"Vix.Vips.Operation.html#measure/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.measure/4","doc":"* input - Image to measure\n  * h - Number of patches across chart\n  * v - Number of patches down chart","ref":"Vix.Vips.Operation.html#measure/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.measure/4","doc":"* height - Height of extract area. Default: `1`\n* width - Width of extract area. Default: `1`\n* top - Top edge of extract area. Default: `0`\n* left - Left edge of extract area. Default: `0`","ref":"Vix.Vips.Operation.html#measure/4-optional"},{"type":"function","title":"Vix.Vips.Operation.measure!/4","doc":"Measure a set of patches on a color chart","ref":"Vix.Vips.Operation.html#measure!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.measure!/4","doc":"* input - Image to measure\n  * h - Number of patches across chart\n  * v - Number of patches down chart","ref":"Vix.Vips.Operation.html#measure!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.measure!/4","doc":"* height - Height of extract area. Default: `1`\n* width - Width of extract area. Default: `1`\n* top - Top edge of extract area. Default: `0`\n* left - Left edge of extract area. Default: `0`","ref":"Vix.Vips.Operation.html#measure!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.merge/6","doc":"Merge two images","ref":"Vix.Vips.Operation.html#merge/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.merge/6","doc":"* ref - Reference image\n  * sec - Secondary image\n  * direction - Horizontal or vertical merge\n  * dx - Horizontal displacement from sec to ref\n  * dy - Vertical displacement from sec to ref","ref":"Vix.Vips.Operation.html#merge/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.merge/6","doc":"* mblend - Maximum blend size. Default: `10`","ref":"Vix.Vips.Operation.html#merge/6-optional"},{"type":"function","title":"Vix.Vips.Operation.merge!/6","doc":"Merge two images","ref":"Vix.Vips.Operation.html#merge!/6"},{"type":"function","title":"Arguments - Vix.Vips.Operation.merge!/6","doc":"* ref - Reference image\n  * sec - Secondary image\n  * direction - Horizontal or vertical merge\n  * dx - Horizontal displacement from sec to ref\n  * dy - Vertical displacement from sec to ref","ref":"Vix.Vips.Operation.html#merge!/6-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.merge!/6","doc":"* mblend - Maximum blend size. Default: `10`","ref":"Vix.Vips.Operation.html#merge!/6-optional"},{"type":"function","title":"Vix.Vips.Operation.min/2","doc":"Find image minimum","ref":"Vix.Vips.Operation.html#min/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.min/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#min/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.min/2","doc":"* size - Number of minimum values to find. Default: `10`","ref":"Vix.Vips.Operation.html#min/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.min/2","doc":"Operation returns a tuple\n\n* out - Output value. (`float()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* y-array - Array of vertical positions. (`list(integer())`)\n* x-array - Array of horizontal positions. (`list(integer())`)\n* out-array - Array of output values. (`list(float())`)\n* y - Vertical position of minimum. (`integer()`)\n* x - Horizontal position of minimum. (`integer()`)","ref":"Vix.Vips.Operation.html#min/2-returns"},{"type":"function","title":"Vix.Vips.Operation.min!/2","doc":"Find image minimum","ref":"Vix.Vips.Operation.html#min!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.min!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#min!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.min!/2","doc":"* size - Number of minimum values to find. Default: `10`","ref":"Vix.Vips.Operation.html#min!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.min!/2","doc":"Operation returns a tuple\n\n* out - Output value. (`float()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* y-array - Array of vertical positions. (`list(integer())`)\n* x-array - Array of horizontal positions. (`list(integer())`)\n* out-array - Array of output values. (`list(float())`)\n* y - Vertical position of minimum. (`integer()`)\n* x - Horizontal position of minimum. (`integer()`)","ref":"Vix.Vips.Operation.html#min!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.morph/3","doc":"Morphology operation","ref":"Vix.Vips.Operation.html#morph/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.morph/3","doc":"* input - Input image argument\n  * mask - Input matrix image\n  * morph - Morphological operation to perform","ref":"Vix.Vips.Operation.html#morph/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.morph!/3","doc":"Morphology operation","ref":"Vix.Vips.Operation.html#morph!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.morph!/3","doc":"* input - Input image argument\n  * mask - Input matrix image\n  * morph - Morphological operation to perform","ref":"Vix.Vips.Operation.html#morph!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.mosaic1/12","doc":"First-order mosaic of two images","ref":"Vix.Vips.Operation.html#mosaic1/12"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mosaic1/12","doc":"* ref - Reference image\n  * sec - Secondary image\n  * direction - Horizontal or vertical mosaic\n  * xr1 - Position of first reference tie-point\n  * yr1 - Position of first reference tie-point\n  * xs1 - Position of first secondary tie-point\n  * ys1 - Position of first secondary tie-point\n  * xr2 - Position of second reference tie-point\n  * yr2 - Position of second reference tie-point\n  * xs2 - Position of second secondary tie-point\n  * ys2 - Position of second secondary tie-point","ref":"Vix.Vips.Operation.html#mosaic1/12-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mosaic1/12","doc":"* bandno - Band to search for features on. Default: `0`\n* mblend - Maximum blend size. Default: `10`\n* interpolate - Interpolate pixels with this. \n* search - Search to improve tie-points. Default: `false`\n* harea - Half area size. Default: `15`\n* hwindow - Half window size. Default: `5`","ref":"Vix.Vips.Operation.html#mosaic1/12-optional"},{"type":"function","title":"Vix.Vips.Operation.mosaic1!/12","doc":"First-order mosaic of two images","ref":"Vix.Vips.Operation.html#mosaic1!/12"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mosaic1!/12","doc":"* ref - Reference image\n  * sec - Secondary image\n  * direction - Horizontal or vertical mosaic\n  * xr1 - Position of first reference tie-point\n  * yr1 - Position of first reference tie-point\n  * xs1 - Position of first secondary tie-point\n  * ys1 - Position of first secondary tie-point\n  * xr2 - Position of second reference tie-point\n  * yr2 - Position of second reference tie-point\n  * xs2 - Position of second secondary tie-point\n  * ys2 - Position of second secondary tie-point","ref":"Vix.Vips.Operation.html#mosaic1!/12-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mosaic1!/12","doc":"* bandno - Band to search for features on. Default: `0`\n* mblend - Maximum blend size. Default: `10`\n* interpolate - Interpolate pixels with this. \n* search - Search to improve tie-points. Default: `false`\n* harea - Half area size. Default: `15`\n* hwindow - Half window size. Default: `5`","ref":"Vix.Vips.Operation.html#mosaic1!/12-optional"},{"type":"function","title":"Vix.Vips.Operation.mosaic/8","doc":"Mosaic two images","ref":"Vix.Vips.Operation.html#mosaic/8"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mosaic/8","doc":"* ref - Reference image\n  * sec - Secondary image\n  * direction - Horizontal or vertical mosaic\n  * xref - Position of reference tie-point\n  * yref - Position of reference tie-point\n  * xsec - Position of secondary tie-point\n  * ysec - Position of secondary tie-point","ref":"Vix.Vips.Operation.html#mosaic/8-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mosaic/8","doc":"* bandno - Band to search for features on. Default: `0`\n* mblend - Maximum blend size. Default: `10`\n* harea - Half area size. Default: `15`\n* hwindow - Half window size. Default: `5`","ref":"Vix.Vips.Operation.html#mosaic/8-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.mosaic/8","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* dx1 - Detected first-order displacement. (`float()`)\n* dy1 - Detected first-order displacement. (`float()`)\n* angle1 - Detected rotation. (`float()`)\n* scale1 - Detected scale. (`float()`)\n* dy0 - Detected integer offset. (`integer()`)\n* dx0 - Detected integer offset. (`integer()`)","ref":"Vix.Vips.Operation.html#mosaic/8-returns"},{"type":"function","title":"Vix.Vips.Operation.mosaic!/8","doc":"Mosaic two images","ref":"Vix.Vips.Operation.html#mosaic!/8"},{"type":"function","title":"Arguments - Vix.Vips.Operation.mosaic!/8","doc":"* ref - Reference image\n  * sec - Secondary image\n  * direction - Horizontal or vertical mosaic\n  * xref - Position of reference tie-point\n  * yref - Position of reference tie-point\n  * xsec - Position of secondary tie-point\n  * ysec - Position of secondary tie-point","ref":"Vix.Vips.Operation.html#mosaic!/8-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.mosaic!/8","doc":"* bandno - Band to search for features on. Default: `0`\n* mblend - Maximum blend size. Default: `10`\n* harea - Half area size. Default: `15`\n* hwindow - Half window size. Default: `5`","ref":"Vix.Vips.Operation.html#mosaic!/8-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.mosaic!/8","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* dx1 - Detected first-order displacement. (`float()`)\n* dy1 - Detected first-order displacement. (`float()`)\n* angle1 - Detected rotation. (`float()`)\n* scale1 - Detected scale. (`float()`)\n* dy0 - Detected integer offset. (`integer()`)\n* dx0 - Detected integer offset. (`integer()`)","ref":"Vix.Vips.Operation.html#mosaic!/8-returns"},{"type":"function","title":"Vix.Vips.Operation.msb/2","doc":"Pick most-significant byte from an image","ref":"Vix.Vips.Operation.html#msb/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.msb/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#msb/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.msb/2","doc":"* band - Band to msb. Default: `0`","ref":"Vix.Vips.Operation.html#msb/2-optional"},{"type":"function","title":"Vix.Vips.Operation.msb!/2","doc":"Pick most-significant byte from an image","ref":"Vix.Vips.Operation.html#msb!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.msb!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#msb!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.msb!/2","doc":"* band - Band to msb. Default: `0`","ref":"Vix.Vips.Operation.html#msb!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.multiply/2","doc":"Multiply two images","ref":"Vix.Vips.Operation.html#multiply/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.multiply/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#multiply/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.multiply!/2","doc":"Multiply two images","ref":"Vix.Vips.Operation.html#multiply!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.multiply!/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#multiply!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.percent/2","doc":"Find threshold for percent of pixels","ref":"Vix.Vips.Operation.html#percent/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.percent/2","doc":"* input - Input image\n  * percent - Percent of pixels","ref":"Vix.Vips.Operation.html#percent/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.percent!/2","doc":"Find threshold for percent of pixels","ref":"Vix.Vips.Operation.html#percent!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.percent!/2","doc":"* input - Input image\n  * percent - Percent of pixels","ref":"Vix.Vips.Operation.html#percent!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.perlin/3","doc":"Make a perlin noise image","ref":"Vix.Vips.Operation.html#perlin/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.perlin/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#perlin/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.perlin/3","doc":"* seed - Random number seed. Default: `0`\n* uchar - Output an unsigned char image. Default: `false`\n* cell-size - Size of Perlin cells. Default: `256`","ref":"Vix.Vips.Operation.html#perlin/3-optional"},{"type":"function","title":"Vix.Vips.Operation.perlin!/3","doc":"Make a perlin noise image","ref":"Vix.Vips.Operation.html#perlin!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.perlin!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#perlin!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.perlin!/3","doc":"* seed - Random number seed. Default: `0`\n* uchar - Output an unsigned char image. Default: `false`\n* cell-size - Size of Perlin cells. Default: `256`","ref":"Vix.Vips.Operation.html#perlin!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.phasecor/2","doc":"Calculate phase correlation","ref":"Vix.Vips.Operation.html#phasecor/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.phasecor/2","doc":"* input - Input image\n  * in2 - Second input image","ref":"Vix.Vips.Operation.html#phasecor/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.phasecor!/2","doc":"Calculate phase correlation","ref":"Vix.Vips.Operation.html#phasecor!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.phasecor!/2","doc":"* input - Input image\n  * in2 - Second input image","ref":"Vix.Vips.Operation.html#phasecor!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.pngload/2","doc":"Load png from file","ref":"Vix.Vips.Operation.html#pngload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#pngload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`","ref":"Vix.Vips.Operation.html#pngload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.pngload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#pngload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.pngload!/2","doc":"Load png from file","ref":"Vix.Vips.Operation.html#pngload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#pngload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`","ref":"Vix.Vips.Operation.html#pngload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.pngload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#pngload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.pngload_buffer/2","doc":"Load png from buffer","ref":"Vix.Vips.Operation.html#pngload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#pngload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`","ref":"Vix.Vips.Operation.html#pngload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.pngload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#pngload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.pngload_buffer!/2","doc":"Load png from buffer","ref":"Vix.Vips.Operation.html#pngload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#pngload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Remove all denial of service limits. Default: `false`","ref":"Vix.Vips.Operation.html#pngload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.pngload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#pngload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.pngsave/3","doc":"Save image to file as png","ref":"Vix.Vips.Operation.html#pngsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#pngsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* effort - Quantisation CPU effort. Default: `7`\n* bitdepth - Write as a 1, 2, 4, 8 or 16 bit image. Default: `8`\n* dither - Amount of dithering. Default: `1.0`\n* Q - Quantisation quality. Default: `100`\n* colours - Max number of palette colours. Default: `256`\n* palette - Quantise to 8bpp palette. Default: `false`\n* filter - libspng row filter flag(s). Default: `[:VIPS_FOREIGN_PNG_FILTER_NONE]`\n* interlace - Interlace image. Default: `false`\n* compression - Compression factor. Default: `6`","ref":"Vix.Vips.Operation.html#pngsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.pngsave!/3","doc":"Save image to file as png","ref":"Vix.Vips.Operation.html#pngsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#pngsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* effort - Quantisation CPU effort. Default: `7`\n* bitdepth - Write as a 1, 2, 4, 8 or 16 bit image. Default: `8`\n* dither - Amount of dithering. Default: `1.0`\n* Q - Quantisation quality. Default: `100`\n* colours - Max number of palette colours. Default: `256`\n* palette - Quantise to 8bpp palette. Default: `false`\n* filter - libspng row filter flag(s). Default: `[:VIPS_FOREIGN_PNG_FILTER_NONE]`\n* interlace - Interlace image. Default: `false`\n* compression - Compression factor. Default: `6`","ref":"Vix.Vips.Operation.html#pngsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.pngsave_buffer/2","doc":"Save image to buffer as png","ref":"Vix.Vips.Operation.html#pngsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#pngsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* effort - Quantisation CPU effort. Default: `7`\n* bitdepth - Write as a 1, 2, 4, 8 or 16 bit image. Default: `8`\n* dither - Amount of dithering. Default: `1.0`\n* Q - Quantisation quality. Default: `100`\n* colours - Max number of palette colours. Default: `256`\n* palette - Quantise to 8bpp palette. Default: `false`\n* filter - libspng row filter flag(s). Default: `[:VIPS_FOREIGN_PNG_FILTER_NONE]`\n* interlace - Interlace image. Default: `false`\n* compression - Compression factor. Default: `6`","ref":"Vix.Vips.Operation.html#pngsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.pngsave_buffer!/2","doc":"Save image to buffer as png","ref":"Vix.Vips.Operation.html#pngsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.pngsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#pngsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.pngsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* effort - Quantisation CPU effort. Default: `7`\n* bitdepth - Write as a 1, 2, 4, 8 or 16 bit image. Default: `8`\n* dither - Amount of dithering. Default: `1.0`\n* Q - Quantisation quality. Default: `100`\n* colours - Max number of palette colours. Default: `256`\n* palette - Quantise to 8bpp palette. Default: `false`\n* filter - libspng row filter flag(s). Default: `[:VIPS_FOREIGN_PNG_FILTER_NONE]`\n* interlace - Interlace image. Default: `false`\n* compression - Compression factor. Default: `6`","ref":"Vix.Vips.Operation.html#pngsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.premultiply/2","doc":"Premultiply image alpha","ref":"Vix.Vips.Operation.html#premultiply/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.premultiply/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#premultiply/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.premultiply/2","doc":"* max-alpha - Maximum value of alpha channel. Default: `255.0`","ref":"Vix.Vips.Operation.html#premultiply/2-optional"},{"type":"function","title":"Vix.Vips.Operation.premultiply!/2","doc":"Premultiply image alpha","ref":"Vix.Vips.Operation.html#premultiply!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.premultiply!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#premultiply!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.premultiply!/2","doc":"* max-alpha - Maximum value of alpha channel. Default: `255.0`","ref":"Vix.Vips.Operation.html#premultiply!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.prewitt/1","doc":"Prewitt edge detector","ref":"Vix.Vips.Operation.html#prewitt/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.prewitt/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#prewitt/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.prewitt!/1","doc":"Prewitt edge detector","ref":"Vix.Vips.Operation.html#prewitt!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.prewitt!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#prewitt!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.profile/1","doc":"Find image profiles","ref":"Vix.Vips.Operation.html#profile/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.profile/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#profile/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.profile/1","doc":"Operation returns a tuple\n\n* columns - First non-zero pixel in column. (`Vix.Vips.Image.t()`)\n* rows - First non-zero pixel in row. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#profile/1-returns"},{"type":"function","title":"Vix.Vips.Operation.profile!/1","doc":"Find image profiles","ref":"Vix.Vips.Operation.html#profile!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.profile!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#profile!/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.profile!/1","doc":"Operation returns a tuple\n\n* columns - First non-zero pixel in column. (`Vix.Vips.Image.t()`)\n* rows - First non-zero pixel in row. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#profile!/1-returns"},{"type":"function","title":"Vix.Vips.Operation.profile_load/1","doc":"Load named icc profile","ref":"Vix.Vips.Operation.html#profile_load/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.profile_load/1","doc":"* name - Profile name","ref":"Vix.Vips.Operation.html#profile_load/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.profile_load!/1","doc":"Load named icc profile","ref":"Vix.Vips.Operation.html#profile_load!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.profile_load!/1","doc":"* name - Profile name","ref":"Vix.Vips.Operation.html#profile_load!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.project/1","doc":"Find image projections","ref":"Vix.Vips.Operation.html#project/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.project/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#project/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.project/1","doc":"Operation returns a tuple\n\n* columns - Sums of columns. (`Vix.Vips.Image.t()`)\n* rows - Sums of rows. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#project/1-returns"},{"type":"function","title":"Vix.Vips.Operation.project!/1","doc":"Find image projections","ref":"Vix.Vips.Operation.html#project!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.project!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#project!/1-arguments"},{"type":"function","title":"Returns - Vix.Vips.Operation.project!/1","doc":"Operation returns a tuple\n\n* columns - Sums of columns. (`Vix.Vips.Image.t()`)\n* rows - Sums of rows. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#project!/1-returns"},{"type":"function","title":"Vix.Vips.Operation.quadratic/3","doc":"Resample an image with a quadratic transform","ref":"Vix.Vips.Operation.html#quadratic/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.quadratic/3","doc":"* input - Input image argument\n  * coeff - Coefficient matrix","ref":"Vix.Vips.Operation.html#quadratic/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.quadratic/3","doc":"* interpolate - Interpolate values with this.","ref":"Vix.Vips.Operation.html#quadratic/3-optional"},{"type":"function","title":"Vix.Vips.Operation.quadratic!/3","doc":"Resample an image with a quadratic transform","ref":"Vix.Vips.Operation.html#quadratic!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.quadratic!/3","doc":"* input - Input image argument\n  * coeff - Coefficient matrix","ref":"Vix.Vips.Operation.html#quadratic!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.quadratic!/3","doc":"* interpolate - Interpolate values with this.","ref":"Vix.Vips.Operation.html#quadratic!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.rad2float/1","doc":"Unpack radiance coding to float rgb","ref":"Vix.Vips.Operation.html#rad2float/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rad2float/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#rad2float/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.rad2float!/1","doc":"Unpack radiance coding to float rgb","ref":"Vix.Vips.Operation.html#rad2float!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rad2float!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#rad2float!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.rank/4","doc":"Rank filter","ref":"Vix.Vips.Operation.html#rank/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rank/4","doc":"* input - Input image argument\n  * width - Window width in pixels\n  * height - Window height in pixels\n  * index - Select pixel at index","ref":"Vix.Vips.Operation.html#rank/4-arguments"},{"type":"function","title":"Vix.Vips.Operation.rank!/4","doc":"Rank filter","ref":"Vix.Vips.Operation.html#rank!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rank!/4","doc":"* input - Input image argument\n  * width - Window width in pixels\n  * height - Window height in pixels\n  * index - Select pixel at index","ref":"Vix.Vips.Operation.html#rank!/4-arguments"},{"type":"function","title":"Vix.Vips.Operation.rawload/5","doc":"Load raw data from a file","ref":"Vix.Vips.Operation.html#rawload/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rawload/5","doc":"* filename - Filename to load from\n  * width - Image width in pixels\n  * height - Image height in pixels\n  * bands - Number of bands in image","ref":"Vix.Vips.Operation.html#rawload/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rawload/5","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* interpretation - Pixel interpretation. Default: `:VIPS_INTERPRETATION_MULTIBAND`\n* format - Pixel format in image. Default: `:VIPS_FORMAT_UCHAR`\n* offset - Offset in bytes from start of file. Default: `0`","ref":"Vix.Vips.Operation.html#rawload/5-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.rawload/5","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#rawload/5-returns"},{"type":"function","title":"Vix.Vips.Operation.rawload!/5","doc":"Load raw data from a file","ref":"Vix.Vips.Operation.html#rawload!/5"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rawload!/5","doc":"* filename - Filename to load from\n  * width - Image width in pixels\n  * height - Image height in pixels\n  * bands - Number of bands in image","ref":"Vix.Vips.Operation.html#rawload!/5-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rawload!/5","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* interpretation - Pixel interpretation. Default: `:VIPS_INTERPRETATION_MULTIBAND`\n* format - Pixel format in image. Default: `:VIPS_FORMAT_UCHAR`\n* offset - Offset in bytes from start of file. Default: `0`","ref":"Vix.Vips.Operation.html#rawload!/5-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.rawload!/5","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#rawload!/5-returns"},{"type":"function","title":"Vix.Vips.Operation.rawsave/3","doc":"Save image to raw file","ref":"Vix.Vips.Operation.html#rawsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rawsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#rawsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rawsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#rawsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.rawsave!/3","doc":"Save image to raw file","ref":"Vix.Vips.Operation.html#rawsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rawsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#rawsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rawsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#rawsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.rawsave_fd/3","doc":"Write raw image to file descriptor","ref":"Vix.Vips.Operation.html#rawsave_fd/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rawsave_fd/3","doc":"* input - Image to save\n  * fd - File descriptor to write to","ref":"Vix.Vips.Operation.html#rawsave_fd/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rawsave_fd/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#rawsave_fd/3-optional"},{"type":"function","title":"Vix.Vips.Operation.rawsave_fd!/3","doc":"Write raw image to file descriptor","ref":"Vix.Vips.Operation.html#rawsave_fd!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rawsave_fd!/3","doc":"* input - Image to save\n  * fd - File descriptor to write to","ref":"Vix.Vips.Operation.html#rawsave_fd!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rawsave_fd!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#rawsave_fd!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.recomb/2","doc":"Linear recombination with matrix","ref":"Vix.Vips.Operation.html#recomb/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.recomb/2","doc":"* input - Input image argument\n  * m - Matrix of coefficients","ref":"Vix.Vips.Operation.html#recomb/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.recomb!/2","doc":"Linear recombination with matrix","ref":"Vix.Vips.Operation.html#recomb!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.recomb!/2","doc":"* input - Input image argument\n  * m - Matrix of coefficients","ref":"Vix.Vips.Operation.html#recomb!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.reduce/4","doc":"Reduce an image","ref":"Vix.Vips.Operation.html#reduce/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.reduce/4","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#reduce/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.reduce/4","doc":"* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `0.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`","ref":"Vix.Vips.Operation.html#reduce/4-optional"},{"type":"function","title":"Vix.Vips.Operation.reduce!/4","doc":"Reduce an image","ref":"Vix.Vips.Operation.html#reduce!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.reduce!/4","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#reduce!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.reduce!/4","doc":"* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `0.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`","ref":"Vix.Vips.Operation.html#reduce!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.reduceh/3","doc":"Shrink an image horizontally","ref":"Vix.Vips.Operation.html#reduceh/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.reduceh/3","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor","ref":"Vix.Vips.Operation.html#reduceh/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.reduceh/3","doc":"* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `0.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`","ref":"Vix.Vips.Operation.html#reduceh/3-optional"},{"type":"function","title":"Vix.Vips.Operation.reduceh!/3","doc":"Shrink an image horizontally","ref":"Vix.Vips.Operation.html#reduceh!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.reduceh!/3","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor","ref":"Vix.Vips.Operation.html#reduceh!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.reduceh!/3","doc":"* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `0.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`","ref":"Vix.Vips.Operation.html#reduceh!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.reducev/3","doc":"Shrink an image vertically","ref":"Vix.Vips.Operation.html#reducev/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.reducev/3","doc":"* input - Input image argument\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#reducev/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.reducev/3","doc":"* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `0.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`","ref":"Vix.Vips.Operation.html#reducev/3-optional"},{"type":"function","title":"Vix.Vips.Operation.reducev!/3","doc":"Shrink an image vertically","ref":"Vix.Vips.Operation.html#reducev!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.reducev!/3","doc":"* input - Input image argument\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#reducev!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.reducev!/3","doc":"* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `0.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`","ref":"Vix.Vips.Operation.html#reducev!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.relational/3","doc":"Relational operation on two images","ref":"Vix.Vips.Operation.html#relational/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.relational/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * relational - Relational to perform","ref":"Vix.Vips.Operation.html#relational/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.relational!/3","doc":"Relational operation on two images","ref":"Vix.Vips.Operation.html#relational!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.relational!/3","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument\n  * relational - Relational to perform","ref":"Vix.Vips.Operation.html#relational!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.relational_const/3","doc":"Relational operations against a constant","ref":"Vix.Vips.Operation.html#relational_const/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.relational_const/3","doc":"* input - Input image\n  * relational - Relational to perform\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#relational_const/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.relational_const!/3","doc":"Relational operations against a constant","ref":"Vix.Vips.Operation.html#relational_const!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.relational_const!/3","doc":"* input - Input image\n  * relational - Relational to perform\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#relational_const!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.remainder/2","doc":"Remainder after integer division of two images","ref":"Vix.Vips.Operation.html#remainder/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.remainder/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#remainder/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.remainder!/2","doc":"Remainder after integer division of two images","ref":"Vix.Vips.Operation.html#remainder!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.remainder!/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#remainder!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.remainder_const/2","doc":"Remainder after integer division of an image and a constant","ref":"Vix.Vips.Operation.html#remainder_const/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.remainder_const/2","doc":"* input - Input image\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#remainder_const/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.remainder_const!/2","doc":"Remainder after integer division of an image and a constant","ref":"Vix.Vips.Operation.html#remainder_const!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.remainder_const!/2","doc":"* input - Input image\n  * c - Array of constants","ref":"Vix.Vips.Operation.html#remainder_const!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.replicate/3","doc":"Replicate an image","ref":"Vix.Vips.Operation.html#replicate/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.replicate/3","doc":"* input - Input image\n  * across - Repeat this many times horizontally\n  * down - Repeat this many times vertically","ref":"Vix.Vips.Operation.html#replicate/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.replicate!/3","doc":"Replicate an image","ref":"Vix.Vips.Operation.html#replicate!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.replicate!/3","doc":"* input - Input image\n  * across - Repeat this many times horizontally\n  * down - Repeat this many times vertically","ref":"Vix.Vips.Operation.html#replicate!/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.resize/3","doc":"Resize an image","ref":"Vix.Vips.Operation.html#resize/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.resize/3","doc":"* input - Input image argument\n  * scale - Scale image by this factor","ref":"Vix.Vips.Operation.html#resize/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.resize/3","doc":"* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* vscale - Vertical scale image by this factor. Default: `0.0`\n* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `2.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#resize/3-optional"},{"type":"function","title":"Vix.Vips.Operation.resize!/3","doc":"Resize an image","ref":"Vix.Vips.Operation.html#resize!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.resize!/3","doc":"* input - Input image argument\n  * scale - Scale image by this factor","ref":"Vix.Vips.Operation.html#resize!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.resize!/3","doc":"* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* vscale - Vertical scale image by this factor. Default: `0.0`\n* centre - Use centre sampling convention. Default: `false`\n* gap - Reducing gap. Default: `2.0`\n* kernel - Resampling kernel. Default: `:VIPS_KERNEL_LANCZOS3`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#resize!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.rot45/2","doc":"Rotate an image","ref":"Vix.Vips.Operation.html#rot45/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rot45/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#rot45/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rot45/2","doc":"* angle - Angle to rotate image. Default: `:VIPS_ANGLE45_D45`","ref":"Vix.Vips.Operation.html#rot45/2-optional"},{"type":"function","title":"Vix.Vips.Operation.rot45!/2","doc":"Rotate an image","ref":"Vix.Vips.Operation.html#rot45!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rot45!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#rot45!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rot45!/2","doc":"* angle - Angle to rotate image. Default: `:VIPS_ANGLE45_D45`","ref":"Vix.Vips.Operation.html#rot45!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.rot/2","doc":"Rotate an image","ref":"Vix.Vips.Operation.html#rot/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rot/2","doc":"* input - Input image\n  * angle - Angle to rotate image","ref":"Vix.Vips.Operation.html#rot/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.rot!/2","doc":"Rotate an image","ref":"Vix.Vips.Operation.html#rot!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rot!/2","doc":"* input - Input image\n  * angle - Angle to rotate image","ref":"Vix.Vips.Operation.html#rot!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.rotate/3","doc":"Rotate an image by a number of degrees","ref":"Vix.Vips.Operation.html#rotate/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rotate/3","doc":"* input - Input image argument\n  * angle - Rotate anticlockwise by this many degrees","ref":"Vix.Vips.Operation.html#rotate/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rotate/3","doc":"* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* ody - Vertical output displacement. Default: `0.0`\n* odx - Horizontal output displacement. Default: `0.0`\n* background - Background value. Default: `nil`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#rotate/3-optional"},{"type":"function","title":"Vix.Vips.Operation.rotate!/3","doc":"Rotate an image by a number of degrees","ref":"Vix.Vips.Operation.html#rotate!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.rotate!/3","doc":"* input - Input image argument\n  * angle - Rotate anticlockwise by this many degrees","ref":"Vix.Vips.Operation.html#rotate!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.rotate!/3","doc":"* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* ody - Vertical output displacement. Default: `0.0`\n* odx - Horizontal output displacement. Default: `0.0`\n* background - Background value. Default: `nil`\n* interpolate - Interpolate pixels with this.","ref":"Vix.Vips.Operation.html#rotate!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.round/2","doc":"Perform a round function on an image","ref":"Vix.Vips.Operation.html#round/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.round/2","doc":"* input - Input image\n  * round - Rounding operation to perform","ref":"Vix.Vips.Operation.html#round/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.round!/2","doc":"Perform a round function on an image","ref":"Vix.Vips.Operation.html#round!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.round!/2","doc":"* input - Input image\n  * round - Rounding operation to perform","ref":"Vix.Vips.Operation.html#round!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.scale/2","doc":"Scale an image to uchar","ref":"Vix.Vips.Operation.html#scale/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scale/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scale/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.scale/2","doc":"* log - Log scale. Default: `false`\n* exp - Exponent for log scale. Default: `0.25`","ref":"Vix.Vips.Operation.html#scale/2-optional"},{"type":"function","title":"Vix.Vips.Operation.scale!/2","doc":"Scale an image to uchar","ref":"Vix.Vips.Operation.html#scale!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scale!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scale!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.scale!/2","doc":"* log - Log scale. Default: `false`\n* exp - Exponent for log scale. Default: `0.25`","ref":"Vix.Vips.Operation.html#scale!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.scharr/1","doc":"Scharr edge detector","ref":"Vix.Vips.Operation.html#scharr/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scharr/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scharr/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.scharr!/1","doc":"Scharr edge detector","ref":"Vix.Vips.Operation.html#scharr!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scharr!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scharr!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.scrgb2bw/2","doc":"Convert scrgb to bw","ref":"Vix.Vips.Operation.html#scrgb2bw/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scrgb2bw/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scrgb2bw/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.scrgb2bw/2","doc":"* depth - Output device space depth in bits. Default: `8`","ref":"Vix.Vips.Operation.html#scrgb2bw/2-optional"},{"type":"function","title":"Vix.Vips.Operation.scrgb2bw!/2","doc":"Convert scrgb to bw","ref":"Vix.Vips.Operation.html#scrgb2bw!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scrgb2bw!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scrgb2bw!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.scrgb2bw!/2","doc":"* depth - Output device space depth in bits. Default: `8`","ref":"Vix.Vips.Operation.html#scrgb2bw!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.scrgb2srgb/2","doc":"Convert an scrgb image to srgb","ref":"Vix.Vips.Operation.html#scrgb2srgb/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scrgb2srgb/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scrgb2srgb/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.scrgb2srgb/2","doc":"* depth - Output device space depth in bits. Default: `8`","ref":"Vix.Vips.Operation.html#scrgb2srgb/2-optional"},{"type":"function","title":"Vix.Vips.Operation.scrgb2srgb!/2","doc":"Convert an scrgb image to srgb","ref":"Vix.Vips.Operation.html#scrgb2srgb!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scrgb2srgb!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scrgb2srgb!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.scrgb2srgb!/2","doc":"* depth - Output device space depth in bits. Default: `8`","ref":"Vix.Vips.Operation.html#scrgb2srgb!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.scrgb2xyz/1","doc":"Transform scrgb to xyz","ref":"Vix.Vips.Operation.html#scrgb2xyz/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scrgb2xyz/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scrgb2xyz/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.scrgb2xyz!/1","doc":"Transform scrgb to xyz","ref":"Vix.Vips.Operation.html#scrgb2xyz!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.scrgb2xyz!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#scrgb2xyz!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.sequential/2","doc":"Check sequential access","ref":"Vix.Vips.Operation.html#sequential/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sequential/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sequential/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.sequential/2","doc":"* access - Expected access pattern. Default: `:VIPS_ACCESS_SEQUENTIAL`\n* tile-height - Tile height in pixels. Default: `1`\n* trace - Trace pixel requests. Default: `true`","ref":"Vix.Vips.Operation.html#sequential/2-optional"},{"type":"function","title":"Vix.Vips.Operation.sequential!/2","doc":"Check sequential access","ref":"Vix.Vips.Operation.html#sequential!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sequential!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sequential!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.sequential!/2","doc":"* access - Expected access pattern. Default: `:VIPS_ACCESS_SEQUENTIAL`\n* tile-height - Tile height in pixels. Default: `1`\n* trace - Trace pixel requests. Default: `true`","ref":"Vix.Vips.Operation.html#sequential!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.sharpen/2","doc":"Unsharp masking for print","ref":"Vix.Vips.Operation.html#sharpen/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sharpen/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sharpen/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.sharpen/2","doc":"* m2 - Slope for jaggy areas. Default: `3.0`\n* m1 - Slope for flat areas. Default: `0.0`\n* y3 - Maximum darkening. Default: `20.0`\n* y2 - Maximum brightening. Default: `10.0`\n* x1 - Flat/jaggy threshold. Default: `2.0`\n* sigma - Sigma of Gaussian. Default: `0.5`\n* radius - Radius of Gaussian. Default: `1`","ref":"Vix.Vips.Operation.html#sharpen/2-optional"},{"type":"function","title":"Vix.Vips.Operation.sharpen!/2","doc":"Unsharp masking for print","ref":"Vix.Vips.Operation.html#sharpen!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sharpen!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sharpen!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.sharpen!/2","doc":"* m2 - Slope for jaggy areas. Default: `3.0`\n* m1 - Slope for flat areas. Default: `0.0`\n* y3 - Maximum darkening. Default: `20.0`\n* y2 - Maximum brightening. Default: `10.0`\n* x1 - Flat/jaggy threshold. Default: `2.0`\n* sigma - Sigma of Gaussian. Default: `0.5`\n* radius - Radius of Gaussian. Default: `1`","ref":"Vix.Vips.Operation.html#sharpen!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.shrink/4","doc":"Shrink an image","ref":"Vix.Vips.Operation.html#shrink/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.shrink/4","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#shrink/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.shrink/4","doc":"* ceil - Round-up output dimensions. Default: `false`","ref":"Vix.Vips.Operation.html#shrink/4-optional"},{"type":"function","title":"Vix.Vips.Operation.shrink!/4","doc":"Shrink an image","ref":"Vix.Vips.Operation.html#shrink!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.shrink!/4","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#shrink!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.shrink!/4","doc":"* ceil - Round-up output dimensions. Default: `false`","ref":"Vix.Vips.Operation.html#shrink!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.shrinkh/3","doc":"Shrink an image horizontally","ref":"Vix.Vips.Operation.html#shrinkh/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.shrinkh/3","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor","ref":"Vix.Vips.Operation.html#shrinkh/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.shrinkh/3","doc":"* ceil - Round-up output dimensions. Default: `false`","ref":"Vix.Vips.Operation.html#shrinkh/3-optional"},{"type":"function","title":"Vix.Vips.Operation.shrinkh!/3","doc":"Shrink an image horizontally","ref":"Vix.Vips.Operation.html#shrinkh!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.shrinkh!/3","doc":"* input - Input image argument\n  * hshrink - Horizontal shrink factor","ref":"Vix.Vips.Operation.html#shrinkh!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.shrinkh!/3","doc":"* ceil - Round-up output dimensions. Default: `false`","ref":"Vix.Vips.Operation.html#shrinkh!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.shrinkv/3","doc":"Shrink an image vertically","ref":"Vix.Vips.Operation.html#shrinkv/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.shrinkv/3","doc":"* input - Input image argument\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#shrinkv/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.shrinkv/3","doc":"* ceil - Round-up output dimensions. Default: `false`","ref":"Vix.Vips.Operation.html#shrinkv/3-optional"},{"type":"function","title":"Vix.Vips.Operation.shrinkv!/3","doc":"Shrink an image vertically","ref":"Vix.Vips.Operation.html#shrinkv!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.shrinkv!/3","doc":"* input - Input image argument\n  * vshrink - Vertical shrink factor","ref":"Vix.Vips.Operation.html#shrinkv!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.shrinkv!/3","doc":"* ceil - Round-up output dimensions. Default: `false`","ref":"Vix.Vips.Operation.html#shrinkv!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.sign/1","doc":"Unit vector of pixel","ref":"Vix.Vips.Operation.html#sign/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sign/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sign/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.sign!/1","doc":"Unit vector of pixel","ref":"Vix.Vips.Operation.html#sign!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sign!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sign!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.similarity/2","doc":"Similarity transform of an image","ref":"Vix.Vips.Operation.html#similarity/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.similarity/2","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#similarity/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.similarity/2","doc":"* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* ody - Vertical output displacement. Default: `0.0`\n* odx - Horizontal output displacement. Default: `0.0`\n* background - Background value. Default: `nil`\n* interpolate - Interpolate pixels with this. \n* angle - Rotate anticlockwise by this many degrees. Default: `0.0`\n* scale - Scale by this factor. Default: `1.0`","ref":"Vix.Vips.Operation.html#similarity/2-optional"},{"type":"function","title":"Vix.Vips.Operation.similarity!/2","doc":"Similarity transform of an image","ref":"Vix.Vips.Operation.html#similarity!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.similarity!/2","doc":"* input - Input image argument","ref":"Vix.Vips.Operation.html#similarity!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.similarity!/2","doc":"* idy - Vertical input displacement. Default: `0.0`\n* idx - Horizontal input displacement. Default: `0.0`\n* ody - Vertical output displacement. Default: `0.0`\n* odx - Horizontal output displacement. Default: `0.0`\n* background - Background value. Default: `nil`\n* interpolate - Interpolate pixels with this. \n* angle - Rotate anticlockwise by this many degrees. Default: `0.0`\n* scale - Scale by this factor. Default: `1.0`","ref":"Vix.Vips.Operation.html#similarity!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.sines/3","doc":"Make a 2d sine wave","ref":"Vix.Vips.Operation.html#sines/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sines/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#sines/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.sines/3","doc":"* vfreq - Vertical spatial frequency. Default: `0.5`\n* hfreq - Horizontal spatial frequency. Default: `0.5`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#sines/3-optional"},{"type":"function","title":"Vix.Vips.Operation.sines!/3","doc":"Make a 2d sine wave","ref":"Vix.Vips.Operation.html#sines!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sines!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#sines!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.sines!/3","doc":"* vfreq - Vertical spatial frequency. Default: `0.5`\n* hfreq - Horizontal spatial frequency. Default: `0.5`\n* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#sines!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.smartcrop/4","doc":"Extract an area from an image","ref":"Vix.Vips.Operation.html#smartcrop/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.smartcrop/4","doc":"* input - Input image\n  * width - Width of extract area\n  * height - Height of extract area","ref":"Vix.Vips.Operation.html#smartcrop/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.smartcrop/4","doc":"* premultiplied - Input image already has premultiplied alpha. Default: `false`\n* interesting - How to measure interestingness. Default: `:VIPS_INTERESTING_ATTENTION`","ref":"Vix.Vips.Operation.html#smartcrop/4-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.smartcrop/4","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* attention-y - Vertical position of attention centre. (`integer()`)\n* attention-x - Horizontal position of attention centre. (`integer()`)","ref":"Vix.Vips.Operation.html#smartcrop/4-returns"},{"type":"function","title":"Vix.Vips.Operation.smartcrop!/4","doc":"Extract an area from an image","ref":"Vix.Vips.Operation.html#smartcrop!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.smartcrop!/4","doc":"* input - Input image\n  * width - Width of extract area\n  * height - Height of extract area","ref":"Vix.Vips.Operation.html#smartcrop!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.smartcrop!/4","doc":"* premultiplied - Input image already has premultiplied alpha. Default: `false`\n* interesting - How to measure interestingness. Default: `:VIPS_INTERESTING_ATTENTION`","ref":"Vix.Vips.Operation.html#smartcrop!/4-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.smartcrop!/4","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* attention-y - Vertical position of attention centre. (`integer()`)\n* attention-x - Horizontal position of attention centre. (`integer()`)","ref":"Vix.Vips.Operation.html#smartcrop!/4-returns"},{"type":"function","title":"Vix.Vips.Operation.sobel/1","doc":"Sobel edge detector","ref":"Vix.Vips.Operation.html#sobel/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sobel/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sobel/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.sobel!/1","doc":"Sobel edge detector","ref":"Vix.Vips.Operation.html#sobel!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sobel!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#sobel!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.spcor/2","doc":"Spatial correlation","ref":"Vix.Vips.Operation.html#spcor/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.spcor/2","doc":"* input - Input image argument\n  * ref - Input reference image","ref":"Vix.Vips.Operation.html#spcor/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.spcor!/2","doc":"Spatial correlation","ref":"Vix.Vips.Operation.html#spcor!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.spcor!/2","doc":"* input - Input image argument\n  * ref - Input reference image","ref":"Vix.Vips.Operation.html#spcor!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.spectrum/1","doc":"Make displayable power spectrum","ref":"Vix.Vips.Operation.html#spectrum/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.spectrum/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#spectrum/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.spectrum!/1","doc":"Make displayable power spectrum","ref":"Vix.Vips.Operation.html#spectrum!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.spectrum!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#spectrum!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.srgb2hsv/1","doc":"Transform srgb to hsv","ref":"Vix.Vips.Operation.html#srgb2hsv/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.srgb2hsv/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#srgb2hsv/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.srgb2hsv!/1","doc":"Transform srgb to hsv","ref":"Vix.Vips.Operation.html#srgb2hsv!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.srgb2hsv!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#srgb2hsv!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.srgb2scrgb/1","doc":"Convert an srgb image to scrgb","ref":"Vix.Vips.Operation.html#srgb2scrgb/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.srgb2scrgb/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#srgb2scrgb/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.srgb2scrgb!/1","doc":"Convert an srgb image to scrgb","ref":"Vix.Vips.Operation.html#srgb2scrgb!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.srgb2scrgb!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#srgb2scrgb!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.stats/1","doc":"Find many image stats","ref":"Vix.Vips.Operation.html#stats/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.stats/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#stats/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.stats!/1","doc":"Find many image stats","ref":"Vix.Vips.Operation.html#stats!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.stats!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#stats!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.stdif/4","doc":"Statistical difference","ref":"Vix.Vips.Operation.html#stdif/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.stdif/4","doc":"* input - Input image\n  * width - Window width in pixels\n  * height - Window height in pixels","ref":"Vix.Vips.Operation.html#stdif/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.stdif/4","doc":"* a - Weight of new mean. Default: `0.5`\n* m0 - New mean. Default: `128.0`\n* b - Weight of new deviation. Default: `0.5`\n* s0 - New deviation. Default: `50.0`","ref":"Vix.Vips.Operation.html#stdif/4-optional"},{"type":"function","title":"Vix.Vips.Operation.stdif!/4","doc":"Statistical difference","ref":"Vix.Vips.Operation.html#stdif!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.stdif!/4","doc":"* input - Input image\n  * width - Window width in pixels\n  * height - Window height in pixels","ref":"Vix.Vips.Operation.html#stdif!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.stdif!/4","doc":"* a - Weight of new mean. Default: `0.5`\n* m0 - New mean. Default: `128.0`\n* b - Weight of new deviation. Default: `0.5`\n* s0 - New deviation. Default: `50.0`","ref":"Vix.Vips.Operation.html#stdif!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.subsample/4","doc":"Subsample an image","ref":"Vix.Vips.Operation.html#subsample/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.subsample/4","doc":"* input - Input image\n  * xfac - Horizontal subsample factor\n  * yfac - Vertical subsample factor","ref":"Vix.Vips.Operation.html#subsample/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.subsample/4","doc":"* point - Point sample. Default: `false`","ref":"Vix.Vips.Operation.html#subsample/4-optional"},{"type":"function","title":"Vix.Vips.Operation.subsample!/4","doc":"Subsample an image","ref":"Vix.Vips.Operation.html#subsample!/4"},{"type":"function","title":"Arguments - Vix.Vips.Operation.subsample!/4","doc":"* input - Input image\n  * xfac - Horizontal subsample factor\n  * yfac - Vertical subsample factor","ref":"Vix.Vips.Operation.html#subsample!/4-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.subsample!/4","doc":"* point - Point sample. Default: `false`","ref":"Vix.Vips.Operation.html#subsample!/4-optional"},{"type":"function","title":"Vix.Vips.Operation.subtract/2","doc":"Subtract two images","ref":"Vix.Vips.Operation.html#subtract/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.subtract/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#subtract/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.subtract!/2","doc":"Subtract two images","ref":"Vix.Vips.Operation.html#subtract!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.subtract!/2","doc":"* left - Left-hand image argument\n  * right - Right-hand image argument","ref":"Vix.Vips.Operation.html#subtract!/2-arguments"},{"type":"function","title":"Vix.Vips.Operation.sum/1","doc":"Sum an array of images","ref":"Vix.Vips.Operation.html#sum/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sum/1","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#sum/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.sum!/1","doc":"Sum an array of images","ref":"Vix.Vips.Operation.html#sum!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.sum!/1","doc":"* input - Array of input images","ref":"Vix.Vips.Operation.html#sum!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.svgload/2","doc":"Load svg with rsvg","ref":"Vix.Vips.Operation.html#svgload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.svgload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#svgload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.svgload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Allow SVG of any size. Default: `false`\n* scale - Scale output by this factor. Default: `1.0`\n* dpi - Render at this DPI. Default: `72.0`","ref":"Vix.Vips.Operation.html#svgload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.svgload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#svgload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.svgload!/2","doc":"Load svg with rsvg","ref":"Vix.Vips.Operation.html#svgload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.svgload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#svgload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.svgload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Allow SVG of any size. Default: `false`\n* scale - Scale output by this factor. Default: `1.0`\n* dpi - Render at this DPI. Default: `72.0`","ref":"Vix.Vips.Operation.html#svgload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.svgload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#svgload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.svgload_buffer/2","doc":"Load svg with rsvg","ref":"Vix.Vips.Operation.html#svgload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.svgload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#svgload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.svgload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Allow SVG of any size. Default: `false`\n* scale - Scale output by this factor. Default: `1.0`\n* dpi - Render at this DPI. Default: `72.0`","ref":"Vix.Vips.Operation.html#svgload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.svgload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#svgload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.svgload_buffer!/2","doc":"Load svg with rsvg","ref":"Vix.Vips.Operation.html#svgload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.svgload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#svgload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.svgload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* unlimited - Allow SVG of any size. Default: `false`\n* scale - Scale output by this factor. Default: `1.0`\n* dpi - Render at this DPI. Default: `72.0`","ref":"Vix.Vips.Operation.html#svgload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.svgload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#svgload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.switch/1","doc":"Find the index of the first non-zero pixel in tests","ref":"Vix.Vips.Operation.html#switch/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.switch/1","doc":"* tests - Table of images to test","ref":"Vix.Vips.Operation.html#switch/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.switch!/1","doc":"Find the index of the first non-zero pixel in tests","ref":"Vix.Vips.Operation.html#switch!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.switch!/1","doc":"* tests - Table of images to test","ref":"Vix.Vips.Operation.html#switch!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.system/2","doc":"Run an external command","ref":"Vix.Vips.Operation.html#system/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.system/2","doc":"* cmd-format - Command to run","ref":"Vix.Vips.Operation.html#system/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.system/2","doc":"* in-format - Format for input filename. Default: `nil`\n* out-format - Format for output filename. Default: `nil`\n* in - Array of input images. Default: `nil`","ref":"Vix.Vips.Operation.html#system/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.system/2","doc":"Operation returns a tuple\n\n\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* log - Command log. (`String.t()`)\n* out - Output image. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#system/2-returns"},{"type":"function","title":"Vix.Vips.Operation.system!/2","doc":"Run an external command","ref":"Vix.Vips.Operation.html#system!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.system!/2","doc":"* cmd-format - Command to run","ref":"Vix.Vips.Operation.html#system!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.system!/2","doc":"* in-format - Format for input filename. Default: `nil`\n* out-format - Format for output filename. Default: `nil`\n* in - Array of input images. Default: `nil`","ref":"Vix.Vips.Operation.html#system!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.system!/2","doc":"Operation returns a tuple\n\n\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* log - Command log. (`String.t()`)\n* out - Output image. (`Vix.Vips.Image.t()`)","ref":"Vix.Vips.Operation.html#system!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.text/2","doc":"Make a text image","ref":"Vix.Vips.Operation.html#text/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.text/2","doc":"* text - Text to render","ref":"Vix.Vips.Operation.html#text/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.text/2","doc":"* wrap - Wrap lines on word or character boundaries. Default: `:VIPS_TEXT_WRAP_WORD`\n* rgba - Enable RGBA output. Default: `false`\n* fontfile - Load this font file. Default: `nil`\n* spacing - Line spacing. Default: `0`\n* dpi - DPI to render at. Default: `72`\n* justify - Justify lines. Default: `false`\n* align - Align on the low, centre or high edge. Default: `:VIPS_ALIGN_LOW`\n* height - Maximum image height in pixels. Default: `0`\n* width - Maximum image width in pixels. Default: `0`\n* font - Font to render with. Default: `nil`","ref":"Vix.Vips.Operation.html#text/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.text/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* autofit-dpi - DPI selected by autofit. (`integer()`)","ref":"Vix.Vips.Operation.html#text/2-returns"},{"type":"function","title":"Vix.Vips.Operation.text!/2","doc":"Make a text image","ref":"Vix.Vips.Operation.html#text!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.text!/2","doc":"* text - Text to render","ref":"Vix.Vips.Operation.html#text!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.text!/2","doc":"* wrap - Wrap lines on word or character boundaries. Default: `:VIPS_TEXT_WRAP_WORD`\n* rgba - Enable RGBA output. Default: `false`\n* fontfile - Load this font file. Default: `nil`\n* spacing - Line spacing. Default: `0`\n* dpi - DPI to render at. Default: `72`\n* justify - Justify lines. Default: `false`\n* align - Align on the low, centre or high edge. Default: `:VIPS_ALIGN_LOW`\n* height - Maximum image height in pixels. Default: `0`\n* width - Maximum image width in pixels. Default: `0`\n* font - Font to render with. Default: `nil`","ref":"Vix.Vips.Operation.html#text!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.text!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* autofit-dpi - DPI selected by autofit. (`integer()`)","ref":"Vix.Vips.Operation.html#text!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.thumbnail/3","doc":"Generate thumbnail from file","ref":"Vix.Vips.Operation.html#thumbnail/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.thumbnail/3","doc":"* filename - Filename to read from\n  * width - Size to this width","ref":"Vix.Vips.Operation.html#thumbnail/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.thumbnail/3","doc":"* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* auto-rotate - Use orientation tags to rotate image upright. Default: `true`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* export-profile - Fallback export profile. Default: `nil`\n* import-profile - Fallback import profile. Default: `nil`\n* linear - Reduce in linear light. Default: `false`\n* crop - Reduce to fill target rectangle, then crop. Default: `:VIPS_INTERESTING_NONE`\n* no-rotate - Don't use orientation tags to rotate image upright. Default: `false`\n* size - Only upsize, only downsize, or both. Default: `:VIPS_SIZE_BOTH`\n* height - Size to this height. Default: `1`","ref":"Vix.Vips.Operation.html#thumbnail/3-optional"},{"type":"function","title":"Vix.Vips.Operation.thumbnail!/3","doc":"Generate thumbnail from file","ref":"Vix.Vips.Operation.html#thumbnail!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.thumbnail!/3","doc":"* filename - Filename to read from\n  * width - Size to this width","ref":"Vix.Vips.Operation.html#thumbnail!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.thumbnail!/3","doc":"* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* auto-rotate - Use orientation tags to rotate image upright. Default: `true`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* export-profile - Fallback export profile. Default: `nil`\n* import-profile - Fallback import profile. Default: `nil`\n* linear - Reduce in linear light. Default: `false`\n* crop - Reduce to fill target rectangle, then crop. Default: `:VIPS_INTERESTING_NONE`\n* no-rotate - Don't use orientation tags to rotate image upright. Default: `false`\n* size - Only upsize, only downsize, or both. Default: `:VIPS_SIZE_BOTH`\n* height - Size to this height. Default: `1`","ref":"Vix.Vips.Operation.html#thumbnail!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.thumbnail_buffer/3","doc":"Generate thumbnail from buffer","ref":"Vix.Vips.Operation.html#thumbnail_buffer/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.thumbnail_buffer/3","doc":"* buffer - Buffer to load from\n  * width - Size to this width","ref":"Vix.Vips.Operation.html#thumbnail_buffer/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.thumbnail_buffer/3","doc":"* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* auto-rotate - Use orientation tags to rotate image upright. Default: `true`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* export-profile - Fallback export profile. Default: `nil`\n* import-profile - Fallback import profile. Default: `nil`\n* linear - Reduce in linear light. Default: `false`\n* crop - Reduce to fill target rectangle, then crop. Default: `:VIPS_INTERESTING_NONE`\n* no-rotate - Don't use orientation tags to rotate image upright. Default: `false`\n* size - Only upsize, only downsize, or both. Default: `:VIPS_SIZE_BOTH`\n* height - Size to this height. Default: `1`\n* option-string - Options that are passed on to the underlying loader. Default: `\"\"`","ref":"Vix.Vips.Operation.html#thumbnail_buffer/3-optional"},{"type":"function","title":"Vix.Vips.Operation.thumbnail_buffer!/3","doc":"Generate thumbnail from buffer","ref":"Vix.Vips.Operation.html#thumbnail_buffer!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.thumbnail_buffer!/3","doc":"* buffer - Buffer to load from\n  * width - Size to this width","ref":"Vix.Vips.Operation.html#thumbnail_buffer!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.thumbnail_buffer!/3","doc":"* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* auto-rotate - Use orientation tags to rotate image upright. Default: `true`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* export-profile - Fallback export profile. Default: `nil`\n* import-profile - Fallback import profile. Default: `nil`\n* linear - Reduce in linear light. Default: `false`\n* crop - Reduce to fill target rectangle, then crop. Default: `:VIPS_INTERESTING_NONE`\n* no-rotate - Don't use orientation tags to rotate image upright. Default: `false`\n* size - Only upsize, only downsize, or both. Default: `:VIPS_SIZE_BOTH`\n* height - Size to this height. Default: `1`\n* option-string - Options that are passed on to the underlying loader. Default: `\"\"`","ref":"Vix.Vips.Operation.html#thumbnail_buffer!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.thumbnail_image/3","doc":"Generate thumbnail from image","ref":"Vix.Vips.Operation.html#thumbnail_image/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.thumbnail_image/3","doc":"* input - Input image argument\n  * width - Size to this width","ref":"Vix.Vips.Operation.html#thumbnail_image/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.thumbnail_image/3","doc":"* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* auto-rotate - Use orientation tags to rotate image upright. Default: `true`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* export-profile - Fallback export profile. Default: `nil`\n* import-profile - Fallback import profile. Default: `nil`\n* linear - Reduce in linear light. Default: `false`\n* crop - Reduce to fill target rectangle, then crop. Default: `:VIPS_INTERESTING_NONE`\n* no-rotate - Don't use orientation tags to rotate image upright. Default: `false`\n* size - Only upsize, only downsize, or both. Default: `:VIPS_SIZE_BOTH`\n* height - Size to this height. Default: `1`","ref":"Vix.Vips.Operation.html#thumbnail_image/3-optional"},{"type":"function","title":"Vix.Vips.Operation.thumbnail_image!/3","doc":"Generate thumbnail from image","ref":"Vix.Vips.Operation.html#thumbnail_image!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.thumbnail_image!/3","doc":"* input - Input image argument\n  * width - Size to this width","ref":"Vix.Vips.Operation.html#thumbnail_image!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.thumbnail_image!/3","doc":"* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* auto-rotate - Use orientation tags to rotate image upright. Default: `true`\n* intent - Rendering intent. Default: `:VIPS_INTENT_RELATIVE`\n* export-profile - Fallback export profile. Default: `nil`\n* import-profile - Fallback import profile. Default: `nil`\n* linear - Reduce in linear light. Default: `false`\n* crop - Reduce to fill target rectangle, then crop. Default: `:VIPS_INTERESTING_NONE`\n* no-rotate - Don't use orientation tags to rotate image upright. Default: `false`\n* size - Only upsize, only downsize, or both. Default: `:VIPS_SIZE_BOTH`\n* height - Size to this height. Default: `1`","ref":"Vix.Vips.Operation.html#thumbnail_image!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.tiffload/2","doc":"Load tiff from file","ref":"Vix.Vips.Operation.html#tiffload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#tiffload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* autorotate - Rotate image using orientation tag. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* subifd - Subifd index. Default: `-1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#tiffload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.tiffload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#tiffload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.tiffload!/2","doc":"Load tiff from file","ref":"Vix.Vips.Operation.html#tiffload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#tiffload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* autorotate - Rotate image using orientation tag. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* subifd - Subifd index. Default: `-1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#tiffload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.tiffload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#tiffload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.tiffload_buffer/2","doc":"Load tiff from buffer","ref":"Vix.Vips.Operation.html#tiffload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#tiffload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* autorotate - Rotate image using orientation tag. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* subifd - Subifd index. Default: `-1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#tiffload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.tiffload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#tiffload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.tiffload_buffer!/2","doc":"Load tiff from buffer","ref":"Vix.Vips.Operation.html#tiffload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#tiffload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* autorotate - Rotate image using orientation tag. Default: `false`\n* n - Number of pages to load, -1 for all. Default: `1`\n* subifd - Subifd index. Default: `-1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#tiffload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.tiffload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#tiffload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.tiffsave/3","doc":"Save image to tiff file","ref":"Vix.Vips.Operation.html#tiffsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#tiffsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* squash - Squash images down to 1 bit. Default: `false`\n* rgbjpeg - Output RGB JPEG rather than YCbCr. Default: `false`\n* premultiply - Save with premultiplied alpha. Default: `false`\n* subifd - Save pyr layers as sub-IFDs. Default: `false`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONETILE`\n* lossless - Enable WEBP lossless mode. Default: `false`\n* level - ZSTD compression level. Default: `10`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* properties - Write a properties document to IMAGEDESCRIPTION. Default: `false`\n* bigtiff - Write a bigtiff image. Default: `false`\n* yres - Vertical resolution in pixels/mm. Default: `1.0`\n* xres - Horizontal resolution in pixels/mm. Default: `1.0`\n* resunit - Resolution unit. Default: `:VIPS_FOREIGN_TIFF_RESUNIT_CM`\n* bitdepth - Write as a 1, 2, 4 or 8 bit image. Default: `0`\n* miniswhite - Use 0 for white in 1-bit images. Default: `false`\n* pyramid - Write a pyramidal tiff. Default: `false`\n* tile-height - Tile height in pixels. Default: `128`\n* tile-width - Tile width in pixels. Default: `128`\n* tile - Write a tiled tiff. Default: `false`\n* predictor - Compression prediction. Default: `:VIPS_FOREIGN_TIFF_PREDICTOR_HORIZONTAL`\n* Q - Q factor. Default: `75`\n* compression - Compression for this file. Default: `:VIPS_FOREIGN_TIFF_COMPRESSION_NONE`","ref":"Vix.Vips.Operation.html#tiffsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.tiffsave!/3","doc":"Save image to tiff file","ref":"Vix.Vips.Operation.html#tiffsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#tiffsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* squash - Squash images down to 1 bit. Default: `false`\n* rgbjpeg - Output RGB JPEG rather than YCbCr. Default: `false`\n* premultiply - Save with premultiplied alpha. Default: `false`\n* subifd - Save pyr layers as sub-IFDs. Default: `false`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONETILE`\n* lossless - Enable WEBP lossless mode. Default: `false`\n* level - ZSTD compression level. Default: `10`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* properties - Write a properties document to IMAGEDESCRIPTION. Default: `false`\n* bigtiff - Write a bigtiff image. Default: `false`\n* yres - Vertical resolution in pixels/mm. Default: `1.0`\n* xres - Horizontal resolution in pixels/mm. Default: `1.0`\n* resunit - Resolution unit. Default: `:VIPS_FOREIGN_TIFF_RESUNIT_CM`\n* bitdepth - Write as a 1, 2, 4 or 8 bit image. Default: `0`\n* miniswhite - Use 0 for white in 1-bit images. Default: `false`\n* pyramid - Write a pyramidal tiff. Default: `false`\n* tile-height - Tile height in pixels. Default: `128`\n* tile-width - Tile width in pixels. Default: `128`\n* tile - Write a tiled tiff. Default: `false`\n* predictor - Compression prediction. Default: `:VIPS_FOREIGN_TIFF_PREDICTOR_HORIZONTAL`\n* Q - Q factor. Default: `75`\n* compression - Compression for this file. Default: `:VIPS_FOREIGN_TIFF_COMPRESSION_NONE`","ref":"Vix.Vips.Operation.html#tiffsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.tiffsave_buffer/2","doc":"Save image to tiff buffer","ref":"Vix.Vips.Operation.html#tiffsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#tiffsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* squash - Squash images down to 1 bit. Default: `false`\n* rgbjpeg - Output RGB JPEG rather than YCbCr. Default: `false`\n* premultiply - Save with premultiplied alpha. Default: `false`\n* subifd - Save pyr layers as sub-IFDs. Default: `false`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONETILE`\n* lossless - Enable WEBP lossless mode. Default: `false`\n* level - ZSTD compression level. Default: `10`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* properties - Write a properties document to IMAGEDESCRIPTION. Default: `false`\n* bigtiff - Write a bigtiff image. Default: `false`\n* yres - Vertical resolution in pixels/mm. Default: `1.0`\n* xres - Horizontal resolution in pixels/mm. Default: `1.0`\n* resunit - Resolution unit. Default: `:VIPS_FOREIGN_TIFF_RESUNIT_CM`\n* bitdepth - Write as a 1, 2, 4 or 8 bit image. Default: `0`\n* miniswhite - Use 0 for white in 1-bit images. Default: `false`\n* pyramid - Write a pyramidal tiff. Default: `false`\n* tile-height - Tile height in pixels. Default: `128`\n* tile-width - Tile width in pixels. Default: `128`\n* tile - Write a tiled tiff. Default: `false`\n* predictor - Compression prediction. Default: `:VIPS_FOREIGN_TIFF_PREDICTOR_HORIZONTAL`\n* Q - Q factor. Default: `75`\n* compression - Compression for this file. Default: `:VIPS_FOREIGN_TIFF_COMPRESSION_NONE`","ref":"Vix.Vips.Operation.html#tiffsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.tiffsave_buffer!/2","doc":"Save image to tiff buffer","ref":"Vix.Vips.Operation.html#tiffsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tiffsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#tiffsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tiffsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* squash - Squash images down to 1 bit. Default: `false`\n* rgbjpeg - Output RGB JPEG rather than YCbCr. Default: `false`\n* premultiply - Save with premultiplied alpha. Default: `false`\n* subifd - Save pyr layers as sub-IFDs. Default: `false`\n* depth - Pyramid depth. Default: `:VIPS_FOREIGN_DZ_DEPTH_ONETILE`\n* lossless - Enable WEBP lossless mode. Default: `false`\n* level - ZSTD compression level. Default: `10`\n* region-shrink - Method to shrink regions. Default: `:VIPS_REGION_SHRINK_MEAN`\n* properties - Write a properties document to IMAGEDESCRIPTION. Default: `false`\n* bigtiff - Write a bigtiff image. Default: `false`\n* yres - Vertical resolution in pixels/mm. Default: `1.0`\n* xres - Horizontal resolution in pixels/mm. Default: `1.0`\n* resunit - Resolution unit. Default: `:VIPS_FOREIGN_TIFF_RESUNIT_CM`\n* bitdepth - Write as a 1, 2, 4 or 8 bit image. Default: `0`\n* miniswhite - Use 0 for white in 1-bit images. Default: `false`\n* pyramid - Write a pyramidal tiff. Default: `false`\n* tile-height - Tile height in pixels. Default: `128`\n* tile-width - Tile width in pixels. Default: `128`\n* tile - Write a tiled tiff. Default: `false`\n* predictor - Compression prediction. Default: `:VIPS_FOREIGN_TIFF_PREDICTOR_HORIZONTAL`\n* Q - Q factor. Default: `75`\n* compression - Compression for this file. Default: `:VIPS_FOREIGN_TIFF_COMPRESSION_NONE`","ref":"Vix.Vips.Operation.html#tiffsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.tilecache/2","doc":"Cache an image as a set of tiles","ref":"Vix.Vips.Operation.html#tilecache/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tilecache/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#tilecache/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tilecache/2","doc":"* persistent - Keep cache between evaluations. Default: `false`\n* threaded - Allow threaded access. Default: `false`\n* access - Expected access pattern. Default: `:VIPS_ACCESS_RANDOM`\n* max-tiles - Maximum number of tiles to cache. Default: `1000`\n* tile-height - Tile height in pixels. Default: `128`\n* tile-width - Tile width in pixels. Default: `128`","ref":"Vix.Vips.Operation.html#tilecache/2-optional"},{"type":"function","title":"Vix.Vips.Operation.tilecache!/2","doc":"Cache an image as a set of tiles","ref":"Vix.Vips.Operation.html#tilecache!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tilecache!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#tilecache!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tilecache!/2","doc":"* persistent - Keep cache between evaluations. Default: `false`\n* threaded - Allow threaded access. Default: `false`\n* access - Expected access pattern. Default: `:VIPS_ACCESS_RANDOM`\n* max-tiles - Maximum number of tiles to cache. Default: `1000`\n* tile-height - Tile height in pixels. Default: `128`\n* tile-width - Tile width in pixels. Default: `128`","ref":"Vix.Vips.Operation.html#tilecache!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.tonelut/1","doc":"Build a look-up table","ref":"Vix.Vips.Operation.html#tonelut/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tonelut/1","doc":"","ref":"Vix.Vips.Operation.html#tonelut/1-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tonelut/1","doc":"* H - Adjust highlights by this much. Default: `0.0`\n* M - Adjust mid-tones by this much. Default: `0.0`\n* S - Adjust shadows by this much. Default: `0.0`\n* Ph - Position of highlights. Default: `0.8`\n* Pm - Position of mid-tones. Default: `0.5`\n* Ps - Position of shadow. Default: `0.2`\n* Lw - Highest value in output. Default: `100.0`\n* Lb - Lowest value in output. Default: `0.0`\n* out-max - Maximum value in output LUT. Default: `32767`\n* in-max - Size of LUT to build. Default: `32767`","ref":"Vix.Vips.Operation.html#tonelut/1-optional"},{"type":"function","title":"Vix.Vips.Operation.tonelut!/1","doc":"Build a look-up table","ref":"Vix.Vips.Operation.html#tonelut!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.tonelut!/1","doc":"","ref":"Vix.Vips.Operation.html#tonelut!/1-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.tonelut!/1","doc":"* H - Adjust highlights by this much. Default: `0.0`\n* M - Adjust mid-tones by this much. Default: `0.0`\n* S - Adjust shadows by this much. Default: `0.0`\n* Ph - Position of highlights. Default: `0.8`\n* Pm - Position of mid-tones. Default: `0.5`\n* Ps - Position of shadow. Default: `0.2`\n* Lw - Highest value in output. Default: `100.0`\n* Lb - Lowest value in output. Default: `0.0`\n* out-max - Maximum value in output LUT. Default: `32767`\n* in-max - Size of LUT to build. Default: `32767`","ref":"Vix.Vips.Operation.html#tonelut!/1-optional"},{"type":"function","title":"Vix.Vips.Operation.transpose3d/2","doc":"Transpose3d an image","ref":"Vix.Vips.Operation.html#transpose3d/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.transpose3d/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#transpose3d/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.transpose3d/2","doc":"* page-height - Height of each input page. Default: `0`","ref":"Vix.Vips.Operation.html#transpose3d/2-optional"},{"type":"function","title":"Vix.Vips.Operation.transpose3d!/2","doc":"Transpose3d an image","ref":"Vix.Vips.Operation.html#transpose3d!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.transpose3d!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#transpose3d!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.transpose3d!/2","doc":"* page-height - Height of each input page. Default: `0`","ref":"Vix.Vips.Operation.html#transpose3d!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.unpremultiply/2","doc":"Unpremultiply image alpha","ref":"Vix.Vips.Operation.html#unpremultiply/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.unpremultiply/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#unpremultiply/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.unpremultiply/2","doc":"* alpha-band - Unpremultiply with this alpha. Default: `3`\n* max-alpha - Maximum value of alpha channel. Default: `255.0`","ref":"Vix.Vips.Operation.html#unpremultiply/2-optional"},{"type":"function","title":"Vix.Vips.Operation.unpremultiply!/2","doc":"Unpremultiply image alpha","ref":"Vix.Vips.Operation.html#unpremultiply!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.unpremultiply!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#unpremultiply!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.unpremultiply!/2","doc":"* alpha-band - Unpremultiply with this alpha. Default: `3`\n* max-alpha - Maximum value of alpha channel. Default: `255.0`","ref":"Vix.Vips.Operation.html#unpremultiply!/2-optional"},{"type":"type","title":"Vix.Vips.Operation.vips_access/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_access/0"},{"type":"type","title":"Vix.Vips.Operation.vips_align/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_align/0"},{"type":"type","title":"Vix.Vips.Operation.vips_angle45/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_angle45/0"},{"type":"type","title":"Vix.Vips.Operation.vips_angle/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_angle/0"},{"type":"type","title":"Vix.Vips.Operation.vips_band_format/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_band_format/0"},{"type":"type","title":"Vix.Vips.Operation.vips_blend_mode/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_blend_mode/0"},{"type":"type","title":"Vix.Vips.Operation.vips_coding/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_coding/0"},{"type":"type","title":"Vix.Vips.Operation.vips_combine/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_combine/0"},{"type":"type","title":"Vix.Vips.Operation.vips_combine_mode/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_combine_mode/0"},{"type":"type","title":"Vix.Vips.Operation.vips_compass_direction/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_compass_direction/0"},{"type":"type","title":"Vix.Vips.Operation.vips_demand_style/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_demand_style/0"},{"type":"type","title":"Vix.Vips.Operation.vips_direction/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_direction/0"},{"type":"type","title":"Vix.Vips.Operation.vips_extend/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_extend/0"},{"type":"type","title":"Vix.Vips.Operation.vips_fail_on/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_fail_on/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_dz_container/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_dz_container/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_dz_depth/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_dz_depth/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_dz_layout/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_dz_layout/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_flags/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_flags/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_heif_compression/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_heif_compression/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_heif_encoder/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_heif_encoder/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_keep/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_keep/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_png_filter/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_png_filter/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_subsample/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_subsample/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_tiff_compression/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_tiff_compression/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_tiff_predictor/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_tiff_predictor/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_tiff_resunit/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_tiff_resunit/0"},{"type":"type","title":"Vix.Vips.Operation.vips_foreign_webp_preset/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_foreign_webp_preset/0"},{"type":"type","title":"Vix.Vips.Operation.vips_intent/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_intent/0"},{"type":"type","title":"Vix.Vips.Operation.vips_interesting/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_interesting/0"},{"type":"type","title":"Vix.Vips.Operation.vips_interpretation/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_interpretation/0"},{"type":"type","title":"Vix.Vips.Operation.vips_kernel/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_kernel/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_boolean/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_boolean/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_complex2/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_complex2/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_complex/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_complex/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_complexget/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_complexget/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_math2/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_math2/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_math/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_math/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_morphology/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_morphology/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_relational/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_relational/0"},{"type":"type","title":"Vix.Vips.Operation.vips_operation_round/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_operation_round/0"},{"type":"type","title":"Vix.Vips.Operation.vips_pcs/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_pcs/0"},{"type":"type","title":"Vix.Vips.Operation.vips_precision/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_precision/0"},{"type":"type","title":"Vix.Vips.Operation.vips_region_shrink/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_region_shrink/0"},{"type":"type","title":"Vix.Vips.Operation.vips_size/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_size/0"},{"type":"type","title":"Vix.Vips.Operation.vips_text_wrap/0","doc":"","ref":"Vix.Vips.Operation.html#t:vips_text_wrap/0"},{"type":"function","title":"Vix.Vips.Operation.vipsload/2","doc":"Load vips from file","ref":"Vix.Vips.Operation.html#vipsload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.vipsload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#vipsload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.vipsload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`","ref":"Vix.Vips.Operation.html#vipsload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.vipsload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#vipsload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.vipsload!/2","doc":"Load vips from file","ref":"Vix.Vips.Operation.html#vipsload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.vipsload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#vipsload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.vipsload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`","ref":"Vix.Vips.Operation.html#vipsload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.vipsload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#vipsload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.vipssave/3","doc":"Save image to file in vips format","ref":"Vix.Vips.Operation.html#vipssave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.vipssave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#vipssave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.vipssave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#vipssave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.vipssave!/3","doc":"Save image to file in vips format","ref":"Vix.Vips.Operation.html#vipssave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.vipssave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#vipssave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.vipssave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`","ref":"Vix.Vips.Operation.html#vipssave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.webpload/2","doc":"Load webp from file","ref":"Vix.Vips.Operation.html#webpload/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpload/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#webpload/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpload/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* shrink - Shrink factor on load. Default: `1`\n* scale - Factor to scale by. Default: `1.0`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#webpload/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.webpload/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#webpload/2-returns"},{"type":"function","title":"Vix.Vips.Operation.webpload!/2","doc":"Load webp from file","ref":"Vix.Vips.Operation.html#webpload!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpload!/2","doc":"* filename - Filename to load from","ref":"Vix.Vips.Operation.html#webpload!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpload!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* shrink - Shrink factor on load. Default: `1`\n* scale - Factor to scale by. Default: `1.0`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#webpload!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.webpload!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#webpload!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.webpload_buffer/2","doc":"Load webp from buffer","ref":"Vix.Vips.Operation.html#webpload_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpload_buffer/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#webpload_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpload_buffer/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* shrink - Shrink factor on load. Default: `1`\n* scale - Factor to scale by. Default: `1.0`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#webpload_buffer/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.webpload_buffer/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#webpload_buffer/2-returns"},{"type":"function","title":"Vix.Vips.Operation.webpload_buffer!/2","doc":"Load webp from buffer","ref":"Vix.Vips.Operation.html#webpload_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpload_buffer!/2","doc":"* buffer - Buffer to load from","ref":"Vix.Vips.Operation.html#webpload_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpload_buffer!/2","doc":"* disc - Open to disc. Default: `true`\n* fail - Fail on first warning. Default: `false`\n* sequential - Sequential read only. Default: `false`\n* revalidate - Don't use a cached result for this operation. Default: `false`\n* fail-on - Error level to fail on. Default: `:VIPS_FAIL_ON_NONE`\n* access - Required access pattern for this file. Default: `:VIPS_ACCESS_RANDOM`\n* memory - Force open via memory. Default: `false`\n* shrink - Shrink factor on load. Default: `1`\n* scale - Factor to scale by. Default: `1.0`\n* n - Number of pages to load, -1 for all. Default: `1`\n* page - First page to load. Default: `0`","ref":"Vix.Vips.Operation.html#webpload_buffer!/2-optional"},{"type":"function","title":"Returns - Vix.Vips.Operation.webpload_buffer!/2","doc":"Operation returns a tuple\n\n* out - Output image. (`Vix.Vips.Image.t()`)\n\nLast value of the tuple is a map of additional output values as key-value pair.\n* flags - Flags for this file. (`vips_foreign_flags`)","ref":"Vix.Vips.Operation.html#webpload_buffer!/2-returns"},{"type":"function","title":"Vix.Vips.Operation.webpsave/3","doc":"Save as webp","ref":"Vix.Vips.Operation.html#webpsave/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpsave/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#webpsave/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpsave/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* mixed - Allow mixed encoding (might reduce file size). Default: `false`\n* reduction-effort - Level of CPU effort to reduce file size. Default: `4`\n* effort - Level of CPU effort to reduce file size. Default: `4`\n* kmax - Maximum number of frames between key frames. Default: `2147483647`\n* kmin - Minimum number of frames between key frames. Default: `2147483646`\n* min-size - Optimise for minimum size. Default: `false`\n* alpha-q - Change alpha plane fidelity for lossy compression. Default: `100`\n* near-lossless - Enable preprocessing in lossless mode (uses Q). Default: `false`\n* smart-subsample - Enable high quality chroma subsampling. Default: `false`\n* preset - Preset for lossy compression. Default: `:VIPS_FOREIGN_WEBP_PRESET_DEFAULT`\n* lossless - Enable lossless compression. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#webpsave/3-optional"},{"type":"function","title":"Vix.Vips.Operation.webpsave!/3","doc":"Save as webp","ref":"Vix.Vips.Operation.html#webpsave!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpsave!/3","doc":"* input - Image to save\n  * filename - Filename to save to","ref":"Vix.Vips.Operation.html#webpsave!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpsave!/3","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* mixed - Allow mixed encoding (might reduce file size). Default: `false`\n* reduction-effort - Level of CPU effort to reduce file size. Default: `4`\n* effort - Level of CPU effort to reduce file size. Default: `4`\n* kmax - Maximum number of frames between key frames. Default: `2147483647`\n* kmin - Minimum number of frames between key frames. Default: `2147483646`\n* min-size - Optimise for minimum size. Default: `false`\n* alpha-q - Change alpha plane fidelity for lossy compression. Default: `100`\n* near-lossless - Enable preprocessing in lossless mode (uses Q). Default: `false`\n* smart-subsample - Enable high quality chroma subsampling. Default: `false`\n* preset - Preset for lossy compression. Default: `:VIPS_FOREIGN_WEBP_PRESET_DEFAULT`\n* lossless - Enable lossless compression. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#webpsave!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.webpsave_buffer/2","doc":"Save as webp","ref":"Vix.Vips.Operation.html#webpsave_buffer/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpsave_buffer/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#webpsave_buffer/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpsave_buffer/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* mixed - Allow mixed encoding (might reduce file size). Default: `false`\n* reduction-effort - Level of CPU effort to reduce file size. Default: `4`\n* effort - Level of CPU effort to reduce file size. Default: `4`\n* kmax - Maximum number of frames between key frames. Default: `2147483647`\n* kmin - Minimum number of frames between key frames. Default: `2147483646`\n* min-size - Optimise for minimum size. Default: `false`\n* alpha-q - Change alpha plane fidelity for lossy compression. Default: `100`\n* near-lossless - Enable preprocessing in lossless mode (uses Q). Default: `false`\n* smart-subsample - Enable high quality chroma subsampling. Default: `false`\n* preset - Preset for lossy compression. Default: `:VIPS_FOREIGN_WEBP_PRESET_DEFAULT`\n* lossless - Enable lossless compression. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#webpsave_buffer/2-optional"},{"type":"function","title":"Vix.Vips.Operation.webpsave_buffer!/2","doc":"Save as webp","ref":"Vix.Vips.Operation.html#webpsave_buffer!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpsave_buffer!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#webpsave_buffer!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpsave_buffer!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* mixed - Allow mixed encoding (might reduce file size). Default: `false`\n* reduction-effort - Level of CPU effort to reduce file size. Default: `4`\n* effort - Level of CPU effort to reduce file size. Default: `4`\n* kmax - Maximum number of frames between key frames. Default: `2147483647`\n* kmin - Minimum number of frames between key frames. Default: `2147483646`\n* min-size - Optimise for minimum size. Default: `false`\n* alpha-q - Change alpha plane fidelity for lossy compression. Default: `100`\n* near-lossless - Enable preprocessing in lossless mode (uses Q). Default: `false`\n* smart-subsample - Enable high quality chroma subsampling. Default: `false`\n* preset - Preset for lossy compression. Default: `:VIPS_FOREIGN_WEBP_PRESET_DEFAULT`\n* lossless - Enable lossless compression. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#webpsave_buffer!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.webpsave_mime/2","doc":"Save image to webp mime","ref":"Vix.Vips.Operation.html#webpsave_mime/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpsave_mime/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#webpsave_mime/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpsave_mime/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* mixed - Allow mixed encoding (might reduce file size). Default: `false`\n* reduction-effort - Level of CPU effort to reduce file size. Default: `4`\n* effort - Level of CPU effort to reduce file size. Default: `4`\n* kmax - Maximum number of frames between key frames. Default: `2147483647`\n* kmin - Minimum number of frames between key frames. Default: `2147483646`\n* min-size - Optimise for minimum size. Default: `false`\n* alpha-q - Change alpha plane fidelity for lossy compression. Default: `100`\n* near-lossless - Enable preprocessing in lossless mode (uses Q). Default: `false`\n* smart-subsample - Enable high quality chroma subsampling. Default: `false`\n* preset - Preset for lossy compression. Default: `:VIPS_FOREIGN_WEBP_PRESET_DEFAULT`\n* lossless - Enable lossless compression. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#webpsave_mime/2-optional"},{"type":"function","title":"Vix.Vips.Operation.webpsave_mime!/2","doc":"Save image to webp mime","ref":"Vix.Vips.Operation.html#webpsave_mime!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.webpsave_mime!/2","doc":"* input - Image to save","ref":"Vix.Vips.Operation.html#webpsave_mime!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.webpsave_mime!/2","doc":"* strip - Strip all metadata from image. Default: `false`\n* profile - Filename of ICC profile to embed. Default: `nil`\n* page-height - Set page height for multipage save. Default: `0`\n* background - Background value. Default: `nil`\n* keep - Which metadata to retain. Default: `[:VIPS_FOREIGN_KEEP_OTHER, :VIPS_FOREIGN_KEEP_ICC, :VIPS_FOREIGN_KEEP_IPTC, :VIPS_FOREIGN_KEEP_XMP, :VIPS_FOREIGN_KEEP_EXIF]`\n* mixed - Allow mixed encoding (might reduce file size). Default: `false`\n* reduction-effort - Level of CPU effort to reduce file size. Default: `4`\n* effort - Level of CPU effort to reduce file size. Default: `4`\n* kmax - Maximum number of frames between key frames. Default: `2147483647`\n* kmin - Minimum number of frames between key frames. Default: `2147483646`\n* min-size - Optimise for minimum size. Default: `false`\n* alpha-q - Change alpha plane fidelity for lossy compression. Default: `100`\n* near-lossless - Enable preprocessing in lossless mode (uses Q). Default: `false`\n* smart-subsample - Enable high quality chroma subsampling. Default: `false`\n* preset - Preset for lossy compression. Default: `:VIPS_FOREIGN_WEBP_PRESET_DEFAULT`\n* lossless - Enable lossless compression. Default: `false`\n* Q - Q factor. Default: `75`","ref":"Vix.Vips.Operation.html#webpsave_mime!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.worley/3","doc":"Make a worley noise image","ref":"Vix.Vips.Operation.html#worley/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.worley/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#worley/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.worley/3","doc":"* seed - Random number seed. Default: `0`\n* cell-size - Size of Worley cells. Default: `256`","ref":"Vix.Vips.Operation.html#worley/3-optional"},{"type":"function","title":"Vix.Vips.Operation.worley!/3","doc":"Make a worley noise image","ref":"Vix.Vips.Operation.html#worley!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.worley!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#worley!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.worley!/3","doc":"* seed - Random number seed. Default: `0`\n* cell-size - Size of Worley cells. Default: `256`","ref":"Vix.Vips.Operation.html#worley!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.wrap/2","doc":"Wrap image origin","ref":"Vix.Vips.Operation.html#wrap/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.wrap/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#wrap/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.wrap/2","doc":"* y - Top edge of input in output. Default: `0`\n* x - Left edge of input in output. Default: `0`","ref":"Vix.Vips.Operation.html#wrap/2-optional"},{"type":"function","title":"Vix.Vips.Operation.wrap!/2","doc":"Wrap image origin","ref":"Vix.Vips.Operation.html#wrap!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.wrap!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#wrap!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.wrap!/2","doc":"* y - Top edge of input in output. Default: `0`\n* x - Left edge of input in output. Default: `0`","ref":"Vix.Vips.Operation.html#wrap!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.xyz2cmyk/1","doc":"Transform xyz to cmyk","ref":"Vix.Vips.Operation.html#xyz2cmyk/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2cmyk/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2cmyk/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.xyz2cmyk!/1","doc":"Transform xyz to cmyk","ref":"Vix.Vips.Operation.html#xyz2cmyk!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2cmyk!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2cmyk!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.xyz2lab/2","doc":"Transform xyz to lab","ref":"Vix.Vips.Operation.html#xyz2lab/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2lab/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2lab/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.xyz2lab/2","doc":"* temp - Colour temperature. Default: `nil`","ref":"Vix.Vips.Operation.html#xyz2lab/2-optional"},{"type":"function","title":"Vix.Vips.Operation.xyz2lab!/2","doc":"Transform xyz to lab","ref":"Vix.Vips.Operation.html#xyz2lab!/2"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2lab!/2","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2lab!/2-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.xyz2lab!/2","doc":"* temp - Colour temperature. Default: `nil`","ref":"Vix.Vips.Operation.html#xyz2lab!/2-optional"},{"type":"function","title":"Vix.Vips.Operation.xyz2scrgb/1","doc":"Transform xyz to scrgb","ref":"Vix.Vips.Operation.html#xyz2scrgb/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2scrgb/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2scrgb/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.xyz2scrgb!/1","doc":"Transform xyz to scrgb","ref":"Vix.Vips.Operation.html#xyz2scrgb!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2scrgb!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2scrgb!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.xyz2yxy/1","doc":"Transform xyz to yxy","ref":"Vix.Vips.Operation.html#xyz2yxy/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2yxy/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2yxy/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.xyz2yxy!/1","doc":"Transform xyz to yxy","ref":"Vix.Vips.Operation.html#xyz2yxy!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz2yxy!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#xyz2yxy!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.xyz/3","doc":"Make an image where pixel values are coordinates","ref":"Vix.Vips.Operation.html#xyz/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#xyz/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.xyz/3","doc":"* esize - Size of fifth dimension. Default: `1`\n* dsize - Size of fourth dimension. Default: `1`\n* csize - Size of third dimension. Default: `1`","ref":"Vix.Vips.Operation.html#xyz/3-optional"},{"type":"function","title":"Vix.Vips.Operation.xyz!/3","doc":"Make an image where pixel values are coordinates","ref":"Vix.Vips.Operation.html#xyz!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.xyz!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#xyz!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.xyz!/3","doc":"* esize - Size of fifth dimension. Default: `1`\n* dsize - Size of fourth dimension. Default: `1`\n* csize - Size of third dimension. Default: `1`","ref":"Vix.Vips.Operation.html#xyz!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.yxy2xyz/1","doc":"Transform yxy to xyz","ref":"Vix.Vips.Operation.html#yxy2xyz/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.yxy2xyz/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#yxy2xyz/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.yxy2xyz!/1","doc":"Transform yxy to xyz","ref":"Vix.Vips.Operation.html#yxy2xyz!/1"},{"type":"function","title":"Arguments - Vix.Vips.Operation.yxy2xyz!/1","doc":"* input - Input image","ref":"Vix.Vips.Operation.html#yxy2xyz!/1-arguments"},{"type":"function","title":"Vix.Vips.Operation.zone/3","doc":"Make a zone plate","ref":"Vix.Vips.Operation.html#zone/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.zone/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#zone/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.zone/3","doc":"* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#zone/3-optional"},{"type":"function","title":"Vix.Vips.Operation.zone!/3","doc":"Make a zone plate","ref":"Vix.Vips.Operation.html#zone!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.zone!/3","doc":"* width - Image width in pixels\n  * height - Image height in pixels","ref":"Vix.Vips.Operation.html#zone!/3-arguments"},{"type":"function","title":"Optional - Vix.Vips.Operation.zone!/3","doc":"* uchar - Output an unsigned char image. Default: `false`","ref":"Vix.Vips.Operation.html#zone!/3-optional"},{"type":"function","title":"Vix.Vips.Operation.zoom/3","doc":"Zoom an image","ref":"Vix.Vips.Operation.html#zoom/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.zoom/3","doc":"* input - Input image\n  * xfac - Horizontal zoom factor\n  * yfac - Vertical zoom factor","ref":"Vix.Vips.Operation.html#zoom/3-arguments"},{"type":"function","title":"Vix.Vips.Operation.zoom!/3","doc":"Zoom an image","ref":"Vix.Vips.Operation.html#zoom!/3"},{"type":"function","title":"Arguments - Vix.Vips.Operation.zoom!/3","doc":"* input - Input image\n  * xfac - Horizontal zoom factor\n  * yfac - Vertical zoom factor","ref":"Vix.Vips.Operation.html#zoom!/3-arguments"},{"type":"exception","title":"Vix.Vips.Image.Error","doc":"","ref":"Vix.Vips.Image.Error.html"},{"type":"extras","title":"Vix","doc":"# Vix\n\n[![CI](https://github.com/akash-akya/vix/actions/workflows/ci.yaml/badge.svg)](https://github.com/akash-akya/vix/actions/workflows/ci.yaml)\n[![Hex.pm](https://img.shields.io/hexpm/v/vix.svg)](https://hex.pm/packages/vix)\n[![docs](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/vix/)\n\n\nBlazing fast image processing for Elixir powered by [libvips](https://libvips.github.io/libvips/), the same engine that powers [sharp.js](https://github.com/lovell/sharp).","ref":"readme.html"},{"type":"extras","title":"Perfect For - Vix","doc":"- Building image processing APIs and services\n- Generating thumbnails at scale\n- Image manipulation in web applications\n- Computer vision preprocessing\n- Processing large scientific/satellite images","ref":"readme.html#perfect-for"},{"type":"extras","title":"Features - Vix","doc":"- **High Performance**: Uses libvips' demand-driven, horizontally threaded architecture\n- **Memory Efficient**: Processes images in chunks, perfect for large files\n- **Streaming Support**: Read/write images without loading them fully into memory\n- **Rich Ecosystem**: Zero-copy integration with [Nx](https://hex.pm/packages/nx) and [eVision](https://hex.pm/packages/evision)\n- **Zero Setup**: Pre-built binaries for MacOS and Linux platforms included.\n- **Auto-updating API**: New libvips features automatically available\n- **Comprehensive Documentation**: [Type specifications and documentation](https://hexdocs.pm/vix/Vix.Vips.Operation.html) for 300+ operations","ref":"readme.html#features"},{"type":"extras","title":"Quick Start - Vix","doc":"```elixir\nMix.install([\n  {:vix, \"~> 0.23\"}\n])\n\nalias Vix.Vips.{Image, Operation}\n\n# Create a thumbnail and optimize for web\n{:ok, thumb} = Operation.thumbnail(\"profile.jpg\", 300)\n:ok = Image.write_to_file(thumb, \"thumbnail.jpg\", Q: 90, strip: true, interlace: true)\n```\n\n[👉 Try in Livebook](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Fakash-akya%2Fvix%2Fblob%2Fmaster%2Flivebooks%2Fintroduction.livemd)\n\n<!-- add before & after -->","ref":"readme.html#quick-start"},{"type":"extras","title":"Common Operations - Vix","doc":"","ref":"readme.html#common-operations"},{"type":"extras","title":"Basic Processing - Vix","doc":"```elixir\n# Reading an image\n{:ok, img} = Image.new_from_file(\"profile.jpg\")\n\n# Resize preserving aspect ratio\n{:ok, resized} = Operation.resize(img, 0.5)  # 50% of original size\n\n# Crop a section\n{:ok, cropped} = Operation.crop(img, 100, 100, 500, 500)\n\n# Rotate with white background\n{:ok, rotated} = Operation.rotate(img, 90, background: [255, 255, 255])\n\n# Smart thumbnail (preserves important features)\n{:ok, thumb} = Operation.thumbnail(\"large.jpg\", 300, size: :VIPS_SIZE_DOWN, crop: :VIPS_INTERESTING_ATTENTION)\n```","ref":"readme.html#basic-processing"},{"type":"extras","title":"Web Optimization - Vix","doc":"```elixir\n# Convert to WebP with quality optimization\n:ok = Image.write_to_file(img, \"output.webp\", Q: 80, effort: 4)\n\n# Create progressive JPEG with metadata stripped\n:ok = Image.write_to_file(img, \"output.jpg\", interlace: true, strip: true, Q: 85)\n\n# Generate multiple formats\n:ok = Image.write_to_file(img, \"photo.avif\", Q: 60)\n:ok = Image.write_to_file(img, \"photo.webp\", Q: 80)\n:ok = Image.write_to_file(img, \"photo.jpg\", Q: 85)\n```","ref":"readme.html#web-optimization"},{"type":"extras","title":"Filters & Effects - Vix","doc":"```elixir\n# Blur\n{:ok, blurred} = Operation.gaussblur(img, 3.0)\n\n# Sharpen\n{:ok, sharp} = Operation.sharpen(img, sigma: 1.0)\n\n# Grayscale\n{:ok, bw} = Operation.colourspace(img, :VIPS_INTERPRETATION_B_W)\n```","ref":"readme.html#filters-effects"},{"type":"extras","title":"Advanced Usage - Vix","doc":"```elixir\n# Smart thumbnail preserving important features\n{:ok, thumb} = Operation.thumbnail(\n  \"large.jpg\",\n  300,\n  size: :VIPS_SIZE_DOWN, # only downsize, it will just copy if asked to upsize\n  crop: :VIPS_INTERESTING_ATTENTION\n)\n\n# Process image stream on the fly\n{:ok, image} =\n  File.stream!(\"large_photo.jpg\", [], 65_536)\n  |> Image.new_from_enum()\n# use `image` for further operations...\n\n# Stream image to S3\n:ok =\n  Image.write_to_stream(image, \".png\")\n  |> Stream.each(&upload_chunk_to_s3/1)\n  |> Stream.run()\n```\n\n<!-- TODO: Would be great to add examples for: -->\n<!-- - Watermarking -->\n<!-- - Image composition -->\n<!-- - Batch processing -->\n<!-- - Text overlay -->","ref":"readme.html#advanced-usage"},{"type":"extras","title":"Performance - Vix","doc":"Libvips very fast and uses very little memory. See the detailed [benchmark](https://github.com/libvips/libvips/wiki/Speed-and-memory-use). Resizing an image is typically 4x-5x faster than using the quickest ImageMagick settings. It can also work with very large images without completely loading them to the memory.","ref":"readme.html#performance"},{"type":"extras","title":"Installation - Vix","doc":"Add Vix to your dependencies:\n\n```elixir\ndef deps do\n  [\n    {:vix, \"~> x.x.x\"}\n  ]\nend\n```\n\nThat's it! Vix includes pre-built binaries for MacOS & Linux.","ref":"readme.html#installation"},{"type":"extras","title":"Advanced Setup - Vix","doc":"Want to use your system's libvips? Set before compilation:\n\n```bash\nexport VIX_COMPILATION_MODE=PLATFORM_PROVIDED_LIBVIPS\n```\n\nSee [libvips installation guide](https://www.libvips.org/install.html) for more details.","ref":"readme.html#advanced-setup"},{"type":"extras","title":"Documentation & Resources - Vix","doc":"- [Complete API Documentation](https://hexdocs.pm/vix/)\n- [Interactive Introduction (Livebook)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Fakash-akya%2Fvix%2Fblob%2Fmaster%2Flivebooks%2Fintroduction.livemd)\n- [Creating Rainbow Effects (Livebook)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Fakash-akya%2Fvix%2Fblob%2Fmaster%2Flivebooks%2Frainbow.livemd)\n- [Auto Document Rotation (Livebook)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Fakash-akya%2Fvix%2Fblob%2Fmaster%2Flivebooks%2Fauto_correct_rotation.livemd)\n- [Picture Language from SICP (Livebook)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Fakash-akya%2Fvix%2Fblob%2Fmaster%2Flivebooks%2Fpicture-language.livemd)","ref":"readme.html#documentation-resources"},{"type":"extras","title":"FAQ - Vix","doc":"","ref":"readme.html#faq"},{"type":"extras","title":"Should I use Vix or Image? - Vix","doc":"[Image](https://github.com/kipcole9/image) is a library which builds on top of Vix.\n\n- Use [Image](https://github.com/kipcole9/image) when you need:\n  - A more Elixir-friendly API for common operations\n  - Higher-level operations like Blurhash\n  - Simple, chainable functions for common operations\n\n- Use Vix directly when you need:\n  - Advanced VIPS features and fine-grained control\n  - Complex image processing pipelines\n  - Direct libvips performance and capabilities\n  - Lesser dependencies","ref":"readme.html#should-i-use-vix-or-image"},{"type":"extras","title":"What image formats are supported? - Vix","doc":"Out of the box: JPEG, PNG, WEBP, TIFF, SVG, HEIF, GIF, and more. Need others? Just install libvips with the required libraries!","ref":"readme.html#what-image-formats-are-supported"},{"type":"extras","title":"License - Vix","doc":"MIT License - see [LICENSE](LICENSE) for details.","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2020 Akash Hiremath\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Vix Introduction","doc":"# Vix Introduction","ref":"introduction.html"},{"type":"extras","title":"Overview - Vix Introduction","doc":"Welcome to an in-depth exploration of Vix, a powerful Elixir library for image processing. This guide will walk you through using Vix to handle common and advanced image processing tasks efficiently. Vix is particularly valuable for applications requiring high-performance image manipulation, such as web applications, scientific image analysis, digital art creation, and batch processing of large image datasets.","ref":"introduction.html#overview"},{"type":"extras","title":"Why Vix? - Vix Introduction","doc":"Vix provides Elixir bindings to libvips, a robust and mature image processing library. Here's why Vix stands out:\n\n* **Speed**: Processes images up to 10x faster than alternatives by using sophisticated algorithms and parallel processing\n* **Memory efficiency**: Rather than loading entire images into memory, Vix streams data in small chunks, making it ideal for processing large images\n* **Rich feature set**: Access to hundreds of image operations from basic transformations to complex filters and analysis tools\n* **Elixir integration**: Seamlessly integrates with Elixir's functional programming paradigm, offering immutable operations and pipeline-friendly APIs","ref":"introduction.html#why-vix"},{"type":"extras","title":"Setup - Vix Introduction","doc":"First, let's set up our development environment with the necessary dependencies:\n\n```elixir\nMix.install([\n  {:vix, \"~> 0.5\"},\n  {:kino, \"~> 0.7\"},  # For interactive examples\n  {:req, \"~> 0.4\"}    # For fetching sample images\n])\n\n# Let's check our Vix version. Vix comes with pre-built libvips binaries\nIO.puts(\"Using libvips version: \" <> Vix.Vips.version())\n```","ref":"introduction.html#setup"},{"type":"extras","title":"Core Concepts - Vix Introduction","doc":"","ref":"introduction.html#core-concepts"},{"type":"extras","title":"The Image Struct - Vix Introduction","doc":"In Vix, images are represented by `%Vix.Vips.Image{}` structs. Following functional programming principles, these structs are immutable - every operation creates a new image rather than modifying the existing one. This approach ensures thread safety and makes it easier to reason about image transformations.\n\nLet's explore the various ways to create and work with images:\n\n```elixir\nalias Vix.Vips.Image\nalias Vix.Vips.Operation\n\n# 1. Loading from file. Change the image path\n# {:ok, from_file} = Image.new_from_file(\"input.jpg\")\n\n# 2. Loading from memory - useful for handling uploaded files or HTTP responses\n# image_binary = File.read!(\"input.jpg\")\n# {:ok, from_binary} = Image.new_from_buffer(image_binary)\n\n# 3. Creating a solid color image - useful for backgrounds or overlays\nred = Image.build_image!(100, 100, [255, 0, 0])\n\n# Vix implements `Kino.Render` protocol, so you can see the image by just\n# returning it for the Livebook cell.\n```\n\nTo make our examples more practical, let's create a helper module to fetch sample images and display them:\n\n```elixir\ndefmodule ImageHelper do\n  def get_sample_image(width, height) do\n    response = Req.get!(\"https://picsum.photos/#{width}/#{height}\", decode_body: false)\n    {:ok, image} = Image.new_from_buffer(response.body)\n    image\n  end\n\n  def show(images, columns \\\\ nil)\n  def show(%Image{} = img, _), do: show([img], 1)\n\n  def show(images, columns) when is_list(images) do\n    columns = columns || length(images)\n\n    images\n    |> Kino.Layout.grid(boxed: true, columns: columns)\n    |> Kino.render()\n\n    :ok\n  end\nend\n```\n\nLet's fetch a sample image to use throughout our examples:\n\n```elixir\nimport ImageHelper\n\n# For our examples, let's use a sample image.\nimage = get_sample_image(800, 600)\n```","ref":"introduction.html#the-image-struct"},{"type":"extras","title":"Image Properties and Metadata - Vix Introduction","doc":"Understanding image properties is crucial for processing. Vix provides comprehensive access to image metadata, which can be essential for making processing decisions or maintaining image information:\n\n```elixir\n# Get all available metadata fields - useful for debugging and understanding image characteristics\n{:ok, fields} = Image.header_field_names(image)\nIO.puts(\"Available fields: #{Enum.join(fields, \", \")}\")\n\n# Get specific field value - useful for understanding image format and processing history\n{:ok, value} = Image.header_value(image, \"vips-loader\")\nIO.puts(\"Loader used: #{value}\")\n\n# Get image dimensions and number of color channels - essential for proper image manipulation\n{width, height, bands} = Image.shape(image)\n```","ref":"introduction.html#image-properties-and-metadata"},{"type":"extras","title":"Basic Operations - Vix Introduction","doc":"","ref":"introduction.html#basic-operations"},{"type":"extras","title":"Resizing and Scaling - Vix Introduction","doc":"Image resizing is one of the most common operations in image processing. Each method has its specific use case and trade-offs between speed and quality:\n\n```elixir\n# Fast thumbnail generation - optimized for speed, perfect for preview generation\nthumbnail = Operation.thumbnail_image!(image, 400)\n# For even better performance use `Operation.thumbnail!` and pass path directly\n# thumbnail = Operation.thumbnail!(\"input.jpg\", 300)\n\n# High-quality resize with Lanczos3 kernel - best for preserving image quality\n# Lanczos3 provides excellent results for both upscaling and downscaling\nresized = Operation.resize!(image, 0.5, kernel: :VIPS_KERNEL_LANCZOS3)\n\n# Scale to specific dimensions while maintaining proper aspect ratio\n# Useful for fitting images into specific containers while preventing distortion\nscaled = Operation.resize!(image, 400 / Image.width(image), vscale: 300 / Image.height(image))\n\n# Smart cropping - uses edge detection and entropy analysis to keep important parts\n# Perfect for automated content-aware thumbnail generation\n{smart_crop, _} = Operation.smartcrop!(image, 300, 200)\n\nshow([thumbnail, resized, scaled, smart_crop], 2)\n```","ref":"introduction.html#resizing-and-scaling"},{"type":"extras","title":"Color Operations - Vix Introduction","doc":"Color manipulation is essential for image enhancement, artistic effects, and preparing images for specific use cases:\n\n```elixir\n# Convert to grayscale - useful for reducing complexity or preparing for analysis\n# Also great for artistic effects or preparing images for machine learning\ngrayscale = Operation.colourspace!(image, :VIPS_INTERPRETATION_B_W)\n\n# Adjust RGB channels individually for color balance\n# Values > 1 increase channel intensity, < 1 decrease it\n# This can correct color casts or create artistic effects\nadjusted = Operation.linear!(image,\n  [1.2, 1.0, 0.8],  # RGB multipliers: boost red, normal green, reduce blue\n  [0, 0, 0]         # RGB offsets: no additional adjustment\n)\n\n# Extract alpha channel (transparency) if present\n# Useful for masking operations or analyzing image transparency\n{:ok, alpha} = Operation.extract_band(image, bands - 1)\n\n# Add an alpha channel - useful for creating partially transparent images\n# Essential for overlays and composition effects\nwith_alpha = Operation.bandjoin!([image, Image.build_image!(width, height, [125])])\n\nshow([grayscale, adjusted, with_alpha])\n```","ref":"introduction.html#color-operations"},{"type":"extras","title":"Operators - Vix Introduction","doc":"Vix provides convenient operator overloading for common image manipulations. These operators make the code more readable and intuitive:\n\n```elixir\nuse Vix.Operator, only: [+: 2, -: 2, *: 2]  # Import specific operators\n\n# Adjust brightness using operators - multiplication scales pixel values\nbrighter = image * 1.2  # Increase brightness by 20%\ndarker = image * 0.8    # Decrease brightness by 20%\n\n# Combining operators for complex effects\n# This creates an enhanced image with adjusted brightness, contrast, and blur\nenhanced = (image * 1.2) - 10 + Operation.gaussblur!(image, 2)\n\nshow([brighter, darker, enhanced])\n```","ref":"introduction.html#operators"},{"type":"extras","title":"The Access Protocol - Vix Introduction","doc":"Vix implements Elixir's Access protocol, providing a powerful way to work with image channels and regions. This makes it easy to extract and manipulate specific parts of an image:\n\n```elixir\n# Get the red channel from an RGB image\n# Useful for channel-specific analysis or effects\nred = image[0]\n\n# Get a 200x100 pixel square from the top-left corner\n# Perfect for creating image tiles or focusing on specific regions\ntop_left = image[[0..199, 0..99]]\n\n# Get the bottom-right 200x100 pixel square\n# Negative indices count from the end, just like in Elixir lists\nbottom_right = image[[-200..-1, -100..-1]]\n\n# Alternatively you can use keyword list for more readable code\n# Get a 200x100 pixel square from the top-left corner, and only red-green channels\nred_top_left = image[[width: 0..199, height: 0..99, band: 0..1]]\n\nshow([top_left, bottom_right, red_top_left])\n\n# Rearrange color channels - useful for color space manipulation\n# RGB -> GBR: Swapping channels can create interesting color effects\nremaped = Operation.bandjoin!([image[1], image[2], image[0]])\n\nshow([red, remaped])\n```","ref":"introduction.html#the-access-protocol"},{"type":"extras","title":"Advanced Techniques - Vix Introduction","doc":"","ref":"introduction.html#advanced-techniques"},{"type":"extras","title":"Creating Processing Pipelines - Vix Introduction","doc":"One of Vix's strengths is its ability to chain operations efficiently using Elixir's pipe operator. This allows you to create complex image processing pipelines that are both readable and performant. Each operation in the pipeline creates a new immutable image, ensuring thread safety and making it easy to debug:\n\n```elixir\ndefmodule ImagePipeline do\n  def process(image) do\n    image\n    |> Operation.resize!(0.8)\n    |> Operation.sharpen!()\n    |> Operation.linear!([1.1], [-0.1])\n  end\nend\n\nImagePipeline.process(image)\n```","ref":"introduction.html#creating-processing-pipelines"},{"type":"extras","title":"Image Composition - Vix Introduction","doc":"Combining images with text or other elements is essential for creating watermarks, annotations, or complex composite images. This example demonstrates professional text overlay with proper DPI handling and alpha channel management:\n\n```elixir\n# Create high-quality text overlay with anti-aliasing\n{text, _} =\n  Operation.text!(\n    \"Hello from Vix!\",\n    width: 400,\n    dpi: 300,         # High DPI ensures sharp text at any size\n    font: \"sans-serif bold\",\n    rgba: true        # Alpha channel enables smooth blending\n  )\n\n# Position text precisely on the image\n# The embed operation handles proper padding and positioning\npositioned_text =\n  Operation.embed!(\n    text,\n    50,              # X offset from left\n    50,              # Y offset from top\n    Image.width(image),\n    Image.height(image)\n  )\n\n# Blend using alpha composition for professional results\ncomposite = Operation.composite2!(image, positioned_text, :VIPS_BLEND_MODE_OVER)\n\nshow([text, composite])\n```","ref":"introduction.html#image-composition"},{"type":"extras","title":"Filters and Effects - Vix Introduction","doc":"Vix provides a comprehensive set of filters and effects suitable for both practical image enhancement and creative artistic expression. Understanding these operations allows you to create sophisticated image processing applications:\n\n```elixir\n# Gaussian blur - essential for noise reduction and creating depth-of-field effects\n# Higher sigma values create stronger blur effects\nblurred = Operation.gaussblur!(image, 3.0)\n\n# Edge detection using the Canny algorithm\n# Perfect for image analysis and artistic effects\n# Multiply by 64 to make edges more visible in the output\nedges = Operation.canny!(image, sigma: 1.4) * 64\n\n# Advanced sharpening with fine-grained control\n# sigma: controls the radius of the effect\n# x1: adjusts the threshold between flat and jagged areas\n# m2: determines overall sharpening strength\nsharpened =\n  Operation.sharpen!(image,\n    sigma: 1.0,\n    x1: 2.0,\n    m2: 20\n  )\n\n# Emboss effect using convolution matrix\n# The matrix defines the relationship between each pixel and its neighbors\n# This creates a 3D-like effect by emphasizing directional changes\n{:ok, conv_matrix} =\n  Image.new_from_list([\n    [-2, -1, 0],   # Top row emphasizes vertical edges\n    [-1, 1, 1],    # Middle row provides center weighting\n    [0, 1, 2]      # Bottom row creates directional lighting effect\n  ])\n\nembossed = Operation.conv!(image, conv_matrix)\n\nshow([blurred, edges, sharpened, embossed], 2)\n```","ref":"introduction.html#filters-and-effects"},{"type":"extras","title":"Image Analysis - Vix Introduction","doc":"Vix includes powerful tools for analyzing image characteristics, making it suitable for both artistic applications and scientific image analysis. The histogram functionality is particularly useful for understanding and adjusting image exposure and color distribution:\n\n```elixir\n# Create histogram from grayscale image\n# Converting to grayscale first simplifies the analysis\nhistogram =\n  image\n  |> Operation.colourspace!(:VIPS_INTERPRETATION_B_W)\n  |> Operation.hist_find!()\n\n# Convert histogram to List for programmatic analysis\n# Useful for automated image adjustment algorithms\nImage.to_list!(histogram)\n|> List.flatten()\n|> IO.inspect(limit: 15, label: :histogram)\n\n# Create visual representation of the grayscale histogram\n# Normalizing ensures consistent visualization regardless of image size\nbw_plot =\n  histogram\n  |> Operation.hist_norm!()  # Scale values to 0..255 range\n  |> Operation.hist_plot!()  # Create visual representation\n\n# Generate and plot full color histogram\n# Useful for analyzing color balance and distribution\ncolor_plot =\n  image\n  |> Operation.hist_find!()    # Calculate histogram for each channel\n  |> Operation.hist_norm!()    # Normalize values\n  |> Operation.hist_plot!()    # Create visual representation\n\nshow([bw_plot, color_plot])\n```","ref":"introduction.html#image-analysis"},{"type":"extras","title":"Error Handling - Vix Introduction","doc":"Vix offers two complementary approaches to error handling, allowing you to choose the most appropriate strategy for your application:\n\n```elixir\n# Pattern 1: Explicit error handling with with\n# Useful for complex workflows where you need fine-grained error control\nresult =\n  with {:ok, resized} <- Operation.resize(image, 0.5),\n       {:ok, processed} <- Operation.sharpen(resized, sigma: 1.0) do\n    {:ok, processed}\n  else\n    {:error, reason} ->\n      IO.puts(\"Failed: #{reason}\")\n      {:error, reason}\n  end\n\n# Pattern 2: Bang (!) variants for simplified error propagation\n# Ideal for scripts or when you want errors to halt execution\nimage\n|> Operation.resize!(0.5)\n|> Operation.sharpen!(sigma: 1.0)\n```","ref":"introduction.html#error-handling"},{"type":"extras","title":"Creating a Color Gradient - Vix Introduction","doc":"This example demonstrates how to programmatically generate color gradients using Vix's color space manipulation capabilities:\n\n```elixir\ndefmodule ColorGradient do\n  def create(width, height) do\n    use Vix.Operator, only: [*: 2, +: 2, /: 2]\n\n    # Generate linear hue gradient\n    # identity! creates a gradient from 0 to width\n    # Multiply by 255/width normalizes values to 0..255 range\n    hue = Operation.identity!(size: width, ushort: true) * 255 / width\n\n    # Convert to HSV color space for vibrant colors\n    # Add full saturation and value channels\n    hsv =\n      hue\n      |> Operation.bandjoin_const!([255, 255])  # Add S and V channels\n      |> Operation.copy!(interpretation: :VIPS_INTERPRETATION_HSV)\n\n    # Create final gradient by repeating horizontally\n    rainbow = Operation.embed!(hsv, 0, 0, width, height, extend: :VIPS_EXTEND_REPEAT)\n\n    show([hue, hsv, rainbow], 1)\n  end\nend\n\nColorGradient.create(600, 100)\n```","ref":"introduction.html#creating-a-color-gradient"},{"type":"extras","title":"Creating a Photo Collage - Vix Introduction","doc":"Create professional-looking photo collages with automatic layout, borders, and titles. This example demonstrates combining multiple images into a single composition:\n\n```elixir\ndefmodule Collage do\n  def create(images, across, gap) do\n    # create collage by arranging images in a grid pattern\n    # across parameter determines number of images per row\n    # gap specifies spacing between images\n    collage = Operation.arrayjoin!(images, across: across, shim: gap)\n\n    # Add a consistent border around the entire collage\n    # This creates a frame effect and ensures clean edges\n    {width, height, _} = Image.shape(collage)\n    collage = Operation.embed!(collage, gap, gap, width + gap * 2, height + gap * 2)\n\n    # Add a title overlay with high DPI for crisp text\n    {title, _} = Operation.text!(\"My Photo Collage\", dpi: 300)\n\n    # Composite the title onto the collage with proper positioning\n    Operation.composite2!(collage, title, :VIPS_BLEND_MODE_OVER, x: 20, y: 20)\n  end\nend\n\n# Create sample collage using multiple images\n# Download sample images for demonstration\nimages = for _ <- 1..4, do: get_sample_image(600, 400)\n\nCollage.create(images, 2, 10)\n```","ref":"introduction.html#creating-a-photo-collage"},{"type":"extras","title":"Creating Instagram-style Filters - Vix Introduction","doc":"Modern photo apps often use preset filters to enhance images. Here's how to create custom filters using Vix's operations:\n\n```elixir\ndefmodule PhotoFilters do\n  def vintage(image) do\n    image\n    # Adjust color balance for warm, aged look\n    |> Operation.linear!([0.9, 0.7, 0.6], [-0.1, 0.1, 0.2])\n    # Add subtle blur to soften details\n    |> Operation.gaussblur!(0.5)\n    # Enhance contrast for dramatic effect\n    |> Operation.linear!([1.2], [-0.1])\n  end\n\n  def dramatic(image) do\n    # Create vignette mask using Gaussian distribution\n    # This darkens the edges while keeping the center bright\n    mask = Operation.gaussmat!(Image.width(image), 0.5, min: 0, max: 0.8)\n\n    image\n    # Increase contrast significantly\n    |> Operation.linear!([1.4], [-0.2])\n    # Enhance edge details for cinematic look\n    |> Operation.sharpen!(sigma: 1.0, x1: 2.0)\n    # Apply vignette effect using overlay blend\n    |> Operation.composite2!(mask, :VIPS_BLEND_MODE_OVERLAY)\n  end\nend\n\n# Apply our custom filters to sample image\nvintage_photo = PhotoFilters.vintage(image)\ndramatic_photo = PhotoFilters.dramatic(image)\n\nshow([vintage_photo, dramatic_photo])\n```","ref":"introduction.html#creating-instagram-style-filters"},{"type":"extras","title":"Performance Considerations - Vix Introduction","doc":"When working with Vix in production environments, keep these performance optimization strategies in mind:\n\n1. **Lazy Operation Execution**:\n\n   * Operations are only executed when the final result is needed\n   * Chain operations together to minimize intermediate processing\n   * Use bang variants (`!`) when you're confident about inputs and want to avoid error checking overhead\n\n2. **Memory-Efficient Processing**:\n\n   ```elixir\n   # Use sequential access for large images to reduce memory usage\n   {:ok, image} = Image.new_from_file(\"large.jpg\", access: :sequential)\n   ```\n\n3. **Optimization Tips**:\n\n   * Use `thumbnail` operations for quick resizes when absolute quality isn't critical\n   * Chain operations to avoid creating unnecessary intermediate images\n   * Consider format-specific loaders when you need fine-grained control\n   * Use appropriate color spaces for your operations (e.g., LAB for color analysis)","ref":"introduction.html#performance-considerations"},{"type":"extras","title":"Next Steps - Vix Introduction","doc":"To continue your journey with Vix, here are some valuable resources:\n\n* **Documentation**:\n\n  * Explore the [Vix documentation](https://hexdocs.pm/vix) for comprehensive API details\n  * Study the [libvips documentation](https://www.libvips.org/API/current/) for understanding the underlying technology\n\n* **Community**:\n\n  * Join the [Elixir Forum](https://elixirforum.com/) to discuss Vix with other developers\n  * Share your custom filters and processing pipelines with the community","ref":"introduction.html#next-steps"},{"type":"extras","title":"Advanced Topics for Further Exploration - Vix Introduction","doc":"Several advanced features deserve deeper investigation:\n\n* **Complex Convolution Operations**:\n\n  * Custom kernel design for specialized filters\n  * Multi-pass convolutions for complex effects\n  * Edge handling strategies\n\n* **Color Management**:\n\n  * Working with ICC profiles for color accuracy\n  * Color space transformations\n  * Calibration and profiling\n\n* **Animation Support**:\n\n  * Processing animated GIFs\n  * Creating animations from static images\n  * Timeline-based effects\n\n* **Advanced Composition**:\n\n  * Complex masking operations\n  * Layer blending modes\n  * Alpha channel manipulation\n\nRemember that Vix operations are non-destructive - they always create new image objects. This makes it safe to experiment with different processing pipelines while keeping your original images intact. The functional nature of Vix operations makes it easy to compose complex transformations while maintaining code clarity and testability.","ref":"introduction.html#advanced-topics-for-further-exploration"},{"type":"extras","title":"Picture Language","doc":"# Picture Language","ref":"picture-language.html"},{"type":"extras","title":"Install dependencies - Picture Language","doc":"```elixir\nMix.install([\n  {:kino, \"~> 0.3.0\"},\n  {:vix, \"~> 0.5\"}\n])\n```\n\nDefining helper function `display` using kino so that we can show image inline\n\n```elixir\ndefmodule VixExt do\n  alias Vix.Vips.Image\n  alias Vix.Vips.Operation\n\n  @max_height 500\n\n  def show(%Image{} = image) do\n    height = Image.height(image)\n\n    # scale down if image height is larger than 500px\n    image =\n      if height > @max_height do\n        Operation.resize!(image, @max_height / height)\n      else\n        image\n      end\n\n    # write vips-image as png image to memory\n    {:ok, image_bin} = Image.write_to_buffer(image, \".png\")\n    Kino.render(Kino.Image.new(image_bin, \"image/png\"))\n\n    :ok\n  end\nend\n```","ref":"picture-language.html#install-dependencies"},{"type":"extras","title":"Picture Language - Picture Language","doc":"Implementing picture language defined in [**Structural and Interpretation of Computer Programs**](https://web.mit.edu/6.001/6.037/sicp.pdf) section [2.2.4](https://web.mit.edu/6.001/6.037/sicp.pdf#subsection.2.2.4) in Elixir using vix\n\n\n```elixir\ndefmodule Pict do\n  alias Vix.Vips.Operation, as: Op\n\n  def beside(a, b) do\n    Op.resize!(Op.join!(a, b, :VIPS_DIRECTION_HORIZONTAL), 0.5, vscale: 1)\n  end\n\n  def below(a, b) do\n    Op.resize!(Op.join!(a, b, :VIPS_DIRECTION_VERTICAL), 1, vscale: 0.5)\n  end\n\n  def vert_flip(p) do\n    Op.flip!(p, :VIPS_DIRECTION_VERTICAL)\n  end\n\n  def horz_flip(p) do\n    Op.flip!(p, :VIPS_DIRECTION_HORIZONTAL)\n  end\nend\n```\n\nImplementation of [Fig. 2.9](https://web.mit.edu/6.001/6.037/sicp.pdf#page=201)\n\n```elixir\ndefmodule PictUtils do\n  import Pict\n\n  def right_split(p, 0), do: p\n\n  def right_split(p, n) do\n    t = right_split(p, n - 1)\n    beside(p, below(t, t))\n  end\n\n  def up_split(p, 0), do: p\n\n  def up_split(p, n) do\n    t = up_split(p, n - 1)\n    below(beside(t, t), p)\n  end\n\n  def corner_split(p, 0), do: p\n\n  def corner_split(p, n) do\n    us = up_split(p, n - 1)\n    rs = right_split(p, n - 1)\n\n    beside(\n      below(beside(us, us), p),\n      below(corner_split(p, n - 1), below(rs, rs))\n    )\n  end\nend\n```\n\n```elixir\nalias Vix.Vips.Image\nimport VixExt\n\n{:ok, img} = Image.new_from_file(\"~/Downloads/kitty.png\")\nimg = PictUtils.corner_split(img, 5)\n\nright = Pict.below(img, Pict.vert_flip(img))\nleft = Pict.horz_flip(right)\nimg = Pict.beside(left, right)\n\nshow(img)\n```","ref":"picture-language.html#picture-language"},{"type":"extras","title":"Creating Rainbow  🌈","doc":"# Creating Rainbow  🌈\n\n```elixir\nMix.install([\n  {:vix, \"~> 0.22.0\"},\n  {:kino, \"~> 0.10.0\"}\n])\n```","ref":"rainbow.html"},{"type":"extras","title":"Introduction - Creating Rainbow  🌈","doc":"Libvips provides over 300 image processing operations so getting an\nintuition for what is possible, and how to combine the primitive\nimage processing operations, can be challenging.\n\nIn this notebook we look into some libvips core operations by\nworking towards a simple goal — generate a rainbow 🌈. \nThe rainbow should have a half-circular arch and a smooth blend \nbetween the colors.","ref":"rainbow.html#introduction"},{"type":"extras","title":"Generating the colors - Creating Rainbow  🌈","doc":"First, let's look into generating the rainbow colors. We need to\ngenerate the whole spectrum with the smooth blend between them.\n\nlibvips provides the `buildlut` function, which generates pointwise\nintermediate values between the provided points. `lut` here means\n**L**ook **U**p **T**able. `buildlut` takes a 1D matrix where each value\nrepresents different points in the format `[position, bands]`.\n`buildlut` will build a single-band, one-pixel-height image with a\nsmooth pointwise transition between the points. If you pass `[0, 0]`\n(at position zero pixel value is zero) `[255, 255]` (at position 255\nvalue is 255), the buildlut will return an image with pixels `0` at\nposition 0, `1` at position 1, `2` at position 2 etc, ending with\n`255` at position 255. We can think of it as a range from 0 to 255, or `0..255//1`.\n\n```elixir\nalias Vix.Vips.Image\nalias Vix.Vips.Operation\n\n# buildlut needs matrix image.\n# we can create matrix-image using `Image.new_matrix_from_array` which takes\n# list and return a vips-image which can be passed to `buildlut`\n{:ok, mat} = Image.new_matrix_from_array(2, 2, [[0, 0], [255, 255]])\n\ngradient = Operation.buildlut!(mat)\n```\n\nSwitch to attributes tab to see more details about the image.\n\nWe can see the gradient clearly if we increase the image height\n\n```elixir\nOperation.resize!(gradient, 3, vscale: 50)\n```\n\n`buildlut` accepts multiple bands as well. So we can generate gradients in grayscale or color.\n```elixir\ndefmodule Vix.KinoUtils do\n  # Utility to read color and parse hex string into list of\n  # 8-bit integers\n  def read_colors do\n    start_color = Kino.Input.color(\"Start\", default: \"#DDDD55\")\n    end_color = Kino.Input.color(\"End\", default: \"#FF2200\")\n\n    [start_color, end_color]\n    |> Kino.Layout.grid(columns: 6)\n    |> Kino.render()\n\n    start_color = read(start_color)\n    end_color = read(end_color)\n\n    {start_color, end_color}\n  end\n\n  defp read(input) do\n    \"#\" <> color = Kino.Input.read(input)\n\n    for < > do\n      String.to_integer(hex, 16)\n    end\n  end\nend\n\n# read user input\n{start_color, end_color} = Vix.KinoUtils.read_colors()\n\n{:ok, mat} =\n  Image.new_matrix_from_array(4, 2, [\n    [0 | start_color],\n    [255 | end_color]\n  ])\n\nmat\n|> Operation.buildlut!()\n|> Operation.cast!(:VIPS_FORMAT_UCHAR)\n|> Operation.resize!(3, vscale: 50)\n\n# change the `Start` and `End` colors and evaluate\n```\n\nTo generate the rainbow colors, the pixel values in RGB colour space\nwill be `[255, 0, 0] (red), [255, 165, 0] (orange) ... [143, 0, 255]\n(violet)`. We could generate these values but it is inconvenient to\njuggle all 3 bands.\n\nGenerating the colors in HSV color space we need `[0, 255, 255] (red),\n[24, 255, 255] (orange) ... [212, 255, 255] (violet)`. Which is much\nnicer to work with, since we only need to change one value.\n\n```elixir\n{:ok, mat} =\n  Image.new_matrix_from_array(4, 2, [\n    # position 0   - [0,   255, 255]\n    [0, 0, 255, 255],\n    # position 255 - [255, 255, 255]\n    [255, 255, 255, 255]\n  ])\n\ngradient = Operation.buildlut!(mat)\n\n# by default the colour space won't be HSV.\n# We make a shallow copy and set the colorspace to HSV.\n# While also setting band format to `unsigned char`\nrainbow_colors =\n  Operation.copy!(gradient,\n    band_format: :VIPS_FORMAT_UCHAR,\n    interpretation: :VIPS_INTERPRETATION_HSV\n  )\n\n# resize to make it visible\nOperation.resize!(rainbow_colors, 3, vscale: 50)\n\n# notice that the output spectrum starts from RED and ends with RED.\n# this is slightly incorrect, since rainbow ends with violet. We'll fix this later\n```","ref":"rainbow.html#generating-the-colors"},{"type":"extras","title":"Generating the Arch - Creating Rainbow  🌈","doc":"How do we generate the half circular arch? There are several way to\napproach this but we are going to use complex band format and polar\ncoordinates.","ref":"rainbow.html#generating-the-arch"},{"type":"extras","title":"Complex Numbers - Creating Rainbow  🌈","doc":"In a traditional coordinate system, a pixel’s position is represented \nby two values: its x- and y-coordinates. The x-coordinate indicates the \nhorizontal position along the width of the plane, while the y-coordinate \nindicates the vertical position along the height. The two values taken \ntogether describe a point's location on a two-dimensional (2D) plane.\n\nNow consider an operator, like the Fourier transformation. It takes a \ncoordinate pair and may output a complex number. How would we handle that? \n\nIt turns out that even though a complex number is a single value, it still \nconsists of two components: a **Real** number and an **Imaginary** number. \nLike the x-coordinate above, the **Real** number component of a complex number\nindicates the horizontal position along the width of the plane. An **Imaginary** \nnumber technically represents how many units, i, a point is located off a 2D plane, \nbut for our purposes, we treat it the way we would a y-coordinate.\n\n<!-- livebook:{\"break_markdown\":true} -->\n\nThere are two different ways to locate a point on 2D plane\n\n* Cartesian coordinate system\n* Polar coordinate system\n\n**Cartesian coordinate System**\n\nHere real part represent x coordinate and imaginary part represents y coordinate.\n\n![](images/Complex_number_illustration.png)\n\n`a` and `b` is used to locate the point `z`\n\n<!-- livebook:{\"break_markdown\":true} -->\n\n**Polar System**\n\nHere real part represents distance from the origin and imaginary part represents angle\n\n![](images/Complex_number_illustration_modarg.png)\n\nAngle `φ` and distance `r` is used to locate point `z`\n\n<!-- livebook:{\"break_markdown\":true} -->\n\n**But why do we need complex number?**\n\nBecause it makes certain operations simple. Operations which operate\non plane rather than axis. For example, to draw a circle on a polar\nplane we only need to vary angle keeping the distance constant.\n\nLet's do an example to see how libvips operations work on the complex\nnumber plane. First, let's create an image that has an origin in the center of\nthe image. It makes it easy to understand what is happening.\n\n```elixir\nuse Vix.Operator\n\nwidth = height = 255\n\n# create 200 x 200 matrix where each pixel represent its own position.\n# pixel at left-top will be `{0, 0}` (black)\n# pixel right-bottom will be `{255, 255}` (white)\nxy = Operation.xyz!(width, height)\n\n# Display how axis values are chaining\nKino.Layout.grid([Kino.Text.new(\"X-Axis\"), Kino.Text.new(\"Y-Axis\"), xy[0], xy[1]], columns: 2)\n|> Kino.render()\n\n# move origin to center of the image\nxy = (xy - [width / 2, height / 2]) * 2\n\n# Display how axis values are changing after moving the origin.\n# Notice that origin black pixel starts at top-left before\n# and at center after moving the origin\nKino.Layout.grid(\n  [Kino.Text.new(\"Centered X-Axis\"), Kino.Text.new(\"Centered Y-Axis\"), xy[0], xy[1]],\n  columns: 2\n)\n```\n\nNow that we have an image, we can see how it looks in polar plane\n\n```elixir\n# convert band format to complex number format.\n# we specify that read 2 bands to form a single complx band.\n# x axis becomes the real part of the complex number\n# y axis becomes the Imaginary part of the complex number\ncomplex_xy = Operation.copy!(xy, format: :VIPS_FORMAT_COMPLEX, bands: 1)\n\n# change the complex number plane to the polar plane.\n# vips reads a complex number and converts it to a value on the polar plane for all pixels.\n# real part will be distance from the origin\n# imaginary part will be the angle in degree\npolar_xy = Operation.complex!(complex_xy, :VIPS_OPERATION_COMPLEX_POLAR)\n\n# convert the complex number back to 2-band float image.\n# x axis is the real part of the complex number\n# y asix is the imaginary part of the complex number\nxy = Operation.copy!(polar_xy, format: :VIPS_FORMAT_FLOAT, bands: 2)\n\n# angle will be in degree (from 0 to 360), scale it back to 255\nxy = xy * [1, height / 360]\n\nKino.Layout.grid([Kino.Text.new(\"X-Axis\"), Kino.Text.new(\"Y-Axis\"), xy[0], xy[1]], columns: 2)\n```\n\nAs you can see the x-axis is the real part of the complex number, which is\ndistance from the origin, and the y-axis is the imaginary part, which is the angle.\n\nThis is much easier to understand if we draw a few lines on the input\nimage. and see how it changes in the polar plane\n\n```elixir\ndefmodule ComplexOps do\n  def to_polar(img, background \\\\ [0, 0, 0]) do\n    %{width: width, height: height} = Image.headers(img)\n    xy = Operation.xyz!(width, height)\n    xy = xy - [width / 2, height / 2]\n\n    scale = min(height, width) / width\n    xy = xy * 2 / scale\n\n    xy =\n      xy\n      |> Operation.copy!(format: :VIPS_FORMAT_COMPLEX, bands: 1)\n      |> Operation.complex!(:VIPS_OPERATION_COMPLEX_POLAR)\n      |> Operation.copy!(format: :VIPS_FORMAT_FLOAT, bands: 2)\n\n    xy = xy * [1, height / 360]\n\n    # mapim takes an input and a `map` and generates an output image\n    # where input image pixels are moved based on map.\n    #\n    # [new_x, new_y] = map[x, y]\n    # out[x, y] = img[new_x, new_y]\n    #\n    # mapim is to rotate, displace, distort, any type of spatial operations.\n    # where the pixel value (color) remain same but the position is changed.\n    Operation.mapim!(img, xy, background: background)\n  end\nend\n\nx_line = Operation.black!(10, height) + 255\ny_line = Operation.black!(width, 10) + 125\n\n# create a black image and draw 2 lines\n# an x axis at 50\n# a y axis at 50\nimg =\n  Operation.black!(width, height)\n  |> Operation.insert!(x_line, 50, 0)\n  |> Operation.insert!(y_line, 0, 50)\n\n# convert img to polar\nout = ComplexOps.to_polar(img)\n\nKino.Layout.grid([Kino.Text.new(\"Input\"), Kino.Text.new(\"Output\"), img, out], columns: 2)\n```\n\nA line on the x axis becomes a circle on the polar plane and a line on\nthe y axis becomes a line from the origin.\n\nSo to draw a rainbow circle, we just draw a rainbow line on the\nx-axis and convert that to the polar plane!\n\n```elixir\nrainbow_colors\n|> Operation.resize!(100 / 255, vscale: 400)\n|> Operation.embed!(150, 0, 600, 400)\n# wrap moves the image to origin\n|> Operation.wrap!()\n|> ComplexOps.to_polar()\n|> dbg()\n\n# select the stage on the output to see how image transforms\n:ok\n```\n\nAll that is left now is to make a few final adjustments to make it pretty\n\n```elixir\n# create colors from violet to red instead of red to red\n{:ok, mat} = Image.new_matrix_from_array(4, 2, [[0, 220, 255, 255], [255, 0, 255, 255]])\n\nrainbow_colors =\n  Operation.copy!(Operation.buildlut!(mat),\n    band_format: :VIPS_FORMAT_UCHAR,\n    interpretation: :VIPS_INTERPRETATION_HSV\n  )\n\nsky_color = [135, 100, 255]\n\nrainbow_colors\n|> Operation.resize!(100 / 255, vscale: 500)\n|> Operation.embed!(50, 0, 500, 500, background: sky_color)\n|> Operation.wrap!()\n|> ComplexOps.to_polar(sky_color)\n# take only top half of the image\n|> Operation.copy!(height: 250, width: 500)\n```","ref":"rainbow.html#complex-numbers"},{"type":"extras","title":"Auto Correct Document Rotation","doc":"# Auto Correct Document Rotation\n\n```elixir\nMix.install(\n  [\n    {:vix, \"~> 0.17.0\"},\n    {:kino, \"~> 0.9.2\"}\n  ],\n  # pre-built binaries does not support fourier transform operations\n  # since these operations depend on an additional library.\n  #\n  # Usually the platform/OS provided libvips comes with these additional library\n  # so we are telling vix to use the libvips provided by the platform\n  # and compile NIF for that. Follow platform specific libvips\n  # installation guide\n  system_env: [\n    {\"VIX_COMPILATION_MODE\", \"PLATFORM_PROVIDED_LIBVIPS\"}\n  ]\n)\n```","ref":"auto_correct_rotation.html"},{"type":"extras","title":"Introduction - Auto Correct Document Rotation","doc":"In this livebook we look into correcting the text image rotation using\nimage processing techniques such as Fourier Transformation, complex\nplanes, and arithmetic operations.\n\nThis notebook is heavily based on libvips [blog post](https://libvips.blogspot.com/2015/11/fancy-transforms.html)\nand [stack overflow answer](https://stackoverflow.com/questions/33698068/align-text-for-ocr/33707537#33707537).\n\nWe use the same image mentioned on the blog to test our implementation.\nSo let's first fetch the test image.\n\n```elixir\nalias Vix.Vips.Image\nalias Vix.Vips.Operation\n\n# import convenience math operators `+`, `-`, `*` etc.\nuse Vix.Operator\n\n# we use `:httpc` to download the image\n{:ok, _} = Application.ensure_all_started(:inets)\n{:ok, _} = Application.ensure_all_started(:ssl)\n\n# image link is from the stackoverflow question\nimage_url = 'https://i.stack.imgur.com/2q4Qr.png'\n{:ok, {{_, 200, _}, _headers, bin}} = :httpc.request(:get, {image_url, []}, [timeout: 5000], [])\n\n{:ok, img} =\n  bin\n  |> IO.iodata_to_binary()\n  |> Image.new_from_buffer()\n\n# convert 4 channel PNG image to black & white\nimg = Operation.colourspace!(img, :VIPS_INTERPRETATION_B_W)\n# skip alpha band\nimg = img[0]\n```\n\nNotice that the image is not fully vertical, orienttion is slightly off","ref":"auto_correct_rotation.html#introduction"},{"type":"extras","title":"Fourier Transformation - Auto Correct Document Rotation","doc":"An image can be expressed as sum of sine and cosine waves of varying\nmagnitudes, frequency and phase. Fourier Transform is an operation\nwhich decomposes an image into its sine and cosine components.\n\nThere are lot of resources online on this topic,\nI found [this](https://web.archive.org/web/20130513181427id_/http://sharp.bu.edu/~slehar/fourier/fourier.html#filtering)\nand [this](https://dsp.stackexchange.com/questions/1637/what-does-frequency-domain-denote-in-case-of-images/1644#1644) useful get started.\n\nLibvips has [`fwfft`](https://www.libvips.org/API/current/libvips-freqfilt.html#vips-fwfft)\nfunction for Forward Fourier Transform operation and\n[`invfft`](https://www.libvips.org/API/current/libvips-freqfilt.html#vips-invfft)\nfor Inverse Fourier Transform operation.","ref":"auto_correct_rotation.html#fourier-transformation"},{"type":"extras","title":"Fwfft - Auto Correct Document Rotation","doc":"`fwfft` returns an image with complex band format. Real part of the\nband will be the wave Amplitude, Imaginary part of the band will be the\nwave Phase. Position of the value is the frequency.\n\nSince the returned image is in Complex band format, it can not be displayed.\nTo make it visible we need convert the complex band to 2 band float, warp the\nimage to center, scale values so they are visible.\n\n```elixir\nwhite = Operation.black!(10, 200) + 255\nvert_line = Operation.embed!(white, 45, 0, 200, 200)\n\n# take fourier transform of the input image\nft = Operation.fwfft!(vert_line)\n\n# display the images, notice the band format and band count\nKino.Layout.grid(\n  [Kino.Text.new(\"Input\"), Kino.Text.new(\"Fourier Transform\"), vert_line, ft],\n  columns: 2\n)\n|> Kino.render()\n\n# convert complex number to 2 band double format\nft = Operation.copy!(ft, format: :VIPS_FORMAT_DOUBLE, bands: 2)\n\n# do logarithm scaling for the image so that points visible\n# and move the origin of the image to center\nscaled_ft =\n  ft\n  |> Operation.scale!(log: true)\n  |> Operation.wrap!()\n\n# separate amplitude and phase channels\namp = scaled_ft[0]\nphase = scaled_ft[1]\n\nKino.Layout.grid(\n  [Kino.Text.new(\"Amplitude\"), Kino.Text.new(\"Phase\"), amp, phase],\n  columns: 2\n)\n```\n\nSince all these conversion is common, libvips provides\n`spectrum` function which does all this for you.\nSpectrum computes fourier transform, takes absolute value\n(amplitude), scales and wraps the origin. It meant for\ndisplaying the Fourier Transform.\n\n```elixir\nOperation.spectrum!(vert_line)\n```\n\nLet's display fourier transform for few sample images to see how the\noutput changes. Change the number of lines and see how fourier transform changes.\n\n```elixir\nlines_count =\n  Kino.Input.number(\"Number of lines\", default: 10)\n  |> Kino.render()\n  |> Kino.Input.read()\n\n# lets create images which black and white lines\nwidth = trunc(100 / lines_count)\nblack_line = Operation.black!(width, 200)\n\n# 10 lines B&W lines\nlines =\n  [black_line, Operation.invert!(black_line)]\n  |> List.duplicate(lines_count)\n  |> List.flatten()\n\nvert_lines = Operation.arrayjoin!(lines, across: length(lines))\nhorz_lines = Operation.rot!(vert_lines, :VIPS_ANGLE_D90)\nvert_horz_lines = vert_lines + horz_lines\n\nsamples = [vert_lines, horz_lines, vert_horz_lines]\n\nsamples\n|> Enum.flat_map(fn img ->\n  [img, Operation.spectrum!(img)]\nend)\n|> Kino.Layout.grid(columns: 2)\n```\n\nAs we can see, the vertical lines in the input image produces a horizontal\nline in the fourier transform and horizontal lines in the\ninput produces to vertical line in the FT. Changing the number of lines\ndoes not change the number lines on the output image.\n\nSo if we take Fourier Transform of a perfect text image, it should have\nvertical lines and or horizontal lines exactly at 0, 90, 180, 270 degree angle,\nsince the characters and lines are either parallel or perpedicular. If the\ndocument is off by some angle then the same should be visible in the Fourier\nTransform.\n\n```elixir\nKino.Layout.grid([img, Operation.spectrum!(img)], columns: 2)\n```\n\nIndeed we can see a slightly off vertical line and horizontal\nlines. Now we just need to find the angle.","ref":"auto_correct_rotation.html#fwfft"},{"type":"extras","title":"Finding the angle - Auto Correct Document Rotation","doc":"As said before output of image of Fourier Transform will be in complex band format.\nThe real part of it is amplitude, which is what we are\nseeing as lines and there is imaginary part which is phase.\n\nThere are two different way to plot complex numbers on a 2D plane.\n\n* Cartesian (Rectangle) coordinate system\n* Polar coordinate system\n\nLibvips provides functions to convert numbers from one plane to other plane.\nIntuitively when converting from Cartesian system to Polar system,\nall vertical lines becomes the circle and horizontal lines becomes the arch/segment.\nWhich is what we used in the \"Creating Rainbow\" livebook for generating the arch.\n\nBut there is also the inverse operation. We can convert an image from Polar\nplan to Cartesian plane. The circle becomes the vertical line and the\nsegment becomes the horizontal line. **More importantly radius becomes the x-axis and\nangle becomes the y-axis.**\n\nLet's see few examples\n\n```elixir\ndefmodule ComplexOps do\n  def to_cartesian(img, background \\\\ [0, 0, 0]) do\n    %{width: width, height: height} = Image.headers(img)\n    xy = Operation.xyz!(width, height)\n\n    # normalize the y-axis to be between 0 and 360\n    xy = xy * [1, 360 / height]\n\n    xy =\n      xy\n      # read values as complex numbers\n      |> Operation.copy!(format: :VIPS_FORMAT_COMPLEX, bands: 1)\n      # convert from polar to Cartesian plane\n      |> Operation.complex!(:VIPS_OPERATION_COMPLEX_RECT)\n      # and convert back to float\n      |> Operation.copy!(format: :VIPS_FORMAT_FLOAT, bands: 2)\n\n    scale = min(width, height) / width\n    xy = xy * (scale / 2)\n    xy = xy + [width / 2, height / 2]\n\n    # mapim takes an input and a `map` and generates an output image\n    # where input image pixels are moved based on map.\n    #\n    # [new_x, new_y] = map[x, y]\n    # out[x, y] = img[new_x, new_y]\n    #\n    # mapim is to rotate, displace, distort, any type of spatial operations.\n    # where the pixel value (color) remain same but the position is changed.\n    Operation.mapim!(img, xy, background: background)\n  end\nend\n\nsamples\n|> Enum.flat_map(fn img ->\n  ft = Operation.spectrum!(img)\n  [img, ft, ComplexOps.to_cartesian(ft)]\nend)\n|> Kino.Layout.grid(columns: 3)\n```\n\n```elixir\n# for the input document\nimg\n|> Operation.spectrum!()\n|> ComplexOps.to_cartesian()\n```\n\nOnly thing left now is to find a row with maximum value.\nThe row number corresponding to the maximum value is the angle.\nLibvips has `project` function which finds the row wise and column\nwise sum and returns them as image, we can then use `max` to\nfind the maximum value and its position.\n\n```elixir\ndefmodule Utils do\n  def find_angle(cartesian) do\n    # find the row wise and column wise sum\n    # returns 2 images with respective column/row sum\n    {_columns, rows} = Operation.project!(cartesian)\n\n    # find position of the row with maximum value\n    {_, %{y: y_pos}} = Operation.max!(rows)\n\n    # convert the y position back to angle.\n    y_pos / Image.height(rows) * 360\n  end\nend\n\nsamples\n|> Enum.flat_map(fn img ->\n  ft = Operation.spectrum!(img)\n  cartesian = ComplexOps.to_cartesian(ft)\n\n  angle = Utils.find_angle(cartesian)\n  # print angle next to image\n  text = Kino.Text.new(\"\\n\\n\\n#{to_string(angle)}\")\n\n  [img, ft, cartesian, text]\nend)\n|> then(fn list ->\n  headers = ~w(Input Fourier-Transform Polar-Plane Angle) |> Enum.map(&Kino.Text.new/1)\n  headers ++ list\nend)\n|> Kino.Layout.grid(columns: 4)\n```\n\nIf there are multiple rows with same maximum values we pick one randomly.\n\nFor the input image\n\n```elixir\nft = Operation.spectrum!(img)\ncartesian = ComplexOps.to_cartesian(ft)\n\nangle = Utils.find_angle(cartesian)\n\n# since we know that angle can only be parallel or perpendicular\n# can take mod of 90\nangle = angle - trunc(angle / 90) * 90\n```","ref":"auto_correct_rotation.html#finding-the-angle"},{"type":"extras","title":"Correcting the rotation - Auto Correct Document Rotation","doc":"Putting it all together now we can rotate the image using the\ndifference as correction to fix the document\n\n```elixir\ndiff = 90 - angle\ncorrected = Operation.rotate!(img, diff)\n\nKino.Layout.grid([Kino.Text.new(\"Input\"), Kino.Text.new(\"Corrected\"), img, corrected], columns: 2)\n```","ref":"auto_correct_rotation.html#correcting-the-rotation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}